/*******************************************************************************
 * Copyright (c) 2007, 2008 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
module dwt.internal.cocoa.OS;

import dwt.dwthelper.utils;

import dwt.internal.C;
import dwt.internal.Library;

import unistd = tango.stdc.posix.unistd;
import stdc = tango.stdc.string;

import Carbon = dwt.internal.c.Carbon;
import custom = dwt.internal.c.custom;
import dwt.internal.cocoa.CGPoint;
import dwt.internal.cocoa.CGRect;
import dwt.internal.cocoa.CGSize;
import dwt.internal.cocoa.NSAffineTransformStruct;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSPoint;
import dwt.internal.cocoa.NSRange;
import dwt.internal.cocoa.NSRect;
import dwt.internal.cocoa.NSSize;
import dwt.internal.cocoa.NSString;
import Cocoa = dwt.internal.objc.cocoa.Cocoa;
import objc = dwt.internal.objc.runtime;

public class OS : C {
    /*static this (){
        Library.loadLibrary("swt-pi"); //$NON-NLS-1$
    }*/
    
    public static const int VERSION;
    static this () {
        int [1] response;
        OS.Gestalt (OS.gestaltSystemVersion, response.ptr);
        VERSION = response [0] & 0xffff;
        
        sel_sendSelection = sel_registerName("sendSelection");
        sel_sendDoubleSelection = sel_registerName("sendDoubleSelection");
        sel_sendVerticalSelection = sel_registerName("sendVerticalSelection");
        sel_sendHorizontalSelection = sel_registerName("sendHorizontalSelection");
        sel_timerProc_ = sel_registerName("timerProc:");
        sel_handleNotification_ = sel_registerName("handleNotification:");
        
        class_DOMDocument = objc_getClass("DOMDocument");
        class_DOMEvent = objc_getClass("DOMEvent");
        class_DOMKeyboardEvent = objc_getClass("DOMKeyboardEvent");
        class_DOMMouseEvent = objc_getClass("DOMMouseEvent");
        class_DOMUIEvent = objc_getClass("DOMUIEvent");
        class_DOMWheelEvent = objc_getClass("DOMWheelEvent");
        class_NSActionCell = objc_getClass("NSActionCell");
        class_NSAffineTransform = objc_getClass("NSAffineTransform");
        class_NSAlert = objc_getClass("NSAlert");
        class_NSAppleEventDescriptor = objc_getClass("NSAppleEventDescriptor");
        class_NSApplication = objc_getClass("NSApplication");
        class_NSArray = objc_getClass("NSArray");
        class_NSAttributedString = objc_getClass("NSAttributedString");
        class_NSAutoreleasePool = objc_getClass("NSAutoreleasePool");
        class_NSBezierPath = objc_getClass("NSBezierPath");
        class_NSBitmapImageRep = objc_getClass("NSBitmapImageRep");
        class_NSBox = objc_getClass("NSBox");
        class_NSBrowserCell = objc_getClass("NSBrowserCell");
        class_NSBundle = objc_getClass("NSBundle");
        class_NSButton = objc_getClass("NSButton");
        class_NSButtonCell = objc_getClass("NSButtonCell");
        class_NSCalendarDate = objc_getClass("NSCalendarDate");
        class_NSCell = objc_getClass("NSCell");
        class_NSCharacterSet = objc_getClass("NSCharacterSet");
        class_NSClipView = objc_getClass("NSClipView");
        class_NSCoder = objc_getClass("NSCoder");
        class_NSColor = objc_getClass("NSColor");
        class_NSColorPanel = objc_getClass("NSColorPanel");
        class_NSColorSpace = objc_getClass("NSColorSpace");
        class_NSComboBox = objc_getClass("NSComboBox");
        class_NSControl = objc_getClass("NSControl");
        class_NSCursor = objc_getClass("NSCursor");
        class_NSData = objc_getClass("NSData");
        class_NSDate = objc_getClass("NSDate");
        class_NSDatePicker = objc_getClass("NSDatePicker");
        class_NSDictionary = objc_getClass("NSDictionary");
        class_NSDirectoryEnumerator = objc_getClass("NSDirectoryEnumerator");
        class_NSEnumerator = objc_getClass("NSEnumerator");
        class_NSError = objc_getClass("NSError");
        class_NSEvent = objc_getClass("NSEvent");
        class_NSFileManager = objc_getClass("NSFileManager");
        class_NSFont = objc_getClass("NSFont");
        class_NSFontManager = objc_getClass("NSFontManager");
        class_NSFontPanel = objc_getClass("NSFontPanel");
        class_NSFormatter = objc_getClass("NSFormatter");
        class_NSGradient = objc_getClass("NSGradient");
        class_NSGraphicsContext = objc_getClass("NSGraphicsContext");
        class_NSHTTPCookie = objc_getClass("NSHTTPCookie");
        class_NSHTTPCookieStorage = objc_getClass("NSHTTPCookieStorage");
        class_NSImage = objc_getClass("NSImage");
        class_NSImageRep = objc_getClass("NSImageRep");
        class_NSImageView = objc_getClass("NSImageView");
        class_NSIndexSet = objc_getClass("NSIndexSet");
        class_NSInputManager = objc_getClass("NSInputManager");
        class_NSKeyedArchiver = objc_getClass("NSKeyedArchiver");
        class_NSKeyedUnarchiver = objc_getClass("NSKeyedUnarchiver");
        class_NSLayoutManager = objc_getClass("NSLayoutManager");
        class_NSMenu = objc_getClass("NSMenu");
        class_NSMenuItem = objc_getClass("NSMenuItem");
        class_NSMutableArray = objc_getClass("NSMutableArray");
        class_NSMutableAttributedString = objc_getClass("NSMutableAttributedString");
        class_NSMutableDictionary = objc_getClass("NSMutableDictionary");
        class_NSMutableIndexSet = objc_getClass("NSMutableIndexSet");
        class_NSMutableParagraphStyle = objc_getClass("NSMutableParagraphStyle");
        class_NSMutableSet = objc_getClass("NSMutableSet");
        class_NSMutableString = objc_getClass("NSMutableString");
        class_NSMutableURLRequest = objc_getClass("NSMutableURLRequest");
        class_NSNotification = objc_getClass("NSNotification");
        class_NSNotificationCenter = objc_getClass("NSNotificationCenter");
        class_NSNumber = objc_getClass("NSNumber");
        class_NSNumberFormatter = objc_getClass("NSNumberFormatter");
        class_NSObject = objc_getClass("NSObject");
        class_NSOpenGLContext = objc_getClass("NSOpenGLContext");
        class_NSOpenGLPixelFormat = objc_getClass("NSOpenGLPixelFormat");
        class_NSOpenGLView = objc_getClass("NSOpenGLView");
        class_NSOpenPanel = objc_getClass("NSOpenPanel");
        class_NSOutlineView = objc_getClass("NSOutlineView");
        class_NSPanel = objc_getClass("NSPanel");
        class_NSParagraphStyle = objc_getClass("NSParagraphStyle");
        class_NSPasteboard = objc_getClass("NSPasteboard");
        class_NSPopUpButton = objc_getClass("NSPopUpButton");
        class_NSPrintInfo = objc_getClass("NSPrintInfo");
        class_NSPrintOperation = objc_getClass("NSPrintOperation");
        class_NSPrintPanel = objc_getClass("NSPrintPanel");
        class_NSPrinter = objc_getClass("NSPrinter");
        class_NSProgressIndicator = objc_getClass("NSProgressIndicator");
        class_NSResponder = objc_getClass("NSResponder");
        class_NSRunLoop = objc_getClass("NSRunLoop");
        class_NSSavePanel = objc_getClass("NSSavePanel");
        class_NSScreen = objc_getClass("NSScreen");
        class_NSScrollView = objc_getClass("NSScrollView");
        class_NSScroller = objc_getClass("NSScroller");
        class_NSSearchField = objc_getClass("NSSearchField");
        class_NSSecureTextField = objc_getClass("NSSecureTextField");
        class_NSSet = objc_getClass("NSSet");
        class_NSSlider = objc_getClass("NSSlider");
        class_NSStatusBar = objc_getClass("NSStatusBar");
        class_NSStatusItem = objc_getClass("NSStatusItem");
        class_NSStepper = objc_getClass("NSStepper");
        class_NSString = objc_getClass("NSString");
        class_NSTabView = objc_getClass("NSTabView");
        class_NSTabViewItem = objc_getClass("NSTabViewItem");
        class_NSTableColumn = objc_getClass("NSTableColumn");
        class_NSTableHeaderCell = objc_getClass("NSTableHeaderCell");
        class_NSTableHeaderView = objc_getClass("NSTableHeaderView");
        class_NSTableView = objc_getClass("NSTableView");
        class_NSText = objc_getClass("NSText");
        class_NSTextContainer = objc_getClass("NSTextContainer");
        class_NSTextField = objc_getClass("NSTextField");
        class_NSTextFieldCell = objc_getClass("NSTextFieldCell");
        class_NSTextStorage = objc_getClass("NSTextStorage");
        class_NSTextTab = objc_getClass("NSTextTab");
        class_NSTextView = objc_getClass("NSTextView");
        class_NSThread = objc_getClass("NSThread");
        class_NSTimeZone = objc_getClass("NSTimeZone");
        class_NSTimer = objc_getClass("NSTimer");
        class_NSTypesetter = objc_getClass("NSTypesetter");
        class_NSURL = objc_getClass("NSURL");
        class_NSURLDownload = objc_getClass("NSURLDownload");
        class_NSURLRequest = objc_getClass("NSURLRequest");
        class_NSValue = objc_getClass("NSValue");
        class_NSView = objc_getClass("NSView");
        class_NSWindow = objc_getClass("NSWindow");
        class_NSWorkspace = objc_getClass("NSWorkspace");
        class_WebDataSource = objc_getClass("WebDataSource");
        class_WebFrame = objc_getClass("WebFrame");
        class_WebFrameView = objc_getClass("WebFrameView");
        class_WebPreferences = objc_getClass("WebPreferences");
        class_WebView = objc_getClass("WebView");
        
        protocol_NSAccessibility = objc_getProtocol("NSAccessibility");
        protocol_NSAccessibilityAdditions = objc_getProtocol("NSAccessibilityAdditions");
        protocol_NSApplicationDelegate = objc_getProtocol("NSApplicationDelegate");
        protocol_NSApplicationNotifications = objc_getProtocol("NSApplicationNotifications");
        protocol_NSColorPanelResponderMethod = objc_getProtocol("NSColorPanelResponderMethod");
        protocol_NSComboBoxNotifications = objc_getProtocol("NSComboBoxNotifications");
        protocol_NSDraggingDestination = objc_getProtocol("NSDraggingDestination");
        protocol_NSDraggingSource = objc_getProtocol("NSDraggingSource");
        protocol_NSFontManagerResponderMethod = objc_getProtocol("NSFontManagerResponderMethod");
        protocol_NSMenuDelegate = objc_getProtocol("NSMenuDelegate");
        protocol_NSOutlineViewDataSource = objc_getProtocol("NSOutlineViewDataSource");
        protocol_NSOutlineViewDelegate = objc_getProtocol("NSOutlineViewDelegate");
        protocol_NSOutlineViewNotifications = objc_getProtocol("NSOutlineViewNotifications");
        protocol_NSPasteboardOwner = objc_getProtocol("NSPasteboardOwner");
        protocol_NSTabViewDelegate = objc_getProtocol("NSTabViewDelegate");
        protocol_NSTableDataSource = objc_getProtocol("NSTableDataSource");
        protocol_NSTableViewDelegate = objc_getProtocol("NSTableViewDelegate");
        protocol_NSTableViewNotifications = objc_getProtocol("NSTableViewNotifications");
        protocol_NSTextDelegate = objc_getProtocol("NSTextDelegate");
        protocol_NSTextInput = objc_getProtocol("NSTextInput");
        protocol_NSTextViewDelegate = objc_getProtocol("NSTextViewDelegate");
        protocol_NSURLDownloadDelegate = objc_getProtocol("NSURLDownloadDelegate");
        protocol_NSWindowDelegate = objc_getProtocol("NSWindowDelegate");
        protocol_NSWindowNotifications = objc_getProtocol("NSWindowNotifications");
        protocol_WebDocumentRepresentation = objc_getProtocol("WebDocumentRepresentation");
        protocol_WebFrameLoadDelegate = objc_getProtocol("WebFrameLoadDelegate");
        protocol_WebOpenPanelResultListener = objc_getProtocol("WebOpenPanelResultListener");
        protocol_WebPolicyDecisionListener = objc_getProtocol("WebPolicyDecisionListener");
        protocol_WebPolicyDelegate = objc_getProtocol("WebPolicyDelegate");
        protocol_WebResourceLoadDelegate = objc_getProtocol("WebResourceLoadDelegate");
        protocol_WebUIDelegate = objc_getProtocol("WebUIDelegate");
        
        sel_DOMDocument = sel_registerName("DOMDocument");
        sel_IBeamCursor = sel_registerName("IBeamCursor");
        sel_TIFFRepresentation = sel_registerName("TIFFRepresentation");
        sel_URL = sel_registerName("URL");
        sel_URLFromPasteboard_ = sel_registerName("URLFromPasteboard:");
        sel_URLWithString_ = sel_registerName("URLWithString:");
        sel_UTF8String = sel_registerName("UTF8String");
        sel_absoluteString = sel_registerName("absoluteString");
        sel_acceptsFirstResponder = sel_registerName("acceptsFirstResponder");
        sel_accessibilityActionDescription_ = sel_registerName("accessibilityActionDescription:");
        sel_accessibilityActionNames = sel_registerName("accessibilityActionNames");
        sel_accessibilityAttributeNames = sel_registerName("accessibilityAttributeNames");
        sel_accessibilityAttributeValue_ = sel_registerName("accessibilityAttributeValue:");
        sel_accessibilityAttributeValue_forParameter_ = sel_registerName("accessibilityAttributeValue:forParameter:");
        sel_accessibilityFocusedUIElement = sel_registerName("accessibilityFocusedUIElement");
        sel_accessibilityHitTest_ = sel_registerName("accessibilityHitTest:");
        sel_accessibilityIsAttributeSettable_ = sel_registerName("accessibilityIsAttributeSettable:");
        sel_accessibilityIsIgnored = sel_registerName("accessibilityIsIgnored");
        sel_accessibilityParameterizedAttributeNames = sel_registerName("accessibilityParameterizedAttributeNames");
        sel_accessibilityPerformAction_ = sel_registerName("accessibilityPerformAction:");
        sel_accessibilitySetOverrideValue_forAttribute_ = sel_registerName("accessibilitySetOverrideValue:forAttribute:");
        sel_accessibilitySetValue_forAttribute_ = sel_registerName("accessibilitySetValue:forAttribute:");
        sel_action = sel_registerName("action");
        sel_activateIgnoringOtherApps_ = sel_registerName("activateIgnoringOtherApps:");
        sel_addAttribute_value_range_ = sel_registerName("addAttribute:value:range:");
        sel_addClip = sel_registerName("addClip");
        sel_addEventListener_listener_useCapture_ = sel_registerName("addEventListener:listener:useCapture:");
        sel_addIndex_ = sel_registerName("addIndex:");
        sel_addItem_ = sel_registerName("addItem:");
        sel_addItemWithObjectValue_ = sel_registerName("addItemWithObjectValue:");
        sel_addLayoutManager_ = sel_registerName("addLayoutManager:");
        sel_addObject_ = sel_registerName("addObject:");
        sel_addObjectsFromArray_ = sel_registerName("addObjectsFromArray:");
        sel_addObserver_selector_name_object_ = sel_registerName("addObserver:selector:name:object:");
        sel_addRepresentation_ = sel_registerName("addRepresentation:");
        sel_addSubview_ = sel_registerName("addSubview:");
        sel_addSubview_positioned_relativeTo_ = sel_registerName("addSubview:positioned:relativeTo:");
        sel_addTabStop_ = sel_registerName("addTabStop:");
        sel_addTabViewItem_ = sel_registerName("addTabViewItem:");
        sel_addTableColumn_ = sel_registerName("addTableColumn:");
        sel_addTemporaryAttribute_value_forCharacterRange_ = sel_registerName("addTemporaryAttribute:value:forCharacterRange:");
        sel_addTextContainer_ = sel_registerName("addTextContainer:");
        sel_addTypes_owner_ = sel_registerName("addTypes:owner:");
        sel_alertWithMessageText_defaultButton_alternateButton_otherButton_informativeTextWithFormat_ = sel_registerName("alertWithMessageText:defaultButton:alternateButton:otherButton:informativeTextWithFormat:");
        sel_alignment = sel_registerName("alignment");
        sel_allKeys = sel_registerName("allKeys");
        sel_alloc = sel_registerName("alloc");
        sel_allowsFloats = sel_registerName("allowsFloats");
        sel_alphaComponent = sel_registerName("alphaComponent");
        sel_alphaValue = sel_registerName("alphaValue");
        sel_altKey = sel_registerName("altKey");
        sel_alternateSelectedControlTextColor = sel_registerName("alternateSelectedControlTextColor");
        sel_alwaysShowsDecimalSeparator = sel_registerName("alwaysShowsDecimalSeparator");
        sel_appendBezierPath_ = sel_registerName("appendBezierPath:");
        sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_ = sel_registerName("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:");
        sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_clockwise_ = sel_registerName("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:clockwise:");
        sel_appendBezierPathWithGlyphs_count_inFont_ = sel_registerName("appendBezierPathWithGlyphs:count:inFont:");
        sel_appendBezierPathWithOvalInRect_ = sel_registerName("appendBezierPathWithOvalInRect:");
        sel_appendBezierPathWithRect_ = sel_registerName("appendBezierPathWithRect:");
        sel_appendBezierPathWithRoundedRect_xRadius_yRadius_ = sel_registerName("appendBezierPathWithRoundedRect:xRadius:yRadius:");
        sel_appendString_ = sel_registerName("appendString:");
        sel_applicationShouldTerminate_ = sel_registerName("applicationShouldTerminate:");
        sel_applicationWillFinishLaunching_ = sel_registerName("applicationWillFinishLaunching:");
        sel_applicationWillResignActive_ = sel_registerName("applicationWillResignActive:");
        sel_applicationWillTerminate_ = sel_registerName("applicationWillTerminate:");
        sel_archivedDataWithRootObject_ = sel_registerName("archivedDataWithRootObject:");
        sel_array = sel_registerName("array");
        sel_arrayWithCapacity_ = sel_registerName("arrayWithCapacity:");
        sel_arrayWithObject_ = sel_registerName("arrayWithObject:");
        sel_arrowCursor = sel_registerName("arrowCursor");
        sel_ascender = sel_registerName("ascender");
        sel_attributedSubstringFromRange_ = sel_registerName("attributedSubstringFromRange:");
        sel_attributesAtIndex_longestEffectiveRange_inRange_ = sel_registerName("attributesAtIndex:longestEffectiveRange:inRange:");
        sel_autorelease = sel_registerName("autorelease");
        sel_availableFontFamilies = sel_registerName("availableFontFamilies");
        sel_availableFonts = sel_registerName("availableFonts");
        sel_availableMembersOfFontFamily_ = sel_registerName("availableMembersOfFontFamily:");
        sel_availableTypeFromArray_ = sel_registerName("availableTypeFromArray:");
        sel_baselineOffsetInLayoutManager_glyphIndex_ = sel_registerName("baselineOffsetInLayoutManager:glyphIndex:");
        sel_becomeFirstResponder = sel_registerName("becomeFirstResponder");
        sel_beginDocument = sel_registerName("beginDocument");
        sel_beginEditing = sel_registerName("beginEditing");
        sel_beginPageInRect_atPlacement_ = sel_registerName("beginPageInRect:atPlacement:");
        sel_bestRepresentationForDevice_ = sel_registerName("bestRepresentationForDevice:");
        sel_bezierPath = sel_registerName("bezierPath");
        sel_bezierPathByFlatteningPath = sel_registerName("bezierPathByFlatteningPath");
        sel_bezierPathWithRect_ = sel_registerName("bezierPathWithRect:");
        sel_bitmapData = sel_registerName("bitmapData");
        sel_bitsPerPixel = sel_registerName("bitsPerPixel");
        sel_bitsPerSample = sel_registerName("bitsPerSample");
        sel_blackColor = sel_registerName("blackColor");
        sel_blueComponent = sel_registerName("blueComponent");
        sel_borderWidth = sel_registerName("borderWidth");
        sel_boundingRectForGlyphRange_inTextContainer_ = sel_registerName("boundingRectForGlyphRange:inTextContainer:");
        sel_bounds = sel_registerName("bounds");
        sel_bundleIdentifier = sel_registerName("bundleIdentifier");
        sel_bundlePath = sel_registerName("bundlePath");
        sel_bundleWithPath_ = sel_registerName("bundleWithPath:");
        sel_button = sel_registerName("button");
        sel_buttonNumber = sel_registerName("buttonNumber");
        sel_bytes = sel_registerName("bytes");
        sel_bytesPerPlane = sel_registerName("bytesPerPlane");
        sel_bytesPerRow = sel_registerName("bytesPerRow");
        sel_calendarDate = sel_registerName("calendarDate");
        sel_canBecomeKeyWindow = sel_registerName("canBecomeKeyWindow");
        sel_canGoBack = sel_registerName("canGoBack");
        sel_canGoForward = sel_registerName("canGoForward");
        sel_canShowMIMEType_ = sel_registerName("canShowMIMEType:");
        sel_cancel = sel_registerName("cancel");
        sel_cancelTracking = sel_registerName("cancelTracking");
        sel_cascadeTopLeftFromPoint_ = sel_registerName("cascadeTopLeftFromPoint:");
        sel_cell = sel_registerName("cell");
        sel_cellClass = sel_registerName("cellClass");
        sel_cellSizeForBounds_ = sel_registerName("cellSizeForBounds:");
        sel_changeColor_ = sel_registerName("changeColor:");
        sel_changeFont_ = sel_registerName("changeFont:");
        sel_charCode = sel_registerName("charCode");
        sel_characterAtIndex_ = sel_registerName("characterAtIndex:");
        sel_characterIndexForGlyphAtIndex_ = sel_registerName("characterIndexForGlyphAtIndex:");
        sel_characterIndexForPoint_ = sel_registerName("characterIndexForPoint:");
        sel_characterIsMember_ = sel_registerName("characterIsMember:");
        sel_characters = sel_registerName("characters");
        sel_charactersIgnoringModifiers = sel_registerName("charactersIgnoringModifiers");
        sel_chooseFilename_ = sel_registerName("chooseFilename:");
        sel_className = sel_registerName("className");
        sel_cleanUpOperation = sel_registerName("cleanUpOperation");
        sel_clearColor = sel_registerName("clearColor");
        sel_clearCurrentContext = sel_registerName("clearCurrentContext");
        sel_clearGLContext = sel_registerName("clearGLContext");
        sel_clickCount = sel_registerName("clickCount");
        sel_clientX = sel_registerName("clientX");
        sel_clientY = sel_registerName("clientY");
        sel_close = sel_registerName("close");
        sel_closePath = sel_registerName("closePath");
        sel_code = sel_registerName("code");
        sel_collapseItem_ = sel_registerName("collapseItem:");
        sel_color = sel_registerName("color");
        sel_colorUsingColorSpace_ = sel_registerName("colorUsingColorSpace:");
        sel_colorUsingColorSpaceName_ = sel_registerName("colorUsingColorSpaceName:");
        sel_colorWithDeviceRed_green_blue_alpha_ = sel_registerName("colorWithDeviceRed:green:blue:alpha:");
        sel_colorWithPatternImage_ = sel_registerName("colorWithPatternImage:");
        sel_columnAtPoint_ = sel_registerName("columnAtPoint:");
        sel_columnAutoresizingStyle = sel_registerName("columnAutoresizingStyle");
        sel_columnIndexesInRect_ = sel_registerName("columnIndexesInRect:");
        sel_columnWithIdentifier_ = sel_registerName("columnWithIdentifier:");
        sel_comboBoxSelectionDidChange_ = sel_registerName("comboBoxSelectionDidChange:");
        sel_concat = sel_registerName("concat");
        sel_conformsToProtocol_ = sel_registerName("conformsToProtocol:");
        sel_containerSize = sel_registerName("containerSize");
        sel_containsObject_ = sel_registerName("containsObject:");
        sel_containsPoint_ = sel_registerName("containsPoint:");
        sel_contentRect = sel_registerName("contentRect");
        sel_contentRectForFrameRect_ = sel_registerName("contentRectForFrameRect:");
        sel_contentSize = sel_registerName("contentSize");
        sel_contentSizeForFrameSize_hasHorizontalScroller_hasVerticalScroller_borderType_ = sel_registerName("contentSizeForFrameSize:hasHorizontalScroller:hasVerticalScroller:borderType:");
        sel_contentView = sel_registerName("contentView");
        sel_contentViewMargins = sel_registerName("contentViewMargins");
        sel_context = sel_registerName("context");
        sel_controlDarkShadowColor = sel_registerName("controlDarkShadowColor");
        sel_controlHighlightColor = sel_registerName("controlHighlightColor");
        sel_controlLightHighlightColor = sel_registerName("controlLightHighlightColor");
        sel_controlPointBounds = sel_registerName("controlPointBounds");
        sel_controlShadowColor = sel_registerName("controlShadowColor");
        sel_controlTextColor = sel_registerName("controlTextColor");
        sel_convertBaseToScreen_ = sel_registerName("convertBaseToScreen:");
        sel_convertPoint_fromView_ = sel_registerName("convertPoint:fromView:");
        sel_convertPoint_toView_ = sel_registerName("convertPoint:toView:");
        sel_convertPointFromBase_ = sel_registerName("convertPointFromBase:");
        sel_convertPointToBase_ = sel_registerName("convertPointToBase:");
        sel_convertRect_fromView_ = sel_registerName("convertRect:fromView:");
        sel_convertRect_toView_ = sel_registerName("convertRect:toView:");
        sel_convertRectFromBase_ = sel_registerName("convertRectFromBase:");
        sel_convertRectToBase_ = sel_registerName("convertRectToBase:");
        sel_convertScreenToBase_ = sel_registerName("convertScreenToBase:");
        sel_convertSize_fromView_ = sel_registerName("convertSize:fromView:");
        sel_convertSize_toView_ = sel_registerName("convertSize:toView:");
        sel_convertSizeFromBase_ = sel_registerName("convertSizeFromBase:");
        sel_convertSizeToBase_ = sel_registerName("convertSizeToBase:");
        sel_cookies = sel_registerName("cookies");
        sel_copy = sel_registerName("copy");
        sel_copy_ = sel_registerName("copy:");
        sel_count = sel_registerName("count");
        sel_createContext = sel_registerName("createContext");
        sel_createFileAtPath_contents_attributes_ = sel_registerName("createFileAtPath:contents:attributes:");
        sel_crosshairCursor = sel_registerName("crosshairCursor");
        sel_ctrlKey = sel_registerName("ctrlKey");
        sel_currentContext = sel_registerName("currentContext");
        sel_currentEditor = sel_registerName("currentEditor");
        sel_currentEvent = sel_registerName("currentEvent");
        sel_currentInputManager = sel_registerName("currentInputManager");
        sel_currentPoint = sel_registerName("currentPoint");
        sel_currentRunLoop = sel_registerName("currentRunLoop");
        sel_currentThread = sel_registerName("currentThread");
        sel_curveToPoint_controlPoint1_controlPoint2_ = sel_registerName("curveToPoint:controlPoint1:controlPoint2:");
        sel_cut_ = sel_registerName("cut:");
        sel_dataForType_ = sel_registerName("dataForType:");
        sel_dataSource = sel_registerName("dataSource");
        sel_dataWithBytes_length_ = sel_registerName("dataWithBytes:length:");
        sel_dateValue = sel_registerName("dateValue");
        sel_dateWithCalendarFormat_timeZone_ = sel_registerName("dateWithCalendarFormat:timeZone:");
        sel_dateWithTimeIntervalSinceNow_ = sel_registerName("dateWithTimeIntervalSinceNow:");
        sel_dateWithYear_month_day_hour_minute_second_timeZone_ = sel_registerName("dateWithYear:month:day:hour:minute:second:timeZone:");
        sel_dayOfMonth = sel_registerName("dayOfMonth");
        sel_decimalDigitCharacterSet = sel_registerName("decimalDigitCharacterSet");
        sel_decimalSeparator = sel_registerName("decimalSeparator");
        sel_declareTypes_owner_ = sel_registerName("declareTypes:owner:");
        sel_defaultCenter = sel_registerName("defaultCenter");
        sel_defaultFlatness = sel_registerName("defaultFlatness");
        sel_defaultLineHeightForFont_ = sel_registerName("defaultLineHeightForFont:");
        sel_defaultManager = sel_registerName("defaultManager");
        sel_defaultPrinter = sel_registerName("defaultPrinter");
        sel_defaultTimeZone = sel_registerName("defaultTimeZone");
        sel_deleteCookie_ = sel_registerName("deleteCookie:");
        sel_deliverResult = sel_registerName("deliverResult");
        sel_deltaX = sel_registerName("deltaX");
        sel_deltaY = sel_registerName("deltaY");
        sel_depth = sel_registerName("depth");
        sel_descender = sel_registerName("descender");
        sel_description = sel_registerName("description");
        sel_deselectAll_ = sel_registerName("deselectAll:");
        sel_deselectItemAtIndex_ = sel_registerName("deselectItemAtIndex:");
        sel_deselectRow_ = sel_registerName("deselectRow:");
        sel_destroyContext = sel_registerName("destroyContext");
        sel_detail = sel_registerName("detail");
        sel_deviceDescription = sel_registerName("deviceDescription");
        sel_deviceRGBColorSpace = sel_registerName("deviceRGBColorSpace");
        sel_dictionary = sel_registerName("dictionary");
        sel_dictionaryWithCapacity_ = sel_registerName("dictionaryWithCapacity:");
        sel_dictionaryWithObject_forKey_ = sel_registerName("dictionaryWithObject:forKey:");
        sel_disableCursorRects = sel_registerName("disableCursorRects");
        sel_disabledControlTextColor = sel_registerName("disabledControlTextColor");
        sel_displayIfNeeded = sel_registerName("displayIfNeeded");
        sel_distantFuture = sel_registerName("distantFuture");
        sel_doCommandBySelector_ = sel_registerName("doCommandBySelector:");
        sel_documentSource = sel_registerName("documentSource");
        sel_documentView = sel_registerName("documentView");
        sel_documentViewShouldHandlePrint = sel_registerName("documentViewShouldHandlePrint");
        sel_documentVisibleRect = sel_registerName("documentVisibleRect");
        sel_doubleClickAtIndex_ = sel_registerName("doubleClickAtIndex:");
        sel_doubleValue = sel_registerName("doubleValue");
        sel_download = sel_registerName("download");
        sel_download_decideDestinationWithSuggestedFilename_ = sel_registerName("download:decideDestinationWithSuggestedFilename:");
        sel_dragImage_at_offset_event_pasteboard_source_slideBack_ = sel_registerName("dragImage:at:offset:event:pasteboard:source:slideBack:");
        sel_draggedImage = sel_registerName("draggedImage");
        sel_draggedImage_beganAt_ = sel_registerName("draggedImage:beganAt:");
        sel_draggedImage_endedAt_operation_ = sel_registerName("draggedImage:endedAt:operation:");
        sel_draggedImageLocation = sel_registerName("draggedImageLocation");
        sel_draggingDestinationWindow = sel_registerName("draggingDestinationWindow");
        sel_draggingEnded_ = sel_registerName("draggingEnded:");
        sel_draggingEntered_ = sel_registerName("draggingEntered:");
        sel_draggingExited_ = sel_registerName("draggingExited:");
        sel_draggingLocation = sel_registerName("draggingLocation");
        sel_draggingPasteboard = sel_registerName("draggingPasteboard");
        sel_draggingSequenceNumber = sel_registerName("draggingSequenceNumber");
        sel_draggingSource = sel_registerName("draggingSource");
        sel_draggingSourceOperationMask = sel_registerName("draggingSourceOperationMask");
        sel_draggingSourceOperationMaskForLocal_ = sel_registerName("draggingSourceOperationMaskForLocal:");
        sel_draggingUpdated_ = sel_registerName("draggingUpdated:");
        sel_drawAtPoint_ = sel_registerName("drawAtPoint:");
        sel_drawAtPoint_fromRect_operation_fraction_ = sel_registerName("drawAtPoint:fromRect:operation:fraction:");
        sel_drawBackgroundForGlyphRange_atPoint_ = sel_registerName("drawBackgroundForGlyphRange:atPoint:");
        sel_drawFromPoint_toPoint_options_ = sel_registerName("drawFromPoint:toPoint:options:");
        sel_drawGlyphsForGlyphRange_atPoint_ = sel_registerName("drawGlyphsForGlyphRange:atPoint:");
        sel_drawInRect_ = sel_registerName("drawInRect:");
        sel_drawInRect_angle_ = sel_registerName("drawInRect:angle:");
        sel_drawInRect_fromRect_operation_fraction_ = sel_registerName("drawInRect:fromRect:operation:fraction:");
        sel_drawInteriorWithFrame_inView_ = sel_registerName("drawInteriorWithFrame:inView:");
        sel_drawRect_ = sel_registerName("drawRect:");
        sel_drawSortIndicatorWithFrame_inView_ascending_priority_ = sel_registerName("drawSortIndicatorWithFrame:inView:ascending:priority:");
        sel_drawStatusBarBackgroundInRect_withHighlight_ = sel_registerName("drawStatusBarBackgroundInRect:withHighlight:");
        sel_drawingRectForBounds_ = sel_registerName("drawingRectForBounds:");
        sel_elementAtIndex_associatedPoints_ = sel_registerName("elementAtIndex:associatedPoints:");
        sel_elementCount = sel_registerName("elementCount");
        sel_enableFreedObjectCheck_ = sel_registerName("enableFreedObjectCheck:");
        sel_endDocument = sel_registerName("endDocument");
        sel_endEditing = sel_registerName("endEditing");
        sel_endPage = sel_registerName("endPage");
        sel_enumeratorAtPath_ = sel_registerName("enumeratorAtPath:");
        sel_expandItem_ = sel_registerName("expandItem:");
        sel_familyName = sel_registerName("familyName");
        sel_fieldEditor_forObject_ = sel_registerName("fieldEditor:forObject:");
        sel_fileURLWithPath_ = sel_registerName("fileURLWithPath:");
        sel_filename = sel_registerName("filename");
        sel_filenames = sel_registerName("filenames");
        sel_fill = sel_registerName("fill");
        sel_fillRect_ = sel_registerName("fillRect:");
        sel_finishLaunching = sel_registerName("finishLaunching");
        sel_firstIndex = sel_registerName("firstIndex");
        sel_firstRectForCharacterRange_ = sel_registerName("firstRectForCharacterRange:");
        sel_firstResponder = sel_registerName("firstResponder");
        sel_flagsChanged_ = sel_registerName("flagsChanged:");
        sel_flushBuffer = sel_registerName("flushBuffer");
        sel_flushGraphics = sel_registerName("flushGraphics");
        sel_font = sel_registerName("font");
        sel_fontName = sel_registerName("fontName");
        sel_fontWithName_size_ = sel_registerName("fontWithName:size:");
        sel_frame = sel_registerName("frame");
        sel_frameOfCellAtColumn_row_ = sel_registerName("frameOfCellAtColumn:row:");
        sel_frameRectForContentRect_ = sel_registerName("frameRectForContentRect:");
        sel_frameSizeForContentSize_hasHorizontalScroller_hasVerticalScroller_borderType_ = sel_registerName("frameSizeForContentSize:hasHorizontalScroller:hasVerticalScroller:borderType:");
        sel_fullPathForApplication_ = sel_registerName("fullPathForApplication:");
        sel_generalPasteboard = sel_registerName("generalPasteboard");
        sel_getBytes_ = sel_registerName("getBytes:");
        sel_getBytes_length_ = sel_registerName("getBytes:length:");
        sel_getCharacters_ = sel_registerName("getCharacters:");
        sel_getCharacters_range_ = sel_registerName("getCharacters:range:");
        sel_getComponents_ = sel_registerName("getComponents:");
        sel_getGlyphs_range_ = sel_registerName("getGlyphs:range:");
        sel_getIndexes_maxCount_inIndexRange_ = sel_registerName("getIndexes:maxCount:inIndexRange:");
        sel_getInfoForFile_application_type_ = sel_registerName("getInfoForFile:application:type:");
        sel_glyphIndexForCharacterAtIndex_ = sel_registerName("glyphIndexForCharacterAtIndex:");
        sel_glyphIndexForPoint_inTextContainer_fractionOfDistanceThroughGlyph_ = sel_registerName("glyphIndexForPoint:inTextContainer:fractionOfDistanceThroughGlyph:");
        sel_glyphRangeForTextContainer_ = sel_registerName("glyphRangeForTextContainer:");
        sel_goBack = sel_registerName("goBack");
        sel_goForward = sel_registerName("goForward");
        sel_graphicsContext = sel_registerName("graphicsContext");
        sel_graphicsContextWithBitmapImageRep_ = sel_registerName("graphicsContextWithBitmapImageRep:");
        sel_graphicsContextWithWindow_ = sel_registerName("graphicsContextWithWindow:");
        sel_greenComponent = sel_registerName("greenComponent");
        sel_handleEvent_ = sel_registerName("handleEvent:");
        sel_handleMouseEvent_ = sel_registerName("handleMouseEvent:");
        sel_hasAlpha = sel_registerName("hasAlpha");
        sel_hasMarkedText = sel_registerName("hasMarkedText");
        sel_headerCell = sel_registerName("headerCell");
        sel_headerRectOfColumn_ = sel_registerName("headerRectOfColumn:");
        sel_headerView = sel_registerName("headerView");
        sel_helpRequested_ = sel_registerName("helpRequested:");
        sel_hide_ = sel_registerName("hide:");
        sel_hideOtherApplications_ = sel_registerName("hideOtherApplications:");
        sel_highlightColorInView_ = sel_registerName("highlightColorInView:");
        sel_highlightSelectionInClipRect_ = sel_registerName("highlightSelectionInClipRect:");
        sel_hitPart = sel_registerName("hitPart");
        sel_hitTest_ = sel_registerName("hitTest:");
        sel_hourOfDay = sel_registerName("hourOfDay");
        sel_iconForFile_ = sel_registerName("iconForFile:");
        sel_iconForFileType_ = sel_registerName("iconForFileType:");
        sel_ignore = sel_registerName("ignore");
        sel_ignoreModifierKeysWhileDragging = sel_registerName("ignoreModifierKeysWhileDragging");
        sel_imageInterpolation = sel_registerName("imageInterpolation");
        sel_imageablePageBounds = sel_registerName("imageablePageBounds");
        sel_increment = sel_registerName("increment");
        sel_indentationPerLevel = sel_registerName("indentationPerLevel");
        sel_indexOfSelectedItem = sel_registerName("indexOfSelectedItem");
        sel_infoDictionary = sel_registerName("infoDictionary");
        sel_init = sel_registerName("init");
        sel_initByReferencingFile_ = sel_registerName("initByReferencingFile:");
        sel_initListDescriptor = sel_registerName("initListDescriptor");
        sel_initWithAttributes_ = sel_registerName("initWithAttributes:");
        sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_ = sel_registerName("initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bitmapFormat:bytesPerRow:bitsPerPixel:");
        sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_ = sel_registerName("initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bytesPerRow:bitsPerPixel:");
        sel_initWithContainerSize_ = sel_registerName("initWithContainerSize:");
        sel_initWithContentRect_styleMask_backing_defer_ = sel_registerName("initWithContentRect:styleMask:backing:defer:");
        sel_initWithContentRect_styleMask_backing_defer_screen_ = sel_registerName("initWithContentRect:styleMask:backing:defer:screen:");
        sel_initWithData_ = sel_registerName("initWithData:");
        sel_initWithDictionary_ = sel_registerName("initWithDictionary:");
        sel_initWithFrame_ = sel_registerName("initWithFrame:");
        sel_initWithFrame_frameName_groupName_ = sel_registerName("initWithFrame:frameName:groupName:");
        sel_initWithFrame_pixelFormat_ = sel_registerName("initWithFrame:pixelFormat:");
        sel_initWithFrame_pullsDown_ = sel_registerName("initWithFrame:pullsDown:");
        sel_initWithIdentifier_ = sel_registerName("initWithIdentifier:");
        sel_initWithImage_hotSpot_ = sel_registerName("initWithImage:hotSpot:");
        sel_initWithIndex_ = sel_registerName("initWithIndex:");
        sel_initWithIndexesInRange_ = sel_registerName("initWithIndexesInRange:");
        sel_initWithSize_ = sel_registerName("initWithSize:");
        sel_initWithStartingColor_endingColor_ = sel_registerName("initWithStartingColor:endingColor:");
        sel_initWithString_ = sel_registerName("initWithString:");
        sel_initWithString_attributes_ = sel_registerName("initWithString:attributes:");
        sel_initWithTitle_ = sel_registerName("initWithTitle:");
        sel_initWithTitle_action_keyEquivalent_ = sel_registerName("initWithTitle:action:keyEquivalent:");
        sel_initWithTransform_ = sel_registerName("initWithTransform:");
        sel_initWithType_location_ = sel_registerName("initWithType:location:");
        sel_initWithURL_ = sel_registerName("initWithURL:");
        sel_insertItem_atIndex_ = sel_registerName("insertItem:atIndex:");
        sel_insertItemWithObjectValue_atIndex_ = sel_registerName("insertItemWithObjectValue:atIndex:");
        sel_insertTabViewItem_atIndex_ = sel_registerName("insertTabViewItem:atIndex:");
        sel_insertText_ = sel_registerName("insertText:");
        sel_intValue = sel_registerName("intValue");
        sel_intercellSpacing = sel_registerName("intercellSpacing");
        sel_interpretKeyEvents_ = sel_registerName("interpretKeyEvents:");
        sel_invalidate = sel_registerName("invalidate");
        sel_invert = sel_registerName("invert");
        sel_isEmpty = sel_registerName("isEmpty");
        sel_isEqual_ = sel_registerName("isEqual:");
        sel_isEqualTo_ = sel_registerName("isEqualTo:");
        sel_isEqualToString_ = sel_registerName("isEqualToString:");
        sel_isFilePackageAtPath_ = sel_registerName("isFilePackageAtPath:");
        sel_isFlipped = sel_registerName("isFlipped");
        sel_isHidden = sel_registerName("isHidden");
        sel_isKeyWindow = sel_registerName("isKeyWindow");
        sel_isKindOfClass_ = sel_registerName("isKindOfClass:");
        sel_isMainThread = sel_registerName("isMainThread");
        sel_isOpaque = sel_registerName("isOpaque");
        sel_isPlanar = sel_registerName("isPlanar");
        sel_isRowSelected_ = sel_registerName("isRowSelected:");
        sel_isRunning = sel_registerName("isRunning");
        sel_isSessionOnly = sel_registerName("isSessionOnly");
        sel_isVisible = sel_registerName("isVisible");
        sel_itemArray = sel_registerName("itemArray");
        sel_itemAtIndex_ = sel_registerName("itemAtIndex:");
        sel_itemAtRow_ = sel_registerName("itemAtRow:");
        sel_itemObjectValueAtIndex_ = sel_registerName("itemObjectValueAtIndex:");
        sel_itemTitleAtIndex_ = sel_registerName("itemTitleAtIndex:");
        sel_jobDisposition = sel_registerName("jobDisposition");
        sel_keyCode = sel_registerName("keyCode");
        sel_keyDown_ = sel_registerName("keyDown:");
        sel_keyEquivalent = sel_registerName("keyEquivalent");
        sel_keyEquivalentModifierMask = sel_registerName("keyEquivalentModifierMask");
        sel_keyUp_ = sel_registerName("keyUp:");
        sel_keyWindow = sel_registerName("keyWindow");
        sel_lastPathComponent = sel_registerName("lastPathComponent");
        sel_leading = sel_registerName("leading");
        sel_length = sel_registerName("length");
        sel_levelForItem_ = sel_registerName("levelForItem:");
        sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_ = sel_registerName("lineFragmentUsedRectForGlyphAtIndex:effectiveRange:");
        sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_withoutAdditionalLayout_ = sel_registerName("lineFragmentUsedRectForGlyphAtIndex:effectiveRange:withoutAdditionalLayout:");
        sel_lineToPoint_ = sel_registerName("lineToPoint:");
        sel_loadHTMLString_baseURL_ = sel_registerName("loadHTMLString:baseURL:");
        sel_loadNibFile_externalNameTable_withZone_ = sel_registerName("loadNibFile:externalNameTable:withZone:");
        sel_loadRequest_ = sel_registerName("loadRequest:");
        sel_localizedDescription = sel_registerName("localizedDescription");
        sel_location = sel_registerName("location");
        sel_locationForGlyphAtIndex_ = sel_registerName("locationForGlyphAtIndex:");
        sel_locationInWindow = sel_registerName("locationInWindow");
        sel_lowercaseString = sel_registerName("lowercaseString");
        sel_mainFrame = sel_registerName("mainFrame");
        sel_mainMenu = sel_registerName("mainMenu");
        sel_mainRunLoop = sel_registerName("mainRunLoop");
        sel_mainScreen = sel_registerName("mainScreen");
        sel_makeCurrentContext = sel_registerName("makeCurrentContext");
        sel_makeFirstResponder_ = sel_registerName("makeFirstResponder:");
        sel_makeKeyAndOrderFront_ = sel_registerName("makeKeyAndOrderFront:");
        sel_markedRange = sel_registerName("markedRange");
        sel_markedTextAttributes = sel_registerName("markedTextAttributes");
        sel_maxValue = sel_registerName("maxValue");
        sel_maximum = sel_registerName("maximum");
        sel_maximumFractionDigits = sel_registerName("maximumFractionDigits");
        sel_maximumIntegerDigits = sel_registerName("maximumIntegerDigits");
        sel_menu = sel_registerName("menu");
        sel_menu_willHighlightItem_ = sel_registerName("menu:willHighlightItem:");
        sel_menuDidClose_ = sel_registerName("menuDidClose:");
        sel_menuForEvent_ = sel_registerName("menuForEvent:");
        sel_menuNeedsUpdate_ = sel_registerName("menuNeedsUpdate:");
        sel_menuWillOpen_ = sel_registerName("menuWillOpen:");
        sel_metaKey = sel_registerName("metaKey");
        sel_minValue = sel_registerName("minValue");
        sel_minimum = sel_registerName("minimum");
        sel_minimumSize = sel_registerName("minimumSize");
        sel_minuteOfHour = sel_registerName("minuteOfHour");
        sel_modifierFlags = sel_registerName("modifierFlags");
        sel_monthOfYear = sel_registerName("monthOfYear");
        sel_mouseDown_ = sel_registerName("mouseDown:");
        sel_mouseDragged_ = sel_registerName("mouseDragged:");
        sel_mouseEntered_ = sel_registerName("mouseEntered:");
        sel_mouseExited_ = sel_registerName("mouseExited:");
        sel_mouseLocation = sel_registerName("mouseLocation");
        sel_mouseLocationOutsideOfEventStream = sel_registerName("mouseLocationOutsideOfEventStream");
        sel_mouseMoved_ = sel_registerName("mouseMoved:");
        sel_mouseUp_ = sel_registerName("mouseUp:");
        sel_moveColumn_toColumn_ = sel_registerName("moveColumn:toColumn:");
        sel_moveToBeginningOfParagraph_ = sel_registerName("moveToBeginningOfParagraph:");
        sel_moveToEndOfParagraph_ = sel_registerName("moveToEndOfParagraph:");
        sel_moveToPoint_ = sel_registerName("moveToPoint:");
        sel_moveUp_ = sel_registerName("moveUp:");
        sel_mutableString = sel_registerName("mutableString");
        sel_name = sel_registerName("name");
        sel_namesOfPromisedFilesDroppedAtDestination_ = sel_registerName("namesOfPromisedFilesDroppedAtDestination:");
        sel_nextEventMatchingMask_untilDate_inMode_dequeue_ = sel_registerName("nextEventMatchingMask:untilDate:inMode:dequeue:");
        sel_nextObject = sel_registerName("nextObject");
        sel_nextWordFromIndex_forward_ = sel_registerName("nextWordFromIndex:forward:");
        sel_noteNumberOfRowsChanged = sel_registerName("noteNumberOfRowsChanged");
        sel_numberOfColumns = sel_registerName("numberOfColumns");
        sel_numberOfComponents = sel_registerName("numberOfComponents");
        sel_numberOfGlyphs = sel_registerName("numberOfGlyphs");
        sel_numberOfItems = sel_registerName("numberOfItems");
        sel_numberOfRows = sel_registerName("numberOfRows");
        sel_numberOfRowsInTableView_ = sel_registerName("numberOfRowsInTableView:");
        sel_numberOfSelectedRows = sel_registerName("numberOfSelectedRows");
        sel_numberOfVisibleItems = sel_registerName("numberOfVisibleItems");
        sel_numberWithBool_ = sel_registerName("numberWithBool:");
        sel_numberWithInt_ = sel_registerName("numberWithInt:");
        sel_numberWithInteger_ = sel_registerName("numberWithInteger:");
        sel_object = sel_registerName("object");
        sel_objectAtIndex_ = sel_registerName("objectAtIndex:");
        sel_objectEnumerator = sel_registerName("objectEnumerator");
        sel_objectForInfoDictionaryKey_ = sel_registerName("objectForInfoDictionaryKey:");
        sel_objectForKey_ = sel_registerName("objectForKey:");
        sel_openFile_withApplication_ = sel_registerName("openFile:withApplication:");
        sel_openGLContext = sel_registerName("openGLContext");
        sel_openPanel = sel_registerName("openPanel");
        sel_openURL_ = sel_registerName("openURL:");
        sel_openURLs_withAppBundleIdentifier_options_additionalEventParamDescriptor_launchIdentifiers_ = sel_registerName("openURLs:withAppBundleIdentifier:options:additionalEventParamDescriptor:launchIdentifiers:");
        sel_options = sel_registerName("options");
        sel_orderFront_ = sel_registerName("orderFront:");
        sel_orderFrontRegardless = sel_registerName("orderFrontRegardless");
        sel_orderFrontStandardAboutPanel_ = sel_registerName("orderFrontStandardAboutPanel:");
        sel_orderOut_ = sel_registerName("orderOut:");
        sel_orderedWindows = sel_registerName("orderedWindows");
        sel_otherEventWithType_location_modifierFlags_timestamp_windowNumber_context_subtype_data1_data2_ = sel_registerName("otherEventWithType:location:modifierFlags:timestamp:windowNumber:context:subtype:data1:data2:");
        sel_otherMouseDown_ = sel_registerName("otherMouseDown:");
        sel_otherMouseDragged_ = sel_registerName("otherMouseDragged:");
        sel_otherMouseUp_ = sel_registerName("otherMouseUp:");
        sel_outlineTableColumn = sel_registerName("outlineTableColumn");
        sel_outlineView_child_ofItem_ = sel_registerName("outlineView:child:ofItem:");
        sel_outlineView_didClickTableColumn_ = sel_registerName("outlineView:didClickTableColumn:");
        sel_outlineView_isItemExpandable_ = sel_registerName("outlineView:isItemExpandable:");
        sel_outlineView_numberOfChildrenOfItem_ = sel_registerName("outlineView:numberOfChildrenOfItem:");
        sel_outlineView_objectValueForTableColumn_byItem_ = sel_registerName("outlineView:objectValueForTableColumn:byItem:");
        sel_outlineView_setObjectValue_forTableColumn_byItem_ = sel_registerName("outlineView:setObjectValue:forTableColumn:byItem:");
        sel_outlineView_shouldCollapseItem_ = sel_registerName("outlineView:shouldCollapseItem:");
        sel_outlineView_shouldExpandItem_ = sel_registerName("outlineView:shouldExpandItem:");
        sel_outlineView_willDisplayCell_forTableColumn_item_ = sel_registerName("outlineView:willDisplayCell:forTableColumn:item:");
        sel_outlineViewColumnDidMove_ = sel_registerName("outlineViewColumnDidMove:");
        sel_outlineViewColumnDidResize_ = sel_registerName("outlineViewColumnDidResize:");
        sel_outlineViewItemDidExpand_ = sel_registerName("outlineViewItemDidExpand:");
        sel_outlineViewSelectionDidChange_ = sel_registerName("outlineViewSelectionDidChange:");
        sel_pageDown_ = sel_registerName("pageDown:");
        sel_pageTitle = sel_registerName("pageTitle");
        sel_pageUp_ = sel_registerName("pageUp:");
        sel_panelConvertFont_ = sel_registerName("panelConvertFont:");
        sel_paperSize = sel_registerName("paperSize");
        sel_paragraphs = sel_registerName("paragraphs");
        sel_paste_ = sel_registerName("paste:");
        sel_pasteboard_provideDataForType_ = sel_registerName("pasteboard:provideDataForType:");
        sel_pasteboardWithName_ = sel_registerName("pasteboardWithName:");
        sel_performDragOperation_ = sel_registerName("performDragOperation:");
        sel_performSelectorOnMainThread_withObject_waitUntilDone_ = sel_registerName("performSelectorOnMainThread:withObject:waitUntilDone:");
        sel_pixelsHigh = sel_registerName("pixelsHigh");
        sel_pixelsWide = sel_registerName("pixelsWide");
        sel_pointSize = sel_registerName("pointSize");
        sel_pointValue = sel_registerName("pointValue");
        sel_pointingHandCursor = sel_registerName("pointingHandCursor");
        sel_popUpContextMenu_withEvent_forView_ = sel_registerName("popUpContextMenu:withEvent:forView:");
        sel_prependTransform_ = sel_registerName("prependTransform:");
        sel_preventDefault = sel_registerName("preventDefault");
        sel_printDocumentView = sel_registerName("printDocumentView");
        sel_printOperationWithPrintInfo_ = sel_registerName("printOperationWithPrintInfo:");
        sel_printOperationWithView_printInfo_ = sel_registerName("printOperationWithView:printInfo:");
        sel_printPanel = sel_registerName("printPanel");
        sel_printer = sel_registerName("printer");
        sel_printerNames = sel_registerName("printerNames");
        sel_printerWithName_ = sel_registerName("printerWithName:");
        sel_propertyListForType_ = sel_registerName("propertyListForType:");
        sel_rangeValue = sel_registerName("rangeValue");
        sel_recentSearches = sel_registerName("recentSearches");
        sel_rectOfColumn_ = sel_registerName("rectOfColumn:");
        sel_rectOfRow_ = sel_registerName("rectOfRow:");
        sel_redComponent = sel_registerName("redComponent");
        sel_reflectScrolledClipView_ = sel_registerName("reflectScrolledClipView:");
        sel_registerForDraggedTypes_ = sel_registerName("registerForDraggedTypes:");
        sel_release = sel_registerName("release");
        sel_reload_ = sel_registerName("reload:");
        sel_reloadData = sel_registerName("reloadData");
        sel_reloadItem_ = sel_registerName("reloadItem:");
        sel_reloadItem_reloadChildren_ = sel_registerName("reloadItem:reloadChildren:");
        sel_removeAllItems = sel_registerName("removeAllItems");
        sel_removeAllPoints = sel_registerName("removeAllPoints");
        sel_removeFromSuperview = sel_registerName("removeFromSuperview");
        sel_removeItem_ = sel_registerName("removeItem:");
        sel_removeItemAtIndex_ = sel_registerName("removeItemAtIndex:");
        sel_removeItemAtPath_error_ = sel_registerName("removeItemAtPath:error:");
        sel_removeObject_ = sel_registerName("removeObject:");
        sel_removeObjectAtIndex_ = sel_registerName("removeObjectAtIndex:");
        sel_removeObserver_ = sel_registerName("removeObserver:");
        sel_removeStatusItem_ = sel_registerName("removeStatusItem:");
        sel_removeTabViewItem_ = sel_registerName("removeTabViewItem:");
        sel_removeTableColumn_ = sel_registerName("removeTableColumn:");
        sel_removeTemporaryAttribute_forCharacterRange_ = sel_registerName("removeTemporaryAttribute:forCharacterRange:");
        sel_replaceCharactersInRange_withString_ = sel_registerName("replaceCharactersInRange:withString:");
        sel_representation = sel_registerName("representation");
        sel_request = sel_registerName("request");
        sel_requestWithURL_ = sel_registerName("requestWithURL:");
        sel_resignFirstResponder = sel_registerName("resignFirstResponder");
        sel_resizeDownCursor = sel_registerName("resizeDownCursor");
        sel_resizeLeftCursor = sel_registerName("resizeLeftCursor");
        sel_resizeLeftRightCursor = sel_registerName("resizeLeftRightCursor");
        sel_resizeRightCursor = sel_registerName("resizeRightCursor");
        sel_resizeUpCursor = sel_registerName("resizeUpCursor");
        sel_resizeUpDownCursor = sel_registerName("resizeUpDownCursor");
        sel_resizingMask = sel_registerName("resizingMask");
        sel_respondsToSelector_ = sel_registerName("respondsToSelector:");
        sel_restoreGraphicsState = sel_registerName("restoreGraphicsState");
        sel_retain = sel_registerName("retain");
        sel_retainCount = sel_registerName("retainCount");
        sel_rightMouseDown_ = sel_registerName("rightMouseDown:");
        sel_rightMouseDragged_ = sel_registerName("rightMouseDragged:");
        sel_rightMouseUp_ = sel_registerName("rightMouseUp:");
        sel_rotateByDegrees_ = sel_registerName("rotateByDegrees:");
        sel_rowAtPoint_ = sel_registerName("rowAtPoint:");
        sel_rowForItem_ = sel_registerName("rowForItem:");
        sel_rowHeight = sel_registerName("rowHeight");
        sel_rowsInRect_ = sel_registerName("rowsInRect:");
        sel_run = sel_registerName("run");
        sel_runModal = sel_registerName("runModal");
        sel_runModalForWindow_ = sel_registerName("runModalForWindow:");
        sel_runModalWithPrintInfo_ = sel_registerName("runModalWithPrintInfo:");
        sel_runMode_beforeDate_ = sel_registerName("runMode:beforeDate:");
        sel_runOperation = sel_registerName("runOperation");
        sel_samplesPerPixel = sel_registerName("samplesPerPixel");
        sel_saveGraphicsState = sel_registerName("saveGraphicsState");
        sel_savePanel = sel_registerName("savePanel");
        sel_scaleXBy_yBy_ = sel_registerName("scaleXBy:yBy:");
        sel_scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_ = sel_registerName("scheduledTimerWithTimeInterval:target:selector:userInfo:repeats:");
        sel_screen = sel_registerName("screen");
        sel_screens = sel_registerName("screens");
        sel_scrollColumnToVisible_ = sel_registerName("scrollColumnToVisible:");
        sel_scrollRangeToVisible_ = sel_registerName("scrollRangeToVisible:");
        sel_scrollRectToVisible_ = sel_registerName("scrollRectToVisible:");
        sel_scrollRowToVisible_ = sel_registerName("scrollRowToVisible:");
        sel_scrollToPoint_ = sel_registerName("scrollToPoint:");
        sel_scrollWheel_ = sel_registerName("scrollWheel:");
        sel_scrollerWidth = sel_registerName("scrollerWidth");
        sel_secondOfMinute = sel_registerName("secondOfMinute");
        sel_secondarySelectedControlColor = sel_registerName("secondarySelectedControlColor");
        sel_selectAll_ = sel_registerName("selectAll:");
        sel_selectItem_ = sel_registerName("selectItem:");
        sel_selectItemAtIndex_ = sel_registerName("selectItemAtIndex:");
        sel_selectRow_byExtendingSelection_ = sel_registerName("selectRow:byExtendingSelection:");
        sel_selectRowIndexes_byExtendingSelection_ = sel_registerName("selectRowIndexes:byExtendingSelection:");
        sel_selectTabViewItemAtIndex_ = sel_registerName("selectTabViewItemAtIndex:");
        sel_selectedControlTextColor = sel_registerName("selectedControlTextColor");
        sel_selectedRange = sel_registerName("selectedRange");
        sel_selectedRow = sel_registerName("selectedRow");
        sel_selectedRowIndexes = sel_registerName("selectedRowIndexes");
        sel_selectedTabViewItem = sel_registerName("selectedTabViewItem");
        sel_selectedTextBackgroundColor = sel_registerName("selectedTextBackgroundColor");
        sel_selectedTextColor = sel_registerName("selectedTextColor");
        sel_sendAction_to_ = sel_registerName("sendAction:to:");
        sel_sendEvent_ = sel_registerName("sendEvent:");
        sel_separatorItem = sel_registerName("separatorItem");
        sel_set = sel_registerName("set");
        sel_setAcceptsMouseMovedEvents_ = sel_registerName("setAcceptsMouseMovedEvents:");
        sel_setAction_ = sel_registerName("setAction:");
        sel_setAlertStyle_ = sel_registerName("setAlertStyle:");
        sel_setAlignment_ = sel_registerName("setAlignment:");
        sel_setAllowsColumnReordering_ = sel_registerName("setAllowsColumnReordering:");
        sel_setAllowsFloats_ = sel_registerName("setAllowsFloats:");
        sel_setAllowsMixedState_ = sel_registerName("setAllowsMixedState:");
        sel_setAllowsMultipleSelection_ = sel_registerName("setAllowsMultipleSelection:");
        sel_setAlphaValue_ = sel_registerName("setAlphaValue:");
        sel_setApplicationIconImage_ = sel_registerName("setApplicationIconImage:");
        sel_setApplicationNameForUserAgent_ = sel_registerName("setApplicationNameForUserAgent:");
        sel_setAttributedStringValue_ = sel_registerName("setAttributedStringValue:");
        sel_setAttributedTitle_ = sel_registerName("setAttributedTitle:");
        sel_setAutoenablesItems_ = sel_registerName("setAutoenablesItems:");
        sel_setAutohidesScrollers_ = sel_registerName("setAutohidesScrollers:");
        sel_setAutoresizesOutlineColumn_ = sel_registerName("setAutoresizesOutlineColumn:");
        sel_setAutoresizesSubviews_ = sel_registerName("setAutoresizesSubviews:");
        sel_setAutoresizingMask_ = sel_registerName("setAutoresizingMask:");
        sel_setAutosaveExpandedItems_ = sel_registerName("setAutosaveExpandedItems:");
        sel_setBackgroundColor_ = sel_registerName("setBackgroundColor:");
        sel_setBezelStyle_ = sel_registerName("setBezelStyle:");
        sel_setBorderType_ = sel_registerName("setBorderType:");
        sel_setBorderWidth_ = sel_registerName("setBorderWidth:");
        sel_setBordered_ = sel_registerName("setBordered:");
        sel_setBoxType_ = sel_registerName("setBoxType:");
        sel_setButtonType_ = sel_registerName("setButtonType:");
        sel_setCacheMode_ = sel_registerName("setCacheMode:");
        sel_setCanChooseDirectories_ = sel_registerName("setCanChooseDirectories:");
        sel_setCanChooseFiles_ = sel_registerName("setCanChooseFiles:");
        sel_setCellClass_ = sel_registerName("setCellClass:");
        sel_setClip = sel_registerName("setClip");
        sel_setColor_ = sel_registerName("setColor:");
        sel_setColumnAutoresizingStyle_ = sel_registerName("setColumnAutoresizingStyle:");
        sel_setCompositingOperation_ = sel_registerName("setCompositingOperation:");
        sel_setContainerSize_ = sel_registerName("setContainerSize:");
        sel_setContentView_ = sel_registerName("setContentView:");
        sel_setContentViewMargins_ = sel_registerName("setContentViewMargins:");
        sel_setCurrentContext_ = sel_registerName("setCurrentContext:");
        sel_setCurrentOperation_ = sel_registerName("setCurrentOperation:");
        sel_setData_forType_ = sel_registerName("setData:forType:");
        sel_setDataCell_ = sel_registerName("setDataCell:");
        sel_setDataSource_ = sel_registerName("setDataSource:");
        sel_setDatePickerElements_ = sel_registerName("setDatePickerElements:");
        sel_setDatePickerStyle_ = sel_registerName("setDatePickerStyle:");
        sel_setDateValue_ = sel_registerName("setDateValue:");
        sel_setDefaultFlatness_ = sel_registerName("setDefaultFlatness:");
        sel_setDefaultTabInterval_ = sel_registerName("setDefaultTabInterval:");
        sel_setDelegate_ = sel_registerName("setDelegate:");
        sel_setDestination_allowOverwrite_ = sel_registerName("setDestination:allowOverwrite:");
        sel_setDirectory_ = sel_registerName("setDirectory:");
        sel_setDocumentView_ = sel_registerName("setDocumentView:");
        sel_setDoubleAction_ = sel_registerName("setDoubleAction:");
        sel_setDoubleValue_ = sel_registerName("setDoubleValue:");
        sel_setDownloadDelegate_ = sel_registerName("setDownloadDelegate:");
        sel_setDrawsBackground_ = sel_registerName("setDrawsBackground:");
        sel_setEditable_ = sel_registerName("setEditable:");
        sel_setEnabled_ = sel_registerName("setEnabled:");
        sel_setFill = sel_registerName("setFill");
        sel_setFireDate_ = sel_registerName("setFireDate:");
        sel_setFirstLineHeadIndent_ = sel_registerName("setFirstLineHeadIndent:");
        sel_setFloatValue_knobProportion_ = sel_registerName("setFloatValue:knobProportion:");
        sel_setFocusRingType_ = sel_registerName("setFocusRingType:");
        sel_setFont_ = sel_registerName("setFont:");
        sel_setFormatter_ = sel_registerName("setFormatter:");
        sel_setFrame_ = sel_registerName("setFrame:");
        sel_setFrame_display_ = sel_registerName("setFrame:display:");
        sel_setFrameLoadDelegate_ = sel_registerName("setFrameLoadDelegate:");
        sel_setFrameOrigin_ = sel_registerName("setFrameOrigin:");
        sel_setFrameSize_ = sel_registerName("setFrameSize:");
        sel_setHasHorizontalScroller_ = sel_registerName("setHasHorizontalScroller:");
        sel_setHasShadow_ = sel_registerName("setHasShadow:");
        sel_setHasVerticalScroller_ = sel_registerName("setHasVerticalScroller:");
        sel_setHeaderCell_ = sel_registerName("setHeaderCell:");
        sel_setHeaderView_ = sel_registerName("setHeaderView:");
        sel_setHidden_ = sel_registerName("setHidden:");
        sel_setHiddenUntilMouseMoves_ = sel_registerName("setHiddenUntilMouseMoves:");
        sel_setHighlightMode_ = sel_registerName("setHighlightMode:");
        sel_setHighlighted_ = sel_registerName("setHighlighted:");
        sel_setHorizontalScroller_ = sel_registerName("setHorizontalScroller:");
        sel_setHorizontallyResizable_ = sel_registerName("setHorizontallyResizable:");
        sel_setIdentifier_ = sel_registerName("setIdentifier:");
        sel_setImage_ = sel_registerName("setImage:");
        sel_setImageAlignment_ = sel_registerName("setImageAlignment:");
        sel_setImageInterpolation_ = sel_registerName("setImageInterpolation:");
        sel_setImagePosition_ = sel_registerName("setImagePosition:");
        sel_setImageScaling_ = sel_registerName("setImageScaling:");
        sel_setIncrement_ = sel_registerName("setIncrement:");
        sel_setIndentationPerLevel_ = sel_registerName("setIndentationPerLevel:");
        sel_setIndeterminate_ = sel_registerName("setIndeterminate:");
        sel_setJavaEnabled_ = sel_registerName("setJavaEnabled:");
        sel_setJobDisposition_ = sel_registerName("setJobDisposition:");
        sel_setJobTitle_ = sel_registerName("setJobTitle:");
        sel_setKeyEquivalent_ = sel_registerName("setKeyEquivalent:");
        sel_setKeyEquivalentModifierMask_ = sel_registerName("setKeyEquivalentModifierMask:");
        sel_setLabel_ = sel_registerName("setLabel:");
        sel_setLeaf_ = sel_registerName("setLeaf:");
        sel_setLength_ = sel_registerName("setLength:");
        sel_setLevel_ = sel_registerName("setLevel:");
        sel_setLineBreakMode_ = sel_registerName("setLineBreakMode:");
        sel_setLineCapStyle_ = sel_registerName("setLineCapStyle:");
        sel_setLineDash_count_phase_ = sel_registerName("setLineDash:count:phase:");
        sel_setLineFragmentPadding_ = sel_registerName("setLineFragmentPadding:");
        sel_setLineFragmentRect_forGlyphRange_usedRect_ = sel_registerName("setLineFragmentRect:forGlyphRange:usedRect:");
        sel_setLineJoinStyle_ = sel_registerName("setLineJoinStyle:");
        sel_setLineSpacing_ = sel_registerName("setLineSpacing:");
        sel_setLineWidth_ = sel_registerName("setLineWidth:");
        sel_setMarkedText_selectedRange_ = sel_registerName("setMarkedText:selectedRange:");
        sel_setMaxSize_ = sel_registerName("setMaxSize:");
        sel_setMaxValue_ = sel_registerName("setMaxValue:");
        sel_setMaximum_ = sel_registerName("setMaximum:");
        sel_setMaximumFractionDigits_ = sel_registerName("setMaximumFractionDigits:");
        sel_setMaximumIntegerDigits_ = sel_registerName("setMaximumIntegerDigits:");
        sel_setMenu_ = sel_registerName("setMenu:");
        sel_setMinSize_ = sel_registerName("setMinSize:");
        sel_setMinValue_ = sel_registerName("setMinValue:");
        sel_setMinWidth_ = sel_registerName("setMinWidth:");
        sel_setMinimum_ = sel_registerName("setMinimum:");
        sel_setMinimumFractionDigits_ = sel_registerName("setMinimumFractionDigits:");
        sel_setMinimumIntegerDigits_ = sel_registerName("setMinimumIntegerDigits:");
        sel_setMiterLimit_ = sel_registerName("setMiterLimit:");
        sel_setNeedsDisplay_ = sel_registerName("setNeedsDisplay:");
        sel_setNeedsDisplayInRect_ = sel_registerName("setNeedsDisplayInRect:");
        sel_setNumberOfVisibleItems_ = sel_registerName("setNumberOfVisibleItems:");
        sel_setNumberStyle_ = sel_registerName("setNumberStyle:");
        sel_setObject_forKey_ = sel_registerName("setObject:forKey:");
        sel_setOnMouseEntered_ = sel_registerName("setOnMouseEntered:");
        sel_setOpaque_ = sel_registerName("setOpaque:");
        sel_setOptions_ = sel_registerName("setOptions:");
        sel_setOutlineTableColumn_ = sel_registerName("setOutlineTableColumn:");
        sel_setPanelFont_isMultiple_ = sel_registerName("setPanelFont:isMultiple:");
        sel_setPartialStringValidationEnabled_ = sel_registerName("setPartialStringValidationEnabled:");
        sel_setPatternPhase_ = sel_registerName("setPatternPhase:");
        sel_setPixelFormat_ = sel_registerName("setPixelFormat:");
        sel_setPolicyDelegate_ = sel_registerName("setPolicyDelegate:");
        sel_setPrinter_ = sel_registerName("setPrinter:");
        sel_setPropertyList_forType_ = sel_registerName("setPropertyList:forType:");
        sel_setPullsDown_ = sel_registerName("setPullsDown:");
        sel_setReleasedWhenClosed_ = sel_registerName("setReleasedWhenClosed:");
        sel_setResizingMask_ = sel_registerName("setResizingMask:");
        sel_setResourceLoadDelegate_ = sel_registerName("setResourceLoadDelegate:");
        sel_setRichText_ = sel_registerName("setRichText:");
        sel_setRowHeight_ = sel_registerName("setRowHeight:");
        sel_setSelectable_ = sel_registerName("setSelectable:");
        sel_setSelectedRange_ = sel_registerName("setSelectedRange:");
        sel_setShouldAntialias_ = sel_registerName("setShouldAntialias:");
        sel_setShowsPrintPanel_ = sel_registerName("setShowsPrintPanel:");
        sel_setShowsProgressPanel_ = sel_registerName("setShowsProgressPanel:");
        sel_setSize_ = sel_registerName("setSize:");
        sel_setState_ = sel_registerName("setState:");
        sel_setString_ = sel_registerName("setString:");
        sel_setString_forType_ = sel_registerName("setString:forType:");
        sel_setStringValue_ = sel_registerName("setStringValue:");
        sel_setStroke = sel_registerName("setStroke");
        sel_setSubmenu_ = sel_registerName("setSubmenu:");
        sel_setTabStops_ = sel_registerName("setTabStops:");
        sel_setTabViewType_ = sel_registerName("setTabViewType:");
        sel_setTarget_ = sel_registerName("setTarget:");
        sel_setTextColor_ = sel_registerName("setTextColor:");
        sel_setTitle_ = sel_registerName("setTitle:");
        sel_setTitleFont_ = sel_registerName("setTitleFont:");
        sel_setTitlePosition_ = sel_registerName("setTitlePosition:");
        sel_setToolTip_ = sel_registerName("setToolTip:");
        sel_setTransformStruct_ = sel_registerName("setTransformStruct:");
        sel_setUIDelegate_ = sel_registerName("setUIDelegate:");
        sel_setURL_ = sel_registerName("setURL:");
        sel_setUpPrintOperationDefaultValues = sel_registerName("setUpPrintOperationDefaultValues");
        sel_setUsesAlternatingRowBackgroundColors_ = sel_registerName("setUsesAlternatingRowBackgroundColors:");
        sel_setUsesThreadedAnimation_ = sel_registerName("setUsesThreadedAnimation:");
        sel_setValue_forKey_ = sel_registerName("setValue:forKey:");
        sel_setValueWraps_ = sel_registerName("setValueWraps:");
        sel_setVerticalScroller_ = sel_registerName("setVerticalScroller:");
        sel_setView_ = sel_registerName("setView:");
        sel_setWidth_ = sel_registerName("setWidth:");
        sel_setWidthTracksTextView_ = sel_registerName("setWidthTracksTextView:");
        sel_setWindingRule_ = sel_registerName("setWindingRule:");
        sel_setWorksWhenModal_ = sel_registerName("setWorksWhenModal:");
        sel_setWraps_ = sel_registerName("setWraps:");
        sel_sharedApplication = sel_registerName("sharedApplication");
        sel_sharedColorPanel = sel_registerName("sharedColorPanel");
        sel_sharedFontManager = sel_registerName("sharedFontManager");
        sel_sharedFontPanel = sel_registerName("sharedFontPanel");
        sel_sharedHTTPCookieStorage = sel_registerName("sharedHTTPCookieStorage");
        sel_sharedPrintInfo = sel_registerName("sharedPrintInfo");
        sel_sharedWorkspace = sel_registerName("sharedWorkspace");
        sel_shiftKey = sel_registerName("shiftKey");
        sel_size = sel_registerName("size");
        sel_sizeToFit = sel_registerName("sizeToFit");
        sel_sizeValue = sel_registerName("sizeValue");
        sel_skipDescendents = sel_registerName("skipDescendents");
        sel_smallSystemFontSize = sel_registerName("smallSystemFontSize");
        sel_sortIndicatorRectForBounds_ = sel_registerName("sortIndicatorRectForBounds:");
        sel_standardPreferences = sel_registerName("standardPreferences");
        sel_startAnimation_ = sel_registerName("startAnimation:");
        sel_state = sel_registerName("state");
        sel_statusItemWithLength_ = sel_registerName("statusItemWithLength:");
        sel_stop_ = sel_registerName("stop:");
        sel_stopLoading_ = sel_registerName("stopLoading:");
        sel_string = sel_registerName("string");
        sel_stringByAddingPercentEscapesUsingEncoding_ = sel_registerName("stringByAddingPercentEscapesUsingEncoding:");
        sel_stringByAppendingPathComponent_ = sel_registerName("stringByAppendingPathComponent:");
        sel_stringByAppendingString_ = sel_registerName("stringByAppendingString:");
        sel_stringByDeletingLastPathComponent = sel_registerName("stringByDeletingLastPathComponent");
        sel_stringByDeletingPathExtension = sel_registerName("stringByDeletingPathExtension");
        sel_stringByEvaluatingJavaScriptFromString_ = sel_registerName("stringByEvaluatingJavaScriptFromString:");
        sel_stringByReplacingOccurrencesOfString_withString_ = sel_registerName("stringByReplacingOccurrencesOfString:withString:");
        sel_stringForObjectValue_ = sel_registerName("stringForObjectValue:");
        sel_stringForType_ = sel_registerName("stringForType:");
        sel_stringValue = sel_registerName("stringValue");
        sel_stringWithCharacters_length_ = sel_registerName("stringWithCharacters:length:");
        sel_stringWithUTF8String_ = sel_registerName("stringWithUTF8String:");
        sel_stroke = sel_registerName("stroke");
        sel_strokeRect_ = sel_registerName("strokeRect:");
        sel_styleMask = sel_registerName("styleMask");
        sel_submenu = sel_registerName("submenu");
        sel_subviews = sel_registerName("subviews");
        sel_superclass = sel_registerName("superclass");
        sel_superview = sel_registerName("superview");
        sel_systemFontOfSize_ = sel_registerName("systemFontOfSize:");
        sel_systemFontSize = sel_registerName("systemFontSize");
        sel_systemFontSizeForControlSize_ = sel_registerName("systemFontSizeForControlSize:");
        sel_systemStatusBar = sel_registerName("systemStatusBar");
        sel_systemVersion = sel_registerName("systemVersion");
        sel_tabStopType = sel_registerName("tabStopType");
        sel_tabStops = sel_registerName("tabStops");
        sel_tabView_didSelectTabViewItem_ = sel_registerName("tabView:didSelectTabViewItem:");
        sel_tabView_willSelectTabViewItem_ = sel_registerName("tabView:willSelectTabViewItem:");
        sel_tabViewItemAtPoint_ = sel_registerName("tabViewItemAtPoint:");
        sel_tableColumns = sel_registerName("tableColumns");
        sel_tableView_didClickTableColumn_ = sel_registerName("tableView:didClickTableColumn:");
        sel_tableView_objectValueForTableColumn_row_ = sel_registerName("tableView:objectValueForTableColumn:row:");
        sel_tableView_setObjectValue_forTableColumn_row_ = sel_registerName("tableView:setObjectValue:forTableColumn:row:");
        sel_tableView_shouldEditTableColumn_row_ = sel_registerName("tableView:shouldEditTableColumn:row:");
        sel_tableView_willDisplayCell_forTableColumn_row_ = sel_registerName("tableView:willDisplayCell:forTableColumn:row:");
        sel_tableViewColumnDidMove_ = sel_registerName("tableViewColumnDidMove:");
        sel_tableViewColumnDidResize_ = sel_registerName("tableViewColumnDidResize:");
        sel_tableViewSelectionDidChange_ = sel_registerName("tableViewSelectionDidChange:");
        sel_target = sel_registerName("target");
        sel_terminate_ = sel_registerName("terminate:");
        sel_textBackgroundColor = sel_registerName("textBackgroundColor");
        sel_textColor = sel_registerName("textColor");
        sel_textContainer = sel_registerName("textContainer");
        sel_textDidChange_ = sel_registerName("textDidChange:");
        sel_textStorage = sel_registerName("textStorage");
        sel_textView_clickedOnLink_atIndex_ = sel_registerName("textView:clickedOnLink:atIndex:");
        sel_textView_willChangeSelectionFromCharacterRange_toCharacterRange_ = sel_registerName("textView:willChangeSelectionFromCharacterRange:toCharacterRange:");
        sel_textViewDidChangeSelection_ = sel_registerName("textViewDidChangeSelection:");
        sel_threadDictionary = sel_registerName("threadDictionary");
        sel_tile = sel_registerName("tile");
        sel_timeZone = sel_registerName("timeZone");
        sel_title = sel_registerName("title");
        sel_titleCell = sel_registerName("titleCell");
        sel_titleOfSelectedItem = sel_registerName("titleOfSelectedItem");
        sel_titleRectForBounds_ = sel_registerName("titleRectForBounds:");
        sel_transform = sel_registerName("transform");
        sel_transformPoint_ = sel_registerName("transformPoint:");
        sel_transformSize_ = sel_registerName("transformSize:");
        sel_transformStruct = sel_registerName("transformStruct");
        sel_transformUsingAffineTransform_ = sel_registerName("transformUsingAffineTransform:");
        sel_translateXBy_yBy_ = sel_registerName("translateXBy:yBy:");
        sel_type = sel_registerName("type");
        sel_types = sel_registerName("types");
        sel_typesetter = sel_registerName("typesetter");
        sel_unarchiveObjectWithData_ = sel_registerName("unarchiveObjectWithData:");
        sel_unhideAllApplications_ = sel_registerName("unhideAllApplications:");
        sel_unmarkText = sel_registerName("unmarkText");
        sel_unregisterDraggedTypes = sel_registerName("unregisterDraggedTypes");
        sel_use = sel_registerName("use");
        sel_usedRectForTextContainer_ = sel_registerName("usedRectForTextContainer:");
        sel_userInfo = sel_registerName("userInfo");
        sel_usesAlternatingRowBackgroundColors = sel_registerName("usesAlternatingRowBackgroundColors");
        sel_validAttributesForMarkedText = sel_registerName("validAttributesForMarkedText");
        sel_valueForKey_ = sel_registerName("valueForKey:");
        sel_valueWithPoint_ = sel_registerName("valueWithPoint:");
        sel_valueWithRange_ = sel_registerName("valueWithRange:");
        sel_valueWithRect_ = sel_registerName("valueWithRect:");
        sel_valueWithSize_ = sel_registerName("valueWithSize:");
        sel_visibleFrame = sel_registerName("visibleFrame");
        sel_visibleRect = sel_registerName("visibleRect");
        sel_wantsPeriodicDraggingUpdates = sel_registerName("wantsPeriodicDraggingUpdates");
        sel_wantsToHandleMouseEvents = sel_registerName("wantsToHandleMouseEvents");
        sel_webFrame = sel_registerName("webFrame");
        sel_webView_contextMenuItemsForElement_defaultMenuItems_ = sel_registerName("webView:contextMenuItemsForElement:defaultMenuItems:");
        sel_webView_createWebViewWithRequest_ = sel_registerName("webView:createWebViewWithRequest:");
        sel_webView_decidePolicyForMIMEType_request_frame_decisionListener_ = sel_registerName("webView:decidePolicyForMIMEType:request:frame:decisionListener:");
        sel_webView_decidePolicyForNavigationAction_request_frame_decisionListener_ = sel_registerName("webView:decidePolicyForNavigationAction:request:frame:decisionListener:");
        sel_webView_decidePolicyForNewWindowAction_request_newFrameName_decisionListener_ = sel_registerName("webView:decidePolicyForNewWindowAction:request:newFrameName:decisionListener:");
        sel_webView_didChangeLocationWithinPageForFrame_ = sel_registerName("webView:didChangeLocationWithinPageForFrame:");
        sel_webView_didCommitLoadForFrame_ = sel_registerName("webView:didCommitLoadForFrame:");
        sel_webView_didFailProvisionalLoadWithError_forFrame_ = sel_registerName("webView:didFailProvisionalLoadWithError:forFrame:");
        sel_webView_didFinishLoadForFrame_ = sel_registerName("webView:didFinishLoadForFrame:");
        sel_webView_didReceiveTitle_forFrame_ = sel_registerName("webView:didReceiveTitle:forFrame:");
        sel_webView_didStartProvisionalLoadForFrame_ = sel_registerName("webView:didStartProvisionalLoadForFrame:");
        sel_webView_identifierForInitialRequest_fromDataSource_ = sel_registerName("webView:identifierForInitialRequest:fromDataSource:");
        sel_webView_mouseDidMoveOverElement_modifierFlags_ = sel_registerName("webView:mouseDidMoveOverElement:modifierFlags:");
        sel_webView_printFrameView_ = sel_registerName("webView:printFrameView:");
        sel_webView_resource_didFailLoadingWithError_fromDataSource_ = sel_registerName("webView:resource:didFailLoadingWithError:fromDataSource:");
        sel_webView_resource_didFinishLoadingFromDataSource_ = sel_registerName("webView:resource:didFinishLoadingFromDataSource:");
        sel_webView_resource_willSendRequest_redirectResponse_fromDataSource_ = sel_registerName("webView:resource:willSendRequest:redirectResponse:fromDataSource:");
        sel_webView_runJavaScriptAlertPanelWithMessage_ = sel_registerName("webView:runJavaScriptAlertPanelWithMessage:");
        sel_webView_runJavaScriptConfirmPanelWithMessage_ = sel_registerName("webView:runJavaScriptConfirmPanelWithMessage:");
        sel_webView_runOpenPanelForFileButtonWithResultListener_ = sel_registerName("webView:runOpenPanelForFileButtonWithResultListener:");
        sel_webView_setFrame_ = sel_registerName("webView:setFrame:");
        sel_webView_setResizable_ = sel_registerName("webView:setResizable:");
        sel_webView_setStatusBarVisible_ = sel_registerName("webView:setStatusBarVisible:");
        sel_webView_setStatusText_ = sel_registerName("webView:setStatusText:");
        sel_webView_setToolbarsVisible_ = sel_registerName("webView:setToolbarsVisible:");
        sel_webView_unableToImplementPolicyWithError_frame_ = sel_registerName("webView:unableToImplementPolicyWithError:frame:");
        sel_webViewClose_ = sel_registerName("webViewClose:");
        sel_webViewFocus_ = sel_registerName("webViewFocus:");
        sel_webViewShow_ = sel_registerName("webViewShow:");
        sel_webViewUnfocus_ = sel_registerName("webViewUnfocus:");
        sel_wheelDelta = sel_registerName("wheelDelta");
        sel_width = sel_registerName("width");
        sel_window = sel_registerName("window");
        sel_windowBackgroundColor = sel_registerName("windowBackgroundColor");
        sel_windowDidBecomeKey_ = sel_registerName("windowDidBecomeKey:");
        sel_windowDidMove_ = sel_registerName("windowDidMove:");
        sel_windowDidResignKey_ = sel_registerName("windowDidResignKey:");
        sel_windowDidResize_ = sel_registerName("windowDidResize:");
        sel_windowFrameColor = sel_registerName("windowFrameColor");
        sel_windowFrameTextColor = sel_registerName("windowFrameTextColor");
        sel_windowNumber = sel_registerName("windowNumber");
        sel_windowShouldClose_ = sel_registerName("windowShouldClose:");
        sel_windowWillClose_ = sel_registerName("windowWillClose:");
        sel_windows = sel_registerName("windows");
        sel_worksWhenModal = sel_registerName("worksWhenModal");
        sel_wraps = sel_registerName("wraps");
        sel_writeToPasteboard_ = sel_registerName("writeToPasteboard:");
        sel_yearOfCommonEra = sel_registerName("yearOfCommonEra");
    }
    
	public static const int gestaltSystemVersion = ('s'<<24) + ('y'<<16) + ('s'<<8) + 'v';
	public static const int noErr = 0;
	public static const int kProcessTransformToForegroundApplication = 1;
	public static const int kAlertCautionIcon = ('c'<<24) + ('a'<<16) + ('u'<<8) + 't';
	public static const int kAlertNoteIcon = ('n'<<24) + ('o'<<16) + ('t'<<8) + 'e';
	public static const int kAlertStopIcon = ('s'<<24) + ('t'<<16) + ('o'<<8) + 'p';
        
    public static const objc.SEL sel_sendSelection;
    public static const objc.SEL sel_sendDoubleSelection;
    public static const objc.SEL sel_sendVerticalSelection;
    public static const objc.SEL sel_sendHorizontalSelection;
    public static const objc.SEL sel_timerProc_;
    public static const objc.SEL sel_handleNotification_;
    
    static this ()
    {
        
    }

/** JNI natives */

/** @method flags=jni */
static char* NewGlobalRef (Object object)
{
    return cast(char*) object;
}
/**
 * @method flags=jni
 * @param globalRef cast=(jobject)
 */
//public static final native void DeleteGlobalRef(int /*long*/ globalRef);
/** @method flags=no_gen */
static Object JNIGetObject (char* globalRef)
{
    return cast(Object) globalRef;
}

/** Carbon calls */

alias Carbon.Gestalt Gestalt;
/** @param psn cast=(ProcessSerialNumber *) */
alias Carbon.GetCurrentProcess GetCurrentProcess;
/** @param psn cast=(ProcessSerialNumber *) */
alias Carbon.SetFrontProcess SetFrontProcess;
/** @param psn cast=(ProcessSerialNumber *) */
alias Carbon.TransformProcessType TransformProcessType;
alias Carbon.CPSSetProcessName CPSSetProcessName;
/** @method flags=dynamic */
alias Carbon.SetThemeCursor SetThemeCursor;
/** @method flags=dynamic */
alias Carbon.GetCurrentButtonState GetCurrentButtonState;

alias Carbon.ThemeCursor ThemeCursor;

public static const ThemeCursor kThemeCopyArrowCursor = ThemeCursor.kThemeCopyArrowCursor;
public static const ThemeCursor kThemeNotAllowedCursor = ThemeCursor.kThemeNotAllowedCursor;
public static const ThemeCursor kThemeAliasArrowCursor = ThemeCursor.kThemeAliasArrowCursor;

/** C calls */

alias unistd.getpid getpid;

/** QuickDraw calls */

/** @method flags=dynamic */
alias Carbon.NewRgn NewRgn;
/** @method flags=dynamic */
alias Carbon.RectRgn RectRgn;
/** @method flags=dynamic */
alias Carbon.OpenRgn OpenRgn;
/** @method flags=dynamic */
alias Carbon.OffsetRgn OffsetRgn;
/** @method flags=dynamic */
alias Carbon.MoveTo MoveTo;
/** @method flags=dynamic */
alias Carbon.LineTo LineTo;
/** @method flags=dynamic */
alias Carbon.UnionRgn UnionRgn;
/** @method flags=dynamic */
alias Carbon.CloseRgn CloseRgn;
/** @method flags=dynamic */
alias Carbon.DisposeRgn DisposeRgn;
/** @method flags=dynamic */
alias Carbon.PtInRgn PtInRgn;
/** @method flags=dynamic */
alias Carbon.GetRegionBounds GetRegionBounds;
/** @method flags=dynamic */
alias Carbon.SectRgn SectRgn;
/** @method flags=dynamic */
alias Carbon.EmptyRgn EmptyRgn;
/** @method flags=dynamic */
alias Carbon.DiffRgn DiffRgn;
/** @method flags=dynamic */
alias Carbon.RectInRgn RectInRgn;
/** @method flags=dynamic */
alias Carbon.QDRegionToRects QDRegionToRects;
/** @method flags=dynamic */
alias Carbon.CopyRgn CopyRgn;
/** @method flags=dynamic */
alias Carbon.SetRect SetRect;
public static const int kQDParseRegionFromTop = (1 << 0);
public static const int kQDParseRegionFromBottom = (1 << 1);
public static const int kQDParseRegionFromLeft = (1 << 2);
public static const int kQDParseRegionFromRight = (1 << 3);
public static const int kQDParseRegionFromTopLeft = kQDParseRegionFromTop | kQDParseRegionFromLeft;
public static const int kQDRegionToRectsMsgParse = 2;

/** Custom callbacks */

/** @method flags=no_gen */
alias custom.drawRect_CALLBACK drawRect_CALLBACK;
/** @method flags=no_gen */
alias custom.drawInteriorWithFrame_inView_CALLBACK drawInteriorWithFrame_inView_CALLBACK;
/** @method flags=no_gen */
alias custom.setFrame_CALLBACK setFrame_CALLBACK;
/** @method flags=no_gen */
alias custom.setFrameOrigin_CALLBACK setFrameOrigin_CALLBACK;
/** @method flags=no_gen */
alias custom.setFrameSize_CALLBACK setFrameSize_CALLBACK;
/** @method flags=no_gen */
alias custom.hitTest_CALLBACK hitTest_CALLBACK;
/** @method flags=no_gen */
alias custom.webView_setFrame_CALLBACK webView_setFrame_CALLBACK;
/** @method flags=no_gen */
alias custom.markedRange_CALLBACK markedRange_CALLBACK;
/** @method flags=no_gen */
alias custom.selectedRange_CALLBACK selectedRange_CALLBACK;
/** @method flags=no_gen */
alias custom.highlightSelectionInClipRect_CALLBACK highlightSelectionInClipRect_CALLBACK;
/** @method flags=no_gen */
alias custom.attributedSubstringFromRange_CALLBACK attributedSubstringFromRange_CALLBACK;
/** @method flags=no_gen */
alias custom.setMarkedText_selectedRange_CALLBACK setMarkedText_selectedRange_CALLBACK;
/** @method flags=no_gen */
alias custom.characterIndexForPoint_CALLBACK characterIndexForPoint_CALLBACK;
/** @method flags=no_gen */
alias custom.firstRectForCharacterRange_CALLBACK firstRectForCharacterRange_CALLBACK;
/** @method flags=no_gen */
alias custom.textView_willChangeSelectionFromCharacterRange_toCharacterRange_CALLBACK textView_willChangeSelectionFromCharacterRange_toCharacterRange_CALLBACK;
/** @method flags=no_gen */
alias custom.draggedImage_movedTo_CALLBACK draggedImage_movedTo_CALLBACK;
/** @method flags=no_gen */
alias custom.draggedImage_beganAt_CALLBACK draggedImage_beganAt_CALLBACK;
/** @method flags=no_gen */
alias custom.draggedImage_endedAt_operation_CALLBACK draggedImage_endedAt_operation_CALLBACK;
/** @method flags=no_gen */
alias custom.accessibilityHitTest_CALLBACK accessibilityHitTest_CALLBACK;
/** @method flags=no_gen */
alias custom.dragSelectionWithEvent_offset_slideBack_CALLBACK dragSelectionWithEvent_offset_slideBack_CALLBACK;
/** Custom structure return */

/** @method flags=no_gen */
alias Cocoa.NSIntersectionRect NSIntersectionRect;

/** Objective-C runtime */

/** @param cls cast=(Class) */
alias objc.class_addIvar class_addIvar;
/**
 * @param cls cast=(Class)
 * @param name cast=(SEL)
 * @param imp cast=(IMP)
 */
alias objc.class_addMethod class_addMethod;
/**
 * @param cls cast=(Class)
 * @param protocol cast=(Protocol *)
 */
alias objc.class_addProtocol class_addProtocol;
/**
 * @param cls cast=(Class)
 * @param name cast=(SEL)
 */
alias objc.class_getMethodImplementation class_getMethodImplementation;
/** @method flags=no_gen */
alias objc.class_getName class_getName;
/** @method flags=dynamic */
alias objc.instrumentObjcMessageSends instrumentObjcMessageSends;
/** @param superclass cast=(Class) */
alias objc.objc_allocateClassPair objc_allocateClassPair;
alias objc.objc_getClass objc_getClass;
alias objc.objc_getProtocol objc_getProtocol;
alias objc.objc_lookUpClass objc_lookUpClass;
/** @method flags=cast */
alias objc.objc_msgSendSuper objc_msgSendSuper;
/** @param cls cast=(Class) */
alias objc.objc_registerClassPair objc_registerClassPair;
/** @param obj cast=(id) */
alias objc.object_getClassName object_getClassName;
/** @param obj cast=(id) */
alias objc.object_getClass object_getClass;

/**
 * @param obj cast=(id)
 * @param outValue cast=(void **)
 */
alias objc.object_getInstanceVariable object_getInstanceVariable;
/**
 * @param obj cast=(id)
 * @param value cast=(void *)
 */
alias objc.object_setInstanceVariable object_setInstanceVariable;
/**
 * @param obj cast=(id)
 * @param clazz cast=(Class) 
 */
alias objc.object_setClass object_setClass;
alias objc.sel_registerName sel_registerName;
size_t objc_super_sizeof ()
{
    return objc.objc_super.sizeof;
}


/** This section is auto generated */

/** Classes */
public static const objc.id class_DOMDocument;
public static const objc.id class_DOMEvent;
public static const objc.id class_DOMKeyboardEvent;
public static const objc.id class_DOMMouseEvent;
public static const objc.id class_DOMUIEvent;
public static const objc.id class_DOMWheelEvent;
public static const objc.id class_NSActionCell;
public static const objc.id class_NSAffineTransform;
public static const objc.id class_NSAlert;
public static const objc.id class_NSAppleEventDescriptor;
public static const objc.id class_NSApplication;
public static const objc.id class_NSArray;
public static const objc.id class_NSAttributedString;
public static const objc.id class_NSAutoreleasePool;
public static const objc.id class_NSBezierPath;
public static const objc.id class_NSBitmapImageRep;
public static const objc.id class_NSBox;
public static const objc.id class_NSBrowserCell;
public static const objc.id class_NSBundle;
public static const objc.id class_NSButton;
public static const objc.id class_NSButtonCell;
public static const objc.id class_NSCalendarDate;
public static const objc.id class_NSCell;
public static const objc.id class_NSCharacterSet;
public static const objc.id class_NSClipView;
public static const objc.id class_NSCoder;
public static const objc.id class_NSColor;
public static const objc.id class_NSColorPanel;
public static const objc.id class_NSColorSpace;
public static const objc.id class_NSComboBox;
public static const objc.id class_NSControl;
public static const objc.id class_NSCursor;
public static const objc.id class_NSData;
public static const objc.id class_NSDate;
public static const objc.id class_NSDatePicker;
public static const objc.id class_NSDictionary;
public static const objc.id class_NSDirectoryEnumerator;
public static const objc.id class_NSEnumerator;
public static const objc.id class_NSError;
public static const objc.id class_NSEvent;
public static const objc.id class_NSFileManager;
public static const objc.id class_NSFont;
public static const objc.id class_NSFontManager;
public static const objc.id class_NSFontPanel;
public static const objc.id class_NSFormatter;
public static const objc.id class_NSGradient;
public static const objc.id class_NSGraphicsContext;
public static const objc.id class_NSHTTPCookie;
public static const objc.id class_NSHTTPCookieStorage;
public static const objc.id class_NSImage;
public static const objc.id class_NSImageRep;
public static const objc.id class_NSImageView;
public static const objc.id class_NSIndexSet;
public static const objc.id class_NSInputManager;
public static const objc.id class_NSKeyedArchiver;
public static const objc.id class_NSKeyedUnarchiver;
public static const objc.id class_NSLayoutManager;
public static const objc.id class_NSMenu;
public static const objc.id class_NSMenuItem;
public static const objc.id class_NSMutableArray;
public static const objc.id class_NSMutableAttributedString;
public static const objc.id class_NSMutableDictionary;
public static const objc.id class_NSMutableIndexSet;
public static const objc.id class_NSMutableParagraphStyle;
public static const objc.id class_NSMutableSet;
public static const objc.id class_NSMutableString;
public static const objc.id class_NSMutableURLRequest;
public static const objc.id class_NSNotification;
public static const objc.id class_NSNotificationCenter;
public static const objc.id class_NSNumber;
public static const objc.id class_NSNumberFormatter;
public static const objc.id class_NSObject;
public static const objc.id class_NSOpenGLContext;
public static const objc.id class_NSOpenGLPixelFormat;
public static const objc.id class_NSOpenGLView;
public static const objc.id class_NSOpenPanel;
public static const objc.id class_NSOutlineView;
public static const objc.id class_NSPanel;
public static const objc.id class_NSParagraphStyle;
public static const objc.id class_NSPasteboard;
public static const objc.id class_NSPopUpButton;
public static const objc.id class_NSPrintInfo;
public static const objc.id class_NSPrintOperation;
public static const objc.id class_NSPrintPanel;
public static const objc.id class_NSPrinter;
public static const objc.id class_NSProgressIndicator;
public static const objc.id class_NSResponder;
public static const objc.id class_NSRunLoop;
public static const objc.id class_NSSavePanel;
public static const objc.id class_NSScreen;
public static const objc.id class_NSScrollView;
public static const objc.id class_NSScroller;
public static const objc.id class_NSSearchField;
public static const objc.id class_NSSecureTextField;
public static const objc.id class_NSSet;
public static const objc.id class_NSSlider;
public static const objc.id class_NSStatusBar;
public static const objc.id class_NSStatusItem;
public static const objc.id class_NSStepper;
public static const objc.id class_NSString;
public static const objc.id class_NSTabView;
public static const objc.id class_NSTabViewItem;
public static const objc.id class_NSTableColumn;
public static const objc.id class_NSTableHeaderCell;
public static const objc.id class_NSTableHeaderView;
public static const objc.id class_NSTableView;
public static const objc.id class_NSText;
public static const objc.id class_NSTextContainer;
public static const objc.id class_NSTextField;
public static const objc.id class_NSTextFieldCell;
public static const objc.id class_NSTextStorage;
public static const objc.id class_NSTextTab;
public static const objc.id class_NSTextView;
public static const objc.id class_NSThread;
public static const objc.id class_NSTimeZone;
public static const objc.id class_NSTimer;
public static const objc.id class_NSTypesetter;
public static const objc.id class_NSURL;
public static const objc.id class_NSURLDownload;
public static const objc.id class_NSURLRequest;
public static const objc.id class_NSValue;
public static const objc.id class_NSView;
public static const objc.id class_NSWindow;
public static const objc.id class_NSWorkspace;
public static const objc.id class_WebDataSource;
public static const objc.id class_WebFrame;
public static const objc.id class_WebFrameView;
public static const objc.id class_WebPreferences;
public static const objc.id class_WebView;

/** Protocols */
public static const objc.Protocol* protocol_NSAccessibility;
public static const objc.Protocol* protocol_NSAccessibilityAdditions;
public static const objc.Protocol* protocol_NSApplicationDelegate;
public static const objc.Protocol* protocol_NSApplicationNotifications;
public static const objc.Protocol* protocol_NSColorPanelResponderMethod;
public static const objc.Protocol* protocol_NSComboBoxNotifications;
public static const objc.Protocol* protocol_NSDraggingDestination;
public static const objc.Protocol* protocol_NSDraggingSource;
public static const objc.Protocol* protocol_NSFontManagerResponderMethod;
public static const objc.Protocol* protocol_NSMenuDelegate;
public static const objc.Protocol* protocol_NSOutlineViewDataSource;
public static const objc.Protocol* protocol_NSOutlineViewDelegate;
public static const objc.Protocol* protocol_NSOutlineViewNotifications;
public static const objc.Protocol* protocol_NSPasteboardOwner;
public static const objc.Protocol* protocol_NSTabViewDelegate;
public static const objc.Protocol* protocol_NSTableDataSource;
public static const objc.Protocol* protocol_NSTableViewDelegate;
public static const objc.Protocol* protocol_NSTableViewNotifications;
public static const objc.Protocol* protocol_NSTextDelegate;
public static const objc.Protocol* protocol_NSTextInput;
public static const objc.Protocol* protocol_NSTextViewDelegate;
public static const objc.Protocol* protocol_NSURLDownloadDelegate;
public static const objc.Protocol* protocol_NSWindowDelegate;
public static const objc.Protocol* protocol_NSWindowNotifications;
public static const objc.Protocol* protocol_WebDocumentRepresentation;
public static const objc.Protocol* protocol_WebFrameLoadDelegate;
public static const objc.Protocol* protocol_WebOpenPanelResultListener;
public static const objc.Protocol* protocol_WebPolicyDecisionListener;
public static const objc.Protocol* protocol_WebPolicyDelegate;
public static const objc.Protocol* protocol_WebResourceLoadDelegate;
public static const objc.Protocol* protocol_WebUIDelegate;

/** Selectors */
public static const objc.SEL sel_DOMDocument;
public static const objc.SEL sel_IBeamCursor;
public static const objc.SEL sel_TIFFRepresentation;
public static const objc.SEL sel_URL;
public static const objc.SEL sel_URLFromPasteboard_;
public static const objc.SEL sel_URLWithString_;
public static const objc.SEL sel_UTF8String;
public static const objc.SEL sel_absoluteString;
public static const objc.SEL sel_acceptsFirstResponder;
public static const objc.SEL sel_accessibilityActionDescription_;
public static const objc.SEL sel_accessibilityActionNames;
public static const objc.SEL sel_accessibilityAttributeNames;
public static const objc.SEL sel_accessibilityAttributeValue_;
public static const objc.SEL sel_accessibilityAttributeValue_forParameter_;
public static const objc.SEL sel_accessibilityFocusedUIElement;
public static const objc.SEL sel_accessibilityHitTest_;
public static const objc.SEL sel_accessibilityIsAttributeSettable_;
public static const objc.SEL sel_accessibilityIsIgnored;
public static const objc.SEL sel_accessibilityParameterizedAttributeNames;
public static const objc.SEL sel_accessibilityPerformAction_;
public static const objc.SEL sel_accessibilitySetOverrideValue_forAttribute_;
public static const objc.SEL sel_accessibilitySetValue_forAttribute_;
public static const objc.SEL sel_action;
public static const objc.SEL sel_activateIgnoringOtherApps_;
public static const objc.SEL sel_addAttribute_value_range_;
public static const objc.SEL sel_addClip;
public static const objc.SEL sel_addEventListener_listener_useCapture_;
public static const objc.SEL sel_addIndex_;
public static const objc.SEL sel_addItem_;
public static const objc.SEL sel_addItemWithObjectValue_;
public static const objc.SEL sel_addLayoutManager_;
public static const objc.SEL sel_addObject_;
public static const objc.SEL sel_addObjectsFromArray_;
public static const objc.SEL sel_addObserver_selector_name_object_;
public static const objc.SEL sel_addRepresentation_;
public static const objc.SEL sel_addSubview_;
public static const objc.SEL sel_addSubview_positioned_relativeTo_;
public static const objc.SEL sel_addTabStop_;
public static const objc.SEL sel_addTabViewItem_;
public static const objc.SEL sel_addTableColumn_;
public static const objc.SEL sel_addTemporaryAttribute_value_forCharacterRange_;
public static const objc.SEL sel_addTextContainer_;
public static const objc.SEL sel_addTypes_owner_;
public static const objc.SEL sel_alertWithMessageText_defaultButton_alternateButton_otherButton_informativeTextWithFormat_;
public static const objc.SEL sel_alignment;
public static const objc.SEL sel_allKeys;
public static const objc.SEL sel_alloc;
public static const objc.SEL sel_allowsFloats;
public static const objc.SEL sel_alphaComponent;
public static const objc.SEL sel_alphaValue;
public static const objc.SEL sel_altKey;
public static const objc.SEL sel_alternateSelectedControlTextColor;
public static const objc.SEL sel_alwaysShowsDecimalSeparator;
public static const objc.SEL sel_appendBezierPath_;
public static const objc.SEL sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_;
public static const objc.SEL sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_clockwise_;
public static const objc.SEL sel_appendBezierPathWithGlyphs_count_inFont_;
public static const objc.SEL sel_appendBezierPathWithOvalInRect_;
public static const objc.SEL sel_appendBezierPathWithRect_;
public static const objc.SEL sel_appendBezierPathWithRoundedRect_xRadius_yRadius_;
public static const objc.SEL sel_appendString_;
public static const objc.SEL sel_applicationShouldTerminate_;
public static const objc.SEL sel_applicationWillFinishLaunching_;
public static const objc.SEL sel_applicationWillResignActive_;
public static const objc.SEL sel_applicationWillTerminate_;
public static const objc.SEL sel_archivedDataWithRootObject_;
public static const objc.SEL sel_array;
public static const objc.SEL sel_arrayWithCapacity_;
public static const objc.SEL sel_arrayWithObject_;
public static const objc.SEL sel_arrowCursor;
public static const objc.SEL sel_ascender;
public static const objc.SEL sel_attributedSubstringFromRange_;
public static const objc.SEL sel_attributesAtIndex_longestEffectiveRange_inRange_;
public static const objc.SEL sel_autorelease;
public static const objc.SEL sel_availableFontFamilies;
public static const objc.SEL sel_availableFonts;
public static const objc.SEL sel_availableMembersOfFontFamily_;
public static const objc.SEL sel_availableTypeFromArray_;
public static const objc.SEL sel_baselineOffsetInLayoutManager_glyphIndex_;
public static const objc.SEL sel_becomeFirstResponder;
public static const objc.SEL sel_beginDocument;
public static const objc.SEL sel_beginEditing;
public static const objc.SEL sel_beginPageInRect_atPlacement_;
public static const objc.SEL sel_bestRepresentationForDevice_;
public static const objc.SEL sel_bezierPath;
public static const objc.SEL sel_bezierPathByFlatteningPath;
public static const objc.SEL sel_bezierPathWithRect_;
public static const objc.SEL sel_bitmapData;
public static const objc.SEL sel_bitsPerPixel;
public static const objc.SEL sel_bitsPerSample;
public static const objc.SEL sel_blackColor;
public static const objc.SEL sel_blueComponent;
public static const objc.SEL sel_borderWidth;
public static const objc.SEL sel_boundingRectForGlyphRange_inTextContainer_;
public static const objc.SEL sel_bounds;
public static const objc.SEL sel_bundleIdentifier;
public static const objc.SEL sel_bundlePath;
public static const objc.SEL sel_bundleWithPath_;
public static const objc.SEL sel_button;
public static const objc.SEL sel_buttonNumber;
public static const objc.SEL sel_bytes;
public static const objc.SEL sel_bytesPerPlane;
public static const objc.SEL sel_bytesPerRow;
public static const objc.SEL sel_calendarDate;
public static const objc.SEL sel_canBecomeKeyWindow;
public static const objc.SEL sel_canGoBack;
public static const objc.SEL sel_canGoForward;
public static const objc.SEL sel_canShowMIMEType_;
public static const objc.SEL sel_cancel;
public static const objc.SEL sel_cancelTracking;
public static const objc.SEL sel_cascadeTopLeftFromPoint_;
public static const objc.SEL sel_cell;
public static const objc.SEL sel_cellClass;
public static const objc.SEL sel_cellSizeForBounds_;
public static const objc.SEL sel_changeColor_;
public static const objc.SEL sel_changeFont_;
public static const objc.SEL sel_charCode;
public static const objc.SEL sel_characterAtIndex_;
public static const objc.SEL sel_characterIndexForGlyphAtIndex_;
public static const objc.SEL sel_characterIndexForPoint_;
public static const objc.SEL sel_characterIsMember_;
public static const objc.SEL sel_characters;
public static const objc.SEL sel_charactersIgnoringModifiers;
public static const objc.SEL sel_chooseFilename_;
public static const objc.SEL sel_className;
public static const objc.SEL sel_cleanUpOperation;
public static const objc.SEL sel_clearColor;
public static const objc.SEL sel_clearCurrentContext;
public static const objc.SEL sel_clearGLContext;
public static const objc.SEL sel_clickCount;
public static const objc.SEL sel_clientX;
public static const objc.SEL sel_clientY;
public static const objc.SEL sel_close;
public static const objc.SEL sel_closePath;
public static const objc.SEL sel_code;
public static const objc.SEL sel_collapseItem_;
public static const objc.SEL sel_color;
public static const objc.SEL sel_colorUsingColorSpace_;
public static const objc.SEL sel_colorUsingColorSpaceName_;
public static const objc.SEL sel_colorWithDeviceRed_green_blue_alpha_;
public static const objc.SEL sel_colorWithPatternImage_;
public static const objc.SEL sel_columnAtPoint_;
public static const objc.SEL sel_columnAutoresizingStyle;
public static const objc.SEL sel_columnIndexesInRect_;
public static const objc.SEL sel_columnWithIdentifier_;
public static const objc.SEL sel_comboBoxSelectionDidChange_;
public static const objc.SEL sel_concat;
public static const objc.SEL sel_conformsToProtocol_;
public static const objc.SEL sel_containerSize;
public static const objc.SEL sel_containsObject_;
public static const objc.SEL sel_containsPoint_;
public static const objc.SEL sel_contentRect;
public static const objc.SEL sel_contentRectForFrameRect_;
public static const objc.SEL sel_contentSize;
public static const objc.SEL sel_contentSizeForFrameSize_hasHorizontalScroller_hasVerticalScroller_borderType_;
public static const objc.SEL sel_contentView;
public static const objc.SEL sel_contentViewMargins;
public static const objc.SEL sel_context;
public static const objc.SEL sel_controlDarkShadowColor;
public static const objc.SEL sel_controlHighlightColor;
public static const objc.SEL sel_controlLightHighlightColor;
public static const objc.SEL sel_controlPointBounds;
public static const objc.SEL sel_controlShadowColor;
public static const objc.SEL sel_controlTextColor;
public static const objc.SEL sel_convertBaseToScreen_;
public static const objc.SEL sel_convertPoint_fromView_;
public static const objc.SEL sel_convertPoint_toView_;
public static const objc.SEL sel_convertPointFromBase_;
public static const objc.SEL sel_convertPointToBase_;
public static const objc.SEL sel_convertRect_fromView_;
public static const objc.SEL sel_convertRect_toView_;
public static const objc.SEL sel_convertRectFromBase_;
public static const objc.SEL sel_convertRectToBase_;
public static const objc.SEL sel_convertScreenToBase_;
public static const objc.SEL sel_convertSize_fromView_;
public static const objc.SEL sel_convertSize_toView_;
public static const objc.SEL sel_convertSizeFromBase_;
public static const objc.SEL sel_convertSizeToBase_;
public static const objc.SEL sel_cookies;
public static const objc.SEL sel_copy;
public static const objc.SEL sel_copy_;
public static const objc.SEL sel_count;
public static const objc.SEL sel_createContext;
public static const objc.SEL sel_createFileAtPath_contents_attributes_;
public static const objc.SEL sel_crosshairCursor;
public static const objc.SEL sel_ctrlKey;
public static const objc.SEL sel_currentContext;
public static const objc.SEL sel_currentEditor;
public static const objc.SEL sel_currentEvent;
public static const objc.SEL sel_currentInputManager;
public static const objc.SEL sel_currentPoint;
public static const objc.SEL sel_currentRunLoop;
public static const objc.SEL sel_currentThread;
public static const objc.SEL sel_curveToPoint_controlPoint1_controlPoint2_;
public static const objc.SEL sel_cut_;
public static const objc.SEL sel_dataForType_;
public static const objc.SEL sel_dataSource;
public static const objc.SEL sel_dataWithBytes_length_;
public static const objc.SEL sel_dateValue;
public static const objc.SEL sel_dateWithCalendarFormat_timeZone_;
public static const objc.SEL sel_dateWithTimeIntervalSinceNow_;
public static const objc.SEL sel_dateWithYear_month_day_hour_minute_second_timeZone_;
public static const objc.SEL sel_dayOfMonth;
public static const objc.SEL sel_decimalDigitCharacterSet;
public static const objc.SEL sel_decimalSeparator;
public static const objc.SEL sel_declareTypes_owner_;
public static const objc.SEL sel_defaultCenter;
public static const objc.SEL sel_defaultFlatness;
public static const objc.SEL sel_defaultLineHeightForFont_;
public static const objc.SEL sel_defaultManager;
public static const objc.SEL sel_defaultPrinter;
public static const objc.SEL sel_defaultTimeZone;
public static const objc.SEL sel_deleteCookie_;
public static const objc.SEL sel_deliverResult;
public static const objc.SEL sel_deltaX;
public static const objc.SEL sel_deltaY;
public static const objc.SEL sel_depth;
public static const objc.SEL sel_descender;
public static const objc.SEL sel_description;
public static const objc.SEL sel_deselectAll_;
public static const objc.SEL sel_deselectItemAtIndex_;
public static const objc.SEL sel_deselectRow_;
public static const objc.SEL sel_destroyContext;
public static const objc.SEL sel_detail;
public static const objc.SEL sel_deviceDescription;
public static const objc.SEL sel_deviceRGBColorSpace;
public static const objc.SEL sel_dictionary;
public static const objc.SEL sel_dictionaryWithCapacity_;
public static const objc.SEL sel_dictionaryWithObject_forKey_;
public static const objc.SEL sel_disableCursorRects;
public static const objc.SEL sel_disabledControlTextColor;
public static const objc.SEL sel_displayIfNeeded;
public static const objc.SEL sel_distantFuture;
public static const objc.SEL sel_doCommandBySelector_;
public static const objc.SEL sel_documentSource;
public static const objc.SEL sel_documentView;
public static const objc.SEL sel_documentViewShouldHandlePrint;
public static const objc.SEL sel_documentVisibleRect;
public static const objc.SEL sel_doubleClickAtIndex_;
public static const objc.SEL sel_doubleValue;
public static const objc.SEL sel_download;
public static const objc.SEL sel_download_decideDestinationWithSuggestedFilename_;
public static const objc.SEL sel_dragImage_at_offset_event_pasteboard_source_slideBack_;
public static const objc.SEL sel_draggedImage;
public static const objc.SEL sel_draggedImage_beganAt_;
public static const objc.SEL sel_draggedImage_endedAt_operation_;
public static const objc.SEL sel_draggedImageLocation;
public static const objc.SEL sel_draggingDestinationWindow;
public static const objc.SEL sel_draggingEnded_;
public static const objc.SEL sel_draggingEntered_;
public static const objc.SEL sel_draggingExited_;
public static const objc.SEL sel_draggingLocation;
public static const objc.SEL sel_draggingPasteboard;
public static const objc.SEL sel_draggingSequenceNumber;
public static const objc.SEL sel_draggingSource;
public static const objc.SEL sel_draggingSourceOperationMask;
public static const objc.SEL sel_draggingSourceOperationMaskForLocal_;
public static const objc.SEL sel_draggingUpdated_;
public static const objc.SEL sel_drawAtPoint_;
public static const objc.SEL sel_drawAtPoint_fromRect_operation_fraction_;
public static const objc.SEL sel_drawBackgroundForGlyphRange_atPoint_;
public static const objc.SEL sel_drawFromPoint_toPoint_options_;
public static const objc.SEL sel_drawGlyphsForGlyphRange_atPoint_;
public static const objc.SEL sel_drawInRect_;
public static const objc.SEL sel_drawInRect_angle_;
public static const objc.SEL sel_drawInRect_fromRect_operation_fraction_;
public static const objc.SEL sel_drawInteriorWithFrame_inView_;
public static const objc.SEL sel_drawRect_;
public static const objc.SEL sel_drawSortIndicatorWithFrame_inView_ascending_priority_;
public static const objc.SEL sel_drawStatusBarBackgroundInRect_withHighlight_;
public static const objc.SEL sel_drawingRectForBounds_;
public static const objc.SEL sel_elementAtIndex_associatedPoints_;
public static const objc.SEL sel_elementCount;
public static const objc.SEL sel_enableFreedObjectCheck_;
public static const objc.SEL sel_endDocument;
public static const objc.SEL sel_endEditing;
public static const objc.SEL sel_endPage;
public static const objc.SEL sel_enumeratorAtPath_;
public static const objc.SEL sel_expandItem_;
public static const objc.SEL sel_familyName;
public static const objc.SEL sel_fieldEditor_forObject_;
public static const objc.SEL sel_fileURLWithPath_;
public static const objc.SEL sel_filename;
public static const objc.SEL sel_filenames;
public static const objc.SEL sel_fill;
public static const objc.SEL sel_fillRect_;
public static const objc.SEL sel_finishLaunching;
public static const objc.SEL sel_firstIndex;
public static const objc.SEL sel_firstRectForCharacterRange_;
public static const objc.SEL sel_firstResponder;
public static const objc.SEL sel_flagsChanged_;
public static const objc.SEL sel_flushBuffer;
public static const objc.SEL sel_flushGraphics;
public static const objc.SEL sel_font;
public static const objc.SEL sel_fontName;
public static const objc.SEL sel_fontWithName_size_;
public static const objc.SEL sel_frame;
public static const objc.SEL sel_frameOfCellAtColumn_row_;
public static const objc.SEL sel_frameRectForContentRect_;
public static const objc.SEL sel_frameSizeForContentSize_hasHorizontalScroller_hasVerticalScroller_borderType_;
public static const objc.SEL sel_fullPathForApplication_;
public static const objc.SEL sel_generalPasteboard;
public static const objc.SEL sel_getBytes_;
public static const objc.SEL sel_getBytes_length_;
public static const objc.SEL sel_getCharacters_;
public static const objc.SEL sel_getCharacters_range_;
public static const objc.SEL sel_getComponents_;
public static const objc.SEL sel_getGlyphs_range_;
public static const objc.SEL sel_getIndexes_maxCount_inIndexRange_;
public static const objc.SEL sel_getInfoForFile_application_type_;
public static const objc.SEL sel_glyphIndexForCharacterAtIndex_;
public static const objc.SEL sel_glyphIndexForPoint_inTextContainer_fractionOfDistanceThroughGlyph_;
public static const objc.SEL sel_glyphRangeForTextContainer_;
public static const objc.SEL sel_goBack;
public static const objc.SEL sel_goForward;
public static const objc.SEL sel_graphicsContext;
public static const objc.SEL sel_graphicsContextWithBitmapImageRep_;
public static const objc.SEL sel_graphicsContextWithWindow_;
public static const objc.SEL sel_greenComponent;
public static const objc.SEL sel_handleEvent_;
public static const objc.SEL sel_handleMouseEvent_;
public static const objc.SEL sel_hasAlpha;
public static const objc.SEL sel_hasMarkedText;
public static const objc.SEL sel_headerCell;
public static const objc.SEL sel_headerRectOfColumn_;
public static const objc.SEL sel_headerView;
public static const objc.SEL sel_helpRequested_;
public static const objc.SEL sel_hide_;
public static const objc.SEL sel_hideOtherApplications_;
public static const objc.SEL sel_highlightColorInView_;
public static const objc.SEL sel_highlightSelectionInClipRect_;
public static const objc.SEL sel_hitPart;
public static const objc.SEL sel_hitTest_;
public static const objc.SEL sel_hourOfDay;
public static const objc.SEL sel_iconForFile_;
public static const objc.SEL sel_iconForFileType_;
public static const objc.SEL sel_ignore;
public static const objc.SEL sel_ignoreModifierKeysWhileDragging;
public static const objc.SEL sel_imageInterpolation;
public static const objc.SEL sel_imageablePageBounds;
public static const objc.SEL sel_increment;
public static const objc.SEL sel_indentationPerLevel;
public static const objc.SEL sel_indexOfSelectedItem;
public static const objc.SEL sel_infoDictionary;
public static const objc.SEL sel_init;
public static const objc.SEL sel_initByReferencingFile_;
public static const objc.SEL sel_initListDescriptor;
public static const objc.SEL sel_initWithAttributes_;
public static const objc.SEL sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_;
public static const objc.SEL sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_;
public static const objc.SEL sel_initWithContainerSize_;
public static const objc.SEL sel_initWithContentRect_styleMask_backing_defer_;
public static const objc.SEL sel_initWithContentRect_styleMask_backing_defer_screen_;
public static const objc.SEL sel_initWithData_;
public static const objc.SEL sel_initWithDictionary_;
public static const objc.SEL sel_initWithFrame_;
public static const objc.SEL sel_initWithFrame_frameName_groupName_;
public static const objc.SEL sel_initWithFrame_pixelFormat_;
public static const objc.SEL sel_initWithFrame_pullsDown_;
public static const objc.SEL sel_initWithIdentifier_;
public static const objc.SEL sel_initWithImage_hotSpot_;
public static const objc.SEL sel_initWithIndex_;
public static const objc.SEL sel_initWithIndexesInRange_;
public static const objc.SEL sel_initWithSize_;
public static const objc.SEL sel_initWithStartingColor_endingColor_;
public static const objc.SEL sel_initWithString_;
public static const objc.SEL sel_initWithString_attributes_;
public static const objc.SEL sel_initWithTitle_;
public static const objc.SEL sel_initWithTitle_action_keyEquivalent_;
public static const objc.SEL sel_initWithTransform_;
public static const objc.SEL sel_initWithType_location_;
public static const objc.SEL sel_initWithURL_;
public static const objc.SEL sel_insertItem_atIndex_;
public static const objc.SEL sel_insertItemWithObjectValue_atIndex_;
public static const objc.SEL sel_insertTabViewItem_atIndex_;
public static const objc.SEL sel_insertText_;
public static const objc.SEL sel_intValue;
public static const objc.SEL sel_intercellSpacing;
public static const objc.SEL sel_interpretKeyEvents_;
public static const objc.SEL sel_invalidate;
public static const objc.SEL sel_invert;
public static const objc.SEL sel_isEmpty;
public static const objc.SEL sel_isEqual_;
public static const objc.SEL sel_isEqualTo_;
public static const objc.SEL sel_isEqualToString_;
public static const objc.SEL sel_isFilePackageAtPath_;
public static const objc.SEL sel_isFlipped;
public static const objc.SEL sel_isHidden;
public static const objc.SEL sel_isKeyWindow;
public static const objc.SEL sel_isKindOfClass_;
public static const objc.SEL sel_isMainThread;
public static const objc.SEL sel_isOpaque;
public static const objc.SEL sel_isPlanar;
public static const objc.SEL sel_isRowSelected_;
public static const objc.SEL sel_isRunning;
public static const objc.SEL sel_isSessionOnly;
public static const objc.SEL sel_isVisible;
public static const objc.SEL sel_itemArray;
public static const objc.SEL sel_itemAtIndex_;
public static const objc.SEL sel_itemAtRow_;
public static const objc.SEL sel_itemObjectValueAtIndex_;
public static const objc.SEL sel_itemTitleAtIndex_;
public static const objc.SEL sel_jobDisposition;
public static const objc.SEL sel_keyCode;
public static const objc.SEL sel_keyDown_;
public static const objc.SEL sel_keyEquivalent;
public static const objc.SEL sel_keyEquivalentModifierMask;
public static const objc.SEL sel_keyUp_;
public static const objc.SEL sel_keyWindow;
public static const objc.SEL sel_lastPathComponent;
public static const objc.SEL sel_leading;
public static const objc.SEL sel_length;
public static const objc.SEL sel_levelForItem_;
public static const objc.SEL sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_;
public static const objc.SEL sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_withoutAdditionalLayout_;
public static const objc.SEL sel_lineToPoint_;
public static const objc.SEL sel_loadHTMLString_baseURL_;
public static const objc.SEL sel_loadNibFile_externalNameTable_withZone_;
public static const objc.SEL sel_loadRequest_;
public static const objc.SEL sel_localizedDescription;
public static const objc.SEL sel_location;
public static const objc.SEL sel_locationForGlyphAtIndex_;
public static const objc.SEL sel_locationInWindow;
public static const objc.SEL sel_lowercaseString;
public static const objc.SEL sel_mainFrame;
public static const objc.SEL sel_mainMenu;
public static const objc.SEL sel_mainRunLoop;
public static const objc.SEL sel_mainScreen;
public static const objc.SEL sel_makeCurrentContext;
public static const objc.SEL sel_makeFirstResponder_;
public static const objc.SEL sel_makeKeyAndOrderFront_;
public static const objc.SEL sel_markedRange;
public static const objc.SEL sel_markedTextAttributes;
public static const objc.SEL sel_maxValue;
public static const objc.SEL sel_maximum;
public static const objc.SEL sel_maximumFractionDigits;
public static const objc.SEL sel_maximumIntegerDigits;
public static const objc.SEL sel_menu;
public static const objc.SEL sel_menu_willHighlightItem_;
public static const objc.SEL sel_menuDidClose_;
public static const objc.SEL sel_menuForEvent_;
public static const objc.SEL sel_menuNeedsUpdate_;
public static const objc.SEL sel_menuWillOpen_;
public static const objc.SEL sel_metaKey;
public static const objc.SEL sel_minValue;
public static const objc.SEL sel_minimum;
public static const objc.SEL sel_minimumSize;
public static const objc.SEL sel_minuteOfHour;
public static const objc.SEL sel_modifierFlags;
public static const objc.SEL sel_monthOfYear;
public static const objc.SEL sel_mouseDown_;
public static const objc.SEL sel_mouseDragged_;
public static const objc.SEL sel_mouseEntered_;
public static const objc.SEL sel_mouseExited_;
public static const objc.SEL sel_mouseLocation;
public static const objc.SEL sel_mouseLocationOutsideOfEventStream;
public static const objc.SEL sel_mouseMoved_;
public static const objc.SEL sel_mouseUp_;
public static const objc.SEL sel_moveColumn_toColumn_;
public static const objc.SEL sel_moveToBeginningOfParagraph_;
public static const objc.SEL sel_moveToEndOfParagraph_;
public static const objc.SEL sel_moveToPoint_;
public static const objc.SEL sel_moveUp_;
public static const objc.SEL sel_mutableString;
public static const objc.SEL sel_name;
public static const objc.SEL sel_namesOfPromisedFilesDroppedAtDestination_;
public static const objc.SEL sel_nextEventMatchingMask_untilDate_inMode_dequeue_;
public static const objc.SEL sel_nextObject;
public static const objc.SEL sel_nextWordFromIndex_forward_;
public static const objc.SEL sel_noteNumberOfRowsChanged;
public static const objc.SEL sel_numberOfColumns;
public static const objc.SEL sel_numberOfComponents;
public static const objc.SEL sel_numberOfGlyphs;
public static const objc.SEL sel_numberOfItems;
public static const objc.SEL sel_numberOfRows;
public static const objc.SEL sel_numberOfRowsInTableView_;
public static const objc.SEL sel_numberOfSelectedRows;
public static const objc.SEL sel_numberOfVisibleItems;
public static const objc.SEL sel_numberWithBool_;
public static const objc.SEL sel_numberWithInt_;
public static const objc.SEL sel_numberWithInteger_;
public static const objc.SEL sel_object;
public static const objc.SEL sel_objectAtIndex_;
public static const objc.SEL sel_objectEnumerator;
public static const objc.SEL sel_objectForInfoDictionaryKey_;
public static const objc.SEL sel_objectForKey_;
public static const objc.SEL sel_openFile_withApplication_;
public static const objc.SEL sel_openGLContext;
public static const objc.SEL sel_openPanel;
public static const objc.SEL sel_openURL_;
public static const objc.SEL sel_openURLs_withAppBundleIdentifier_options_additionalEventParamDescriptor_launchIdentifiers_;
public static const objc.SEL sel_options;
public static const objc.SEL sel_orderFront_;
public static const objc.SEL sel_orderFrontRegardless;
public static const objc.SEL sel_orderFrontStandardAboutPanel_;
public static const objc.SEL sel_orderOut_;
public static const objc.SEL sel_orderedWindows;
public static const objc.SEL sel_otherEventWithType_location_modifierFlags_timestamp_windowNumber_context_subtype_data1_data2_;
public static const objc.SEL sel_otherMouseDown_;
public static const objc.SEL sel_otherMouseDragged_;
public static const objc.SEL sel_otherMouseUp_;
public static const objc.SEL sel_outlineTableColumn;
public static const objc.SEL sel_outlineView_child_ofItem_;
public static const objc.SEL sel_outlineView_didClickTableColumn_;
public static const objc.SEL sel_outlineView_isItemExpandable_;
public static const objc.SEL sel_outlineView_numberOfChildrenOfItem_;
public static const objc.SEL sel_outlineView_objectValueForTableColumn_byItem_;
public static const objc.SEL sel_outlineView_setObjectValue_forTableColumn_byItem_;
public static const objc.SEL sel_outlineView_shouldCollapseItem_;
public static const objc.SEL sel_outlineView_shouldExpandItem_;
public static const objc.SEL sel_outlineView_willDisplayCell_forTableColumn_item_;
public static const objc.SEL sel_outlineViewColumnDidMove_;
public static const objc.SEL sel_outlineViewColumnDidResize_;
public static const objc.SEL sel_outlineViewItemDidExpand_;
public static const objc.SEL sel_outlineViewSelectionDidChange_;
public static const objc.SEL sel_pageDown_;
public static const objc.SEL sel_pageTitle;
public static const objc.SEL sel_pageUp_;
public static const objc.SEL sel_panelConvertFont_;
public static const objc.SEL sel_paperSize;
public static const objc.SEL sel_paragraphs;
public static const objc.SEL sel_paste_;
public static const objc.SEL sel_pasteboard_provideDataForType_;
public static const objc.SEL sel_pasteboardWithName_;
public static const objc.SEL sel_performDragOperation_;
public static const objc.SEL sel_performSelectorOnMainThread_withObject_waitUntilDone_;
public static const objc.SEL sel_pixelsHigh;
public static const objc.SEL sel_pixelsWide;
public static const objc.SEL sel_pointSize;
public static const objc.SEL sel_pointValue;
public static const objc.SEL sel_pointingHandCursor;
public static const objc.SEL sel_popUpContextMenu_withEvent_forView_;
public static const objc.SEL sel_prependTransform_;
public static const objc.SEL sel_preventDefault;
public static const objc.SEL sel_printDocumentView;
public static const objc.SEL sel_printOperationWithPrintInfo_;
public static const objc.SEL sel_printOperationWithView_printInfo_;
public static const objc.SEL sel_printPanel;
public static const objc.SEL sel_printer;
public static const objc.SEL sel_printerNames;
public static const objc.SEL sel_printerWithName_;
public static const objc.SEL sel_propertyListForType_;
public static const objc.SEL sel_rangeValue;
public static const objc.SEL sel_recentSearches;
public static const objc.SEL sel_rectOfColumn_;
public static const objc.SEL sel_rectOfRow_;
public static const objc.SEL sel_redComponent;
public static const objc.SEL sel_reflectScrolledClipView_;
public static const objc.SEL sel_registerForDraggedTypes_;
public static const objc.SEL sel_release;
public static const objc.SEL sel_reload_;
public static const objc.SEL sel_reloadData;
public static const objc.SEL sel_reloadItem_;
public static const objc.SEL sel_reloadItem_reloadChildren_;
public static const objc.SEL sel_removeAllItems;
public static const objc.SEL sel_removeAllPoints;
public static const objc.SEL sel_removeFromSuperview;
public static const objc.SEL sel_removeItem_;
public static const objc.SEL sel_removeItemAtIndex_;
public static const objc.SEL sel_removeItemAtPath_error_;
public static const objc.SEL sel_removeObject_;
public static const objc.SEL sel_removeObjectAtIndex_;
public static const objc.SEL sel_removeObserver_;
public static const objc.SEL sel_removeStatusItem_;
public static const objc.SEL sel_removeTabViewItem_;
public static const objc.SEL sel_removeTableColumn_;
public static const objc.SEL sel_removeTemporaryAttribute_forCharacterRange_;
public static const objc.SEL sel_replaceCharactersInRange_withString_;
public static const objc.SEL sel_representation;
public static const objc.SEL sel_request;
public static const objc.SEL sel_requestWithURL_;
public static const objc.SEL sel_resignFirstResponder;
public static const objc.SEL sel_resizeDownCursor;
public static const objc.SEL sel_resizeLeftCursor;
public static const objc.SEL sel_resizeLeftRightCursor;
public static const objc.SEL sel_resizeRightCursor;
public static const objc.SEL sel_resizeUpCursor;
public static const objc.SEL sel_resizeUpDownCursor;
public static const objc.SEL sel_resizingMask;
public static const objc.SEL sel_respondsToSelector_;
public static const objc.SEL sel_restoreGraphicsState;
public static const objc.SEL sel_retain;
public static const objc.SEL sel_retainCount;
public static const objc.SEL sel_rightMouseDown_;
public static const objc.SEL sel_rightMouseDragged_;
public static const objc.SEL sel_rightMouseUp_;
public static const objc.SEL sel_rotateByDegrees_;
public static const objc.SEL sel_rowAtPoint_;
public static const objc.SEL sel_rowForItem_;
public static const objc.SEL sel_rowHeight;
public static const objc.SEL sel_rowsInRect_;
public static const objc.SEL sel_run;
public static const objc.SEL sel_runModal;
public static const objc.SEL sel_runModalForWindow_;
public static const objc.SEL sel_runModalWithPrintInfo_;
public static const objc.SEL sel_runMode_beforeDate_;
public static const objc.SEL sel_runOperation;
public static const objc.SEL sel_samplesPerPixel;
public static const objc.SEL sel_saveGraphicsState;
public static const objc.SEL sel_savePanel;
public static const objc.SEL sel_scaleXBy_yBy_;
public static const objc.SEL sel_scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_;
public static const objc.SEL sel_screen;
public static const objc.SEL sel_screens;
public static const objc.SEL sel_scrollColumnToVisible_;
public static const objc.SEL sel_scrollRangeToVisible_;
public static const objc.SEL sel_scrollRectToVisible_;
public static const objc.SEL sel_scrollRowToVisible_;
public static const objc.SEL sel_scrollToPoint_;
public static const objc.SEL sel_scrollWheel_;
public static const objc.SEL sel_scrollerWidth;
public static const objc.SEL sel_secondOfMinute;
public static const objc.SEL sel_secondarySelectedControlColor;
public static const objc.SEL sel_selectAll_;
public static const objc.SEL sel_selectItem_;
public static const objc.SEL sel_selectItemAtIndex_;
public static const objc.SEL sel_selectRow_byExtendingSelection_;
public static const objc.SEL sel_selectRowIndexes_byExtendingSelection_;
public static const objc.SEL sel_selectTabViewItemAtIndex_;
public static const objc.SEL sel_selectedControlTextColor;
public static const objc.SEL sel_selectedRange;
public static const objc.SEL sel_selectedRow;
public static const objc.SEL sel_selectedRowIndexes;
public static const objc.SEL sel_selectedTabViewItem;
public static const objc.SEL sel_selectedTextBackgroundColor;
public static const objc.SEL sel_selectedTextColor;
public static const objc.SEL sel_sendAction_to_;
public static const objc.SEL sel_sendEvent_;
public static const objc.SEL sel_separatorItem;
public static const objc.SEL sel_set;
public static const objc.SEL sel_setAcceptsMouseMovedEvents_;
public static const objc.SEL sel_setAction_;
public static const objc.SEL sel_setAlertStyle_;
public static const objc.SEL sel_setAlignment_;
public static const objc.SEL sel_setAllowsColumnReordering_;
public static const objc.SEL sel_setAllowsFloats_;
public static const objc.SEL sel_setAllowsMixedState_;
public static const objc.SEL sel_setAllowsMultipleSelection_;
public static const objc.SEL sel_setAlphaValue_;
public static const objc.SEL sel_setApplicationIconImage_;
public static const objc.SEL sel_setApplicationNameForUserAgent_;
public static const objc.SEL sel_setAttributedStringValue_;
public static const objc.SEL sel_setAttributedTitle_;
public static const objc.SEL sel_setAutoenablesItems_;
public static const objc.SEL sel_setAutohidesScrollers_;
public static const objc.SEL sel_setAutoresizesOutlineColumn_;
public static const objc.SEL sel_setAutoresizesSubviews_;
public static const objc.SEL sel_setAutoresizingMask_;
public static const objc.SEL sel_setAutosaveExpandedItems_;
public static const objc.SEL sel_setBackgroundColor_;
public static const objc.SEL sel_setBezelStyle_;
public static const objc.SEL sel_setBorderType_;
public static const objc.SEL sel_setBorderWidth_;
public static const objc.SEL sel_setBordered_;
public static const objc.SEL sel_setBoxType_;
public static const objc.SEL sel_setButtonType_;
public static const objc.SEL sel_setCacheMode_;
public static const objc.SEL sel_setCanChooseDirectories_;
public static const objc.SEL sel_setCanChooseFiles_;
public static const objc.SEL sel_setCellClass_;
public static const objc.SEL sel_setClip;
public static const objc.SEL sel_setColor_;
public static const objc.SEL sel_setColumnAutoresizingStyle_;
public static const objc.SEL sel_setCompositingOperation_;
public static const objc.SEL sel_setContainerSize_;
public static const objc.SEL sel_setContentView_;
public static const objc.SEL sel_setContentViewMargins_;
public static const objc.SEL sel_setCurrentContext_;
public static const objc.SEL sel_setCurrentOperation_;
public static const objc.SEL sel_setData_forType_;
public static const objc.SEL sel_setDataCell_;
public static const objc.SEL sel_setDataSource_;
public static const objc.SEL sel_setDatePickerElements_;
public static const objc.SEL sel_setDatePickerStyle_;
public static const objc.SEL sel_setDateValue_;
public static const objc.SEL sel_setDefaultFlatness_;
public static const objc.SEL sel_setDefaultTabInterval_;
public static const objc.SEL sel_setDelegate_;
public static const objc.SEL sel_setDestination_allowOverwrite_;
public static const objc.SEL sel_setDirectory_;
public static const objc.SEL sel_setDocumentView_;
public static const objc.SEL sel_setDoubleAction_;
public static const objc.SEL sel_setDoubleValue_;
public static const objc.SEL sel_setDownloadDelegate_;
public static const objc.SEL sel_setDrawsBackground_;
public static const objc.SEL sel_setEditable_;
public static const objc.SEL sel_setEnabled_;
public static const objc.SEL sel_setFill;
public static const objc.SEL sel_setFireDate_;
public static const objc.SEL sel_setFirstLineHeadIndent_;
public static const objc.SEL sel_setFloatValue_knobProportion_;
public static const objc.SEL sel_setFocusRingType_;
public static const objc.SEL sel_setFont_;
public static const objc.SEL sel_setFormatter_;
public static const objc.SEL sel_setFrame_;
public static const objc.SEL sel_setFrame_display_;
public static const objc.SEL sel_setFrameLoadDelegate_;
public static const objc.SEL sel_setFrameOrigin_;
public static const objc.SEL sel_setFrameSize_;
public static const objc.SEL sel_setHasHorizontalScroller_;
public static const objc.SEL sel_setHasShadow_;
public static const objc.SEL sel_setHasVerticalScroller_;
public static const objc.SEL sel_setHeaderCell_;
public static const objc.SEL sel_setHeaderView_;
public static const objc.SEL sel_setHidden_;
public static const objc.SEL sel_setHiddenUntilMouseMoves_;
public static const objc.SEL sel_setHighlightMode_;
public static const objc.SEL sel_setHighlighted_;
public static const objc.SEL sel_setHorizontalScroller_;
public static const objc.SEL sel_setHorizontallyResizable_;
public static const objc.SEL sel_setIdentifier_;
public static const objc.SEL sel_setImage_;
public static const objc.SEL sel_setImageAlignment_;
public static const objc.SEL sel_setImageInterpolation_;
public static const objc.SEL sel_setImagePosition_;
public static const objc.SEL sel_setImageScaling_;
public static const objc.SEL sel_setIncrement_;
public static const objc.SEL sel_setIndentationPerLevel_;
public static const objc.SEL sel_setIndeterminate_;
public static const objc.SEL sel_setJavaEnabled_;
public static const objc.SEL sel_setJobDisposition_;
public static const objc.SEL sel_setJobTitle_;
public static const objc.SEL sel_setKeyEquivalent_;
public static const objc.SEL sel_setKeyEquivalentModifierMask_;
public static const objc.SEL sel_setLabel_;
public static const objc.SEL sel_setLeaf_;
public static const objc.SEL sel_setLength_;
public static const objc.SEL sel_setLevel_;
public static const objc.SEL sel_setLineBreakMode_;
public static const objc.SEL sel_setLineCapStyle_;
public static const objc.SEL sel_setLineDash_count_phase_;
public static const objc.SEL sel_setLineFragmentPadding_;
public static const objc.SEL sel_setLineFragmentRect_forGlyphRange_usedRect_;
public static const objc.SEL sel_setLineJoinStyle_;
public static const objc.SEL sel_setLineSpacing_;
public static const objc.SEL sel_setLineWidth_;
public static const objc.SEL sel_setMarkedText_selectedRange_;
public static const objc.SEL sel_setMaxSize_;
public static const objc.SEL sel_setMaxValue_;
public static const objc.SEL sel_setMaximum_;
public static const objc.SEL sel_setMaximumFractionDigits_;
public static const objc.SEL sel_setMaximumIntegerDigits_;
public static const objc.SEL sel_setMenu_;
public static const objc.SEL sel_setMinSize_;
public static const objc.SEL sel_setMinValue_;
public static const objc.SEL sel_setMinWidth_;
public static const objc.SEL sel_setMinimum_;
public static const objc.SEL sel_setMinimumFractionDigits_;
public static const objc.SEL sel_setMinimumIntegerDigits_;
public static const objc.SEL sel_setMiterLimit_;
public static const objc.SEL sel_setNeedsDisplay_;
public static const objc.SEL sel_setNeedsDisplayInRect_;
public static const objc.SEL sel_setNumberOfVisibleItems_;
public static const objc.SEL sel_setNumberStyle_;
public static const objc.SEL sel_setObject_forKey_;
public static const objc.SEL sel_setOnMouseEntered_;
public static const objc.SEL sel_setOpaque_;
public static const objc.SEL sel_setOptions_;
public static const objc.SEL sel_setOutlineTableColumn_;
public static const objc.SEL sel_setPanelFont_isMultiple_;
public static const objc.SEL sel_setPartialStringValidationEnabled_;
public static const objc.SEL sel_setPatternPhase_;
public static const objc.SEL sel_setPixelFormat_;
public static const objc.SEL sel_setPolicyDelegate_;
public static const objc.SEL sel_setPrinter_;
public static const objc.SEL sel_setPropertyList_forType_;
public static const objc.SEL sel_setPullsDown_;
public static const objc.SEL sel_setReleasedWhenClosed_;
public static const objc.SEL sel_setResizingMask_;
public static const objc.SEL sel_setResourceLoadDelegate_;
public static const objc.SEL sel_setRichText_;
public static const objc.SEL sel_setRowHeight_;
public static const objc.SEL sel_setSelectable_;
public static const objc.SEL sel_setSelectedRange_;
public static const objc.SEL sel_setShouldAntialias_;
public static const objc.SEL sel_setShowsPrintPanel_;
public static const objc.SEL sel_setShowsProgressPanel_;
public static const objc.SEL sel_setSize_;
public static const objc.SEL sel_setState_;
public static const objc.SEL sel_setString_;
public static const objc.SEL sel_setString_forType_;
public static const objc.SEL sel_setStringValue_;
public static const objc.SEL sel_setStroke;
public static const objc.SEL sel_setSubmenu_;
public static const objc.SEL sel_setTabStops_;
public static const objc.SEL sel_setTabViewType_;
public static const objc.SEL sel_setTarget_;
public static const objc.SEL sel_setTextColor_;
public static const objc.SEL sel_setTitle_;
public static const objc.SEL sel_setTitleFont_;
public static const objc.SEL sel_setTitlePosition_;
public static const objc.SEL sel_setToolTip_;
public static const objc.SEL sel_setTransformStruct_;
public static const objc.SEL sel_setUIDelegate_;
public static const objc.SEL sel_setURL_;
public static const objc.SEL sel_setUpPrintOperationDefaultValues;
public static const objc.SEL sel_setUsesAlternatingRowBackgroundColors_;
public static const objc.SEL sel_setUsesThreadedAnimation_;
public static const objc.SEL sel_setValue_forKey_;
public static const objc.SEL sel_setValueWraps_;
public static const objc.SEL sel_setVerticalScroller_;
public static const objc.SEL sel_setView_;
public static const objc.SEL sel_setWidth_;
public static const objc.SEL sel_setWidthTracksTextView_;
public static const objc.SEL sel_setWindingRule_;
public static const objc.SEL sel_setWorksWhenModal_;
public static const objc.SEL sel_setWraps_;
public static const objc.SEL sel_sharedApplication;
public static const objc.SEL sel_sharedColorPanel;
public static const objc.SEL sel_sharedFontManager;
public static const objc.SEL sel_sharedFontPanel;
public static const objc.SEL sel_sharedHTTPCookieStorage;
public static const objc.SEL sel_sharedPrintInfo;
public static const objc.SEL sel_sharedWorkspace;
public static const objc.SEL sel_shiftKey;
public static const objc.SEL sel_size;
public static const objc.SEL sel_sizeToFit;
public static const objc.SEL sel_sizeValue;
public static const objc.SEL sel_skipDescendents;
public static const objc.SEL sel_smallSystemFontSize;
public static const objc.SEL sel_sortIndicatorRectForBounds_;
public static const objc.SEL sel_standardPreferences;
public static const objc.SEL sel_startAnimation_;
public static const objc.SEL sel_state;
public static const objc.SEL sel_statusItemWithLength_;
public static const objc.SEL sel_stop_;
public static const objc.SEL sel_stopLoading_;
public static const objc.SEL sel_string;
public static const objc.SEL sel_stringByAddingPercentEscapesUsingEncoding_;
public static const objc.SEL sel_stringByAppendingPathComponent_;
public static const objc.SEL sel_stringByAppendingString_;
public static const objc.SEL sel_stringByDeletingLastPathComponent;
public static const objc.SEL sel_stringByDeletingPathExtension;
public static const objc.SEL sel_stringByEvaluatingJavaScriptFromString_;
public static const objc.SEL sel_stringByReplacingOccurrencesOfString_withString_;
public static const objc.SEL sel_stringForObjectValue_;
public static const objc.SEL sel_stringForType_;
public static const objc.SEL sel_stringValue;
public static const objc.SEL sel_stringWithCharacters_length_;
public static const objc.SEL sel_stringWithUTF8String_;
public static const objc.SEL sel_stroke;
public static const objc.SEL sel_strokeRect_;
public static const objc.SEL sel_styleMask;
public static const objc.SEL sel_submenu;
public static const objc.SEL sel_subviews;
public static const objc.SEL sel_superclass;
public static const objc.SEL sel_superview;
public static const objc.SEL sel_systemFontOfSize_;
public static const objc.SEL sel_systemFontSize;
public static const objc.SEL sel_systemFontSizeForControlSize_;
public static const objc.SEL sel_systemStatusBar;
public static const objc.SEL sel_systemVersion;
public static const objc.SEL sel_tabStopType;
public static const objc.SEL sel_tabStops;
public static const objc.SEL sel_tabView_didSelectTabViewItem_;
public static const objc.SEL sel_tabView_willSelectTabViewItem_;
public static const objc.SEL sel_tabViewItemAtPoint_;
public static const objc.SEL sel_tableColumns;
public static const objc.SEL sel_tableView_didClickTableColumn_;
public static const objc.SEL sel_tableView_objectValueForTableColumn_row_;
public static const objc.SEL sel_tableView_setObjectValue_forTableColumn_row_;
public static const objc.SEL sel_tableView_shouldEditTableColumn_row_;
public static const objc.SEL sel_tableView_willDisplayCell_forTableColumn_row_;
public static const objc.SEL sel_tableViewColumnDidMove_;
public static const objc.SEL sel_tableViewColumnDidResize_;
public static const objc.SEL sel_tableViewSelectionDidChange_;
public static const objc.SEL sel_target;
public static const objc.SEL sel_terminate_;
public static const objc.SEL sel_textBackgroundColor;
public static const objc.SEL sel_textColor;
public static const objc.SEL sel_textContainer;
public static const objc.SEL sel_textDidChange_;
public static const objc.SEL sel_textStorage;
public static const objc.SEL sel_textView_clickedOnLink_atIndex_;
public static const objc.SEL sel_textView_willChangeSelectionFromCharacterRange_toCharacterRange_;
public static const objc.SEL sel_textViewDidChangeSelection_;
public static const objc.SEL sel_threadDictionary;
public static const objc.SEL sel_tile;
public static const objc.SEL sel_timeZone;
public static const objc.SEL sel_title;
public static const objc.SEL sel_titleCell;
public static const objc.SEL sel_titleOfSelectedItem;
public static const objc.SEL sel_titleRectForBounds_;
public static const objc.SEL sel_transform;
public static const objc.SEL sel_transformPoint_;
public static const objc.SEL sel_transformSize_;
public static const objc.SEL sel_transformStruct;
public static const objc.SEL sel_transformUsingAffineTransform_;
public static const objc.SEL sel_translateXBy_yBy_;
public static const objc.SEL sel_type;
public static const objc.SEL sel_types;
public static const objc.SEL sel_typesetter;
public static const objc.SEL sel_unarchiveObjectWithData_;
public static const objc.SEL sel_unhideAllApplications_;
public static const objc.SEL sel_unmarkText;
public static const objc.SEL sel_unregisterDraggedTypes;
public static const objc.SEL sel_use;
public static const objc.SEL sel_usedRectForTextContainer_;
public static const objc.SEL sel_userInfo;
public static const objc.SEL sel_usesAlternatingRowBackgroundColors;
public static const objc.SEL sel_validAttributesForMarkedText;
public static const objc.SEL sel_valueForKey_;
public static const objc.SEL sel_valueWithPoint_;
public static const objc.SEL sel_valueWithRange_;
public static const objc.SEL sel_valueWithRect_;
public static const objc.SEL sel_valueWithSize_;
public static const objc.SEL sel_visibleFrame;
public static const objc.SEL sel_visibleRect;
public static const objc.SEL sel_wantsPeriodicDraggingUpdates;
public static const objc.SEL sel_wantsToHandleMouseEvents;
public static const objc.SEL sel_webFrame;
public static const objc.SEL sel_webView_contextMenuItemsForElement_defaultMenuItems_;
public static const objc.SEL sel_webView_createWebViewWithRequest_;
public static const objc.SEL sel_webView_decidePolicyForMIMEType_request_frame_decisionListener_;
public static const objc.SEL sel_webView_decidePolicyForNavigationAction_request_frame_decisionListener_;
public static const objc.SEL sel_webView_decidePolicyForNewWindowAction_request_newFrameName_decisionListener_;
public static const objc.SEL sel_webView_didChangeLocationWithinPageForFrame_;
public static const objc.SEL sel_webView_didCommitLoadForFrame_;
public static const objc.SEL sel_webView_didFailProvisionalLoadWithError_forFrame_;
public static const objc.SEL sel_webView_didFinishLoadForFrame_;
public static const objc.SEL sel_webView_didReceiveTitle_forFrame_;
public static const objc.SEL sel_webView_didStartProvisionalLoadForFrame_;
public static const objc.SEL sel_webView_identifierForInitialRequest_fromDataSource_;
public static const objc.SEL sel_webView_mouseDidMoveOverElement_modifierFlags_;
public static const objc.SEL sel_webView_printFrameView_;
public static const objc.SEL sel_webView_resource_didFailLoadingWithError_fromDataSource_;
public static const objc.SEL sel_webView_resource_didFinishLoadingFromDataSource_;
public static const objc.SEL sel_webView_resource_willSendRequest_redirectResponse_fromDataSource_;
public static const objc.SEL sel_webView_runJavaScriptAlertPanelWithMessage_;
public static const objc.SEL sel_webView_runJavaScriptConfirmPanelWithMessage_;
public static const objc.SEL sel_webView_runOpenPanelForFileButtonWithResultListener_;
public static const objc.SEL sel_webView_setFrame_;
public static const objc.SEL sel_webView_setResizable_;
public static const objc.SEL sel_webView_setStatusBarVisible_;
public static const objc.SEL sel_webView_setStatusText_;
public static const objc.SEL sel_webView_setToolbarsVisible_;
public static const objc.SEL sel_webView_unableToImplementPolicyWithError_frame_;
public static const objc.SEL sel_webViewClose_;
public static const objc.SEL sel_webViewFocus_;
public static const objc.SEL sel_webViewShow_;
public static const objc.SEL sel_webViewUnfocus_;
public static const objc.SEL sel_wheelDelta;
public static const objc.SEL sel_width;
public static const objc.SEL sel_window;
public static const objc.SEL sel_windowBackgroundColor;
public static const objc.SEL sel_windowDidBecomeKey_;
public static const objc.SEL sel_windowDidMove_;
public static const objc.SEL sel_windowDidResignKey_;
public static const objc.SEL sel_windowDidResize_;
public static const objc.SEL sel_windowFrameColor;
public static const objc.SEL sel_windowFrameTextColor;
public static const objc.SEL sel_windowNumber;
public static const objc.SEL sel_windowShouldClose_;
public static const objc.SEL sel_windowWillClose_;
public static const objc.SEL sel_windows;
public static const objc.SEL sel_worksWhenModal;
public static const objc.SEL sel_wraps;
public static const objc.SEL sel_writeToPasteboard_;
public static const objc.SEL sel_yearOfCommonEra;

/** Constants */
public static final int NSAWTEventType = 16;
public static final int NSAboveBottom = 4;
public static final int NSAboveTop = 1;
public static final int NSAddTraitFontAction = 2;
public static final int NSAdobeCNS1CharacterCollection = 1;
public static final int NSAdobeGB1CharacterCollection = 2;
public static final int NSAdobeJapan1CharacterCollection = 3;
public static final int NSAdobeJapan2CharacterCollection = 4;
public static final int NSAdobeKorea1CharacterCollection = 5;
public static final int NSAlertAlternateReturn = 0;
public static final int NSAlertDefaultReturn = 1;
public static final int NSAlertErrorReturn = -2;
public static final int NSAlertFirstButtonReturn = 1000;
public static final int NSAlertOtherReturn = -1;
public static final int NSAlertSecondButtonReturn = 1001;
public static final int NSAlertThirdButtonReturn = 1002;
public static final int NSAllScrollerParts = 2;
public static final int NSAlphaFirstBitmapFormat = 1;
public static final int NSAlphaNonpremultipliedBitmapFormat = 2;
public static final int NSAlphaShiftKeyMask = 65536;
public static final int NSAlternateKeyMask = 524288;
public static final int NSAnimationBlocking = 0;
public static final int NSAnimationEaseIn = 1;
public static final int NSAnimationEaseInOut = 0;
public static final int NSAnimationEaseOut = 2;
public static final int NSAnimationEffectDisappearingItemDefault = 0;
public static final int NSAnimationEffectPoof = 10;
public static final int NSAnimationLinear = 3;
public static final int NSAnimationNonblocking = 1;
public static final int NSAnimationNonblockingThreaded = 2;
public static final int NSAnyEventMask = -1;
public static final int NSAnyType = 0;
public static final int NSAppKitDefined = 13;
public static final int NSAppKitDefinedMask = 8192;
public static final int NSAppKitVersionNumber10_0 = 577;
public static final int NSAppKitVersionNumber10_1 = 620;
public static final int NSAppKitVersionNumber10_2 = 663;
public static final double NSAppKitVersionNumber10_2_3 = 663.60000000000002;
public static final int NSAppKitVersionNumber10_3 = 743;
public static final double NSAppKitVersionNumber10_3_2 = 743.13999999999999;
public static final double NSAppKitVersionNumber10_3_3 = 743.20000000000005;
public static final double NSAppKitVersionNumber10_3_5 = 743.24000000000001;
public static final double NSAppKitVersionNumber10_3_7 = 743.33000000000004;
public static final double NSAppKitVersionNumber10_3_9 = 743.36000000000001;
public static final int NSAppKitVersionNumber10_4 = 824;
public static final double NSAppKitVersionNumberWithColumnResizingBrowser = 685.00000000000000;
public static final double NSAppKitVersionNumberWithContinuousScrollingBrowser = 680.00000000000000;
public static final double NSAppKitVersionNumberWithCursorSizeSupport = 682.00000000000000;
public static final double NSAppKitVersionNumberWithCustomSheetPosition = 686.00000000000000;
public static final double NSAppKitVersionNumberWithDirectionalTabs = 631.00000000000000;
public static final double NSAppKitVersionNumberWithPatternColorLeakFix = 641.00000000000000;
public static final int NSApplicationActivatedEventType = 1;
public static final int NSApplicationDeactivatedEventType = 2;
public static final int NSApplicationDefined = 15;
public static final int NSApplicationDefinedMask = 32768;
public static final int NSApplicationDelegateReplyCancel = 1;
public static final int NSApplicationDelegateReplyFailure = 2;
public static final int NSApplicationDelegateReplySuccess = 0;
public static final int NSAscendingPageOrder = 1;
public static final int NSAtBottom = 5;
public static final int NSAtTop = 2;
public static final int NSAttachmentCharacter = 65532;
public static final int NSAutoPagination = 0;
public static final int NSAutosaveOperation = 3;
public static final int NSBMPFileType = 1;
public static final int NSBackTabCharacter = 25;
public static final int NSBackgroundStyleDark = 1;
public static final int NSBackgroundStyleLight = 0;
public static final int NSBackgroundStyleLowered = 3;
public static final int NSBackgroundStyleRaised = 2;
public static final int NSBackgroundTab = 1;
public static final int NSBackingStoreBuffered = 2;
public static final int NSBackingStoreNonretained = 1;
public static final int NSBackingStoreRetained = 0;
public static final int NSBackspaceCharacter = 8;
public static final int NSBacktabTextMovement = 18;
public static final int NSBeginFunctionKey = 63274;
public static final int NSBelowBottom = 6;
public static final int NSBelowTop = 3;
public static final int NSBevelLineJoinStyle = 2;
public static final int NSBezelBorder = 2;
public static final int NSBlueControlTint = 1;
public static final int NSBoldFontMask = 2;
public static final int NSBorderlessWindowMask = 0;
public static final int NSBottomTabsBezelBorder = 2;
public static final int NSBoxCustom = 4;
public static final int NSBoxOldStyle = 3;
public static final int NSBoxPrimary = 0;
public static final int NSBoxSecondary = 1;
public static final int NSBoxSeparator = 2;
public static final int NSBreakFunctionKey = 63282;
public static final int NSBrowserAutoColumnResizing = 1;
public static final int NSBrowserDropAbove = 1;
public static final int NSBrowserDropOn = 0;
public static final int NSBrowserNoColumnResizing = 0;
public static final int NSBrowserUserColumnResizing = 2;
public static final int NSButtLineCapStyle = 0;
public static final int NSCMYKColorSpaceModel = 2;
public static final int NSCMYKModeColorPanel = 2;
public static final int NSCancelButton = 0;
public static final int NSCancelTextMovement = 23;
public static final int NSCarriageReturnCharacter = 13;
public static final int NSCellAllowsMixedState = 16;
public static final int NSCellChangesContents = 14;
public static final int NSCellDisabled = 0;
public static final int NSCellEditable = 3;
public static final int NSCellHasImageHorizontal = 12;
public static final int NSCellHasImageOnLeftOrBottom = 13;
public static final int NSCellHasOverlappingImage = 11;
public static final int NSCellHighlighted = 5;
public static final int NSCellHitContentArea = 1;
public static final int NSCellHitEditableTextArea = 2;
public static final int NSCellHitNone = 0;
public static final int NSCellHitTrackableArea = 4;
public static final int NSCellIsBordered = 10;
public static final int NSCellIsInsetButton = 15;
public static final int NSCellLightsByBackground = 9;
public static final int NSCellLightsByContents = 6;
public static final int NSCellLightsByGray = 7;
public static final int NSCellState = 1;
public static final int NSCenterTabStopType = 2;
public static final int NSCenterTextAlignment = 2;
public static final int NSChangeAutosaved = 4;
public static final int NSChangeBackgroundCell = 8;
public static final int NSChangeBackgroundCellMask = 8;
public static final int NSChangeCleared = 2;
public static final int NSChangeDone = 0;
public static final int NSChangeGrayCell = 4;
public static final int NSChangeGrayCellMask = 4;
public static final int NSChangeReadOtherContents = 3;
public static final int NSChangeRedone = 5;
public static final int NSChangeUndone = 1;
public static final int NSCircularBezelStyle = 7;
public static final int NSCircularSlider = 1;
public static final int NSClearControlTint = 7;
public static final int NSClearDisplayFunctionKey = 63290;
public static final int NSClearLineFunctionKey = 63289;
public static final int NSClipPagination = 2;
public static final int NSClockAndCalendarDatePickerStyle = 1;
public static final int NSClosableWindowMask = 2;
public static final int NSClosePathBezierPathElement = 3;
public static final int NSColorListModeColorPanel = 5;
public static final int NSColorPanelAllModesMask = 65535;
public static final int NSColorPanelCMYKModeMask = 4;
public static final int NSColorPanelColorListModeMask = 32;
public static final int NSColorPanelCrayonModeMask = 128;
public static final int NSColorPanelCustomPaletteModeMask = 16;
public static final int NSColorPanelGrayModeMask = 1;
public static final int NSColorPanelHSBModeMask = 8;
public static final int NSColorPanelRGBModeMask = 2;
public static final int NSColorPanelWheelModeMask = 64;
public static final int NSColorRenderingIntentAbsoluteColorimetric = 1;
public static final int NSColorRenderingIntentDefault = 0;
public static final int NSColorRenderingIntentPerceptual = 3;
public static final int NSColorRenderingIntentRelativeColorimetric = 2;
public static final int NSColorRenderingIntentSaturation = 4;
public static final int NSCommandKeyMask = 1048576;
public static final int NSCompositeClear = 0;
public static final int NSCompositeCopy = 1;
public static final int NSCompositeDestinationAtop = 9;
public static final int NSCompositeDestinationIn = 7;
public static final int NSCompositeDestinationOut = 8;
public static final int NSCompositeDestinationOver = 6;
public static final int NSCompositeHighlight = 12;
public static final int NSCompositePlusDarker = 11;
public static final int NSCompositePlusLighter = 13;
public static final int NSCompositeSourceAtop = 5;
public static final int NSCompositeSourceIn = 3;
public static final int NSCompositeSourceOut = 4;
public static final int NSCompositeSourceOver = 2;
public static final int NSCompositeXOR = 10;
public static final int NSCompressedFontMask = 512;
public static final int NSCondensedFontMask = 64;
public static final int NSContentsCellMask = 1;
public static final int NSContinuousCapacityLevelIndicatorStyle = 1;
public static final int NSControlGlyph = 16777215;
public static final int NSControlKeyMask = 262144;
public static final int NSCrayonModeColorPanel = 7;
public static final int NSCriticalAlertStyle = 2;
public static final int NSCriticalRequest = 0;
public static final int NSCursorPointingDevice = 2;
public static final int NSCursorUpdate = 17;
public static final int NSCursorUpdateMask = 131072;
public static final int NSCurveToBezierPathElement = 2;
public static final int NSCustomPaletteModeColorPanel = 4;
public static final int NSDecimalTabStopType = 3;
public static final int NSDefaultControlTint = 0;
public static final int NSDefaultTokenStyle = 0;
public static final int NSDeleteCharFunctionKey = 63294;
public static final int NSDeleteCharacter = 127;
public static final int NSDeleteFunctionKey = 63272;
public static final int NSDeleteLineFunctionKey = 63292;
public static final int NSDescendingPageOrder = -1;
public static final int NSDeviceIndependentModifierFlagsMask = -65536;
public static final int NSDeviceNColorSpaceModel = 4;
public static final int NSDirectSelection = 0;
public static final int NSDisclosureBezelStyle = 5;
public static final int NSDiscreteCapacityLevelIndicatorStyle = 2;
public static final int NSDisplayWindowRunLoopOrdering = 600000;
public static final int NSDocModalWindowMask = 64;
public static final int NSDockWindowLevel = 20;
public static final int NSDoubleType = 6;
public static final int NSDownArrowFunctionKey = 63233;
public static final int NSDownTextMovement = 22;
public static final int NSDragOperationAll = 15;
public static final int NSDragOperationAll_Obsolete = 15;
public static final int NSDragOperationCopy = 1;
public static final int NSDragOperationDelete = 32;
public static final int NSDragOperationEvery = -1;
public static final int NSDragOperationGeneric = 4;
public static final int NSDragOperationLink = 2;
public static final int NSDragOperationMove = 16;
public static final int NSDragOperationNone = 0;
public static final int NSDragOperationPrivate = 8;
public static final int NSDrawerClosedState = 0;
public static final int NSDrawerClosingState = 3;
public static final int NSDrawerOpenState = 2;
public static final int NSDrawerOpeningState = 1;
public static final int NSEndFunctionKey = 63275;
public static final int NSEnterCharacter = 3;
public static final int NSEraDatePickerElementFlag = 256;
public static final int NSEraserPointingDevice = 3;
public static final int NSEvenOddWindingRule = 1;
public static final int NSExclude10_4ElementsIconCreationOption = 4;
public static final int NSExcludeQuickDrawElementsIconCreationOption = 2;
public static final int NSExecuteFunctionKey = 63298;
public static final int NSExpandedFontMask = 32;
public static final int NSF10FunctionKey = 63245;
public static final int NSF11FunctionKey = 63246;
public static final int NSF12FunctionKey = 63247;
public static final int NSF13FunctionKey = 63248;
public static final int NSF14FunctionKey = 63249;
public static final int NSF15FunctionKey = 63250;
public static final int NSF16FunctionKey = 63251;
public static final int NSF17FunctionKey = 63252;
public static final int NSF18FunctionKey = 63253;
public static final int NSF19FunctionKey = 63254;
public static final int NSF1FunctionKey = 63236;
public static final int NSF20FunctionKey = 63255;
public static final int NSF21FunctionKey = 63256;
public static final int NSF22FunctionKey = 63257;
public static final int NSF23FunctionKey = 63258;
public static final int NSF24FunctionKey = 63259;
public static final int NSF25FunctionKey = 63260;
public static final int NSF26FunctionKey = 63261;
public static final int NSF27FunctionKey = 63262;
public static final int NSF28FunctionKey = 63263;
public static final int NSF29FunctionKey = 63264;
public static final int NSF2FunctionKey = 63237;
public static final int NSF30FunctionKey = 63265;
public static final int NSF31FunctionKey = 63266;
public static final int NSF32FunctionKey = 63267;
public static final int NSF33FunctionKey = 63268;
public static final int NSF34FunctionKey = 63269;
public static final int NSF35FunctionKey = 63270;
public static final int NSF3FunctionKey = 63238;
public static final int NSF4FunctionKey = 63239;
public static final int NSF5FunctionKey = 63240;
public static final int NSF6FunctionKey = 63241;
public static final int NSF7FunctionKey = 63242;
public static final int NSF8FunctionKey = 63243;
public static final int NSF9FunctionKey = 63244;
public static final int NSFPCurrentField = 134;
public static final int NSFPPreviewButton = 131;
public static final int NSFPPreviewField = 128;
public static final int NSFPRevertButton = 130;
public static final int NSFPSetButton = 132;
public static final int NSFPSizeField = 129;
public static final int NSFPSizeTitle = 133;
public static final int NSFileHandlingPanelCancelButton = 0;
public static final int NSFileHandlingPanelOKButton = 1;
public static final int NSFindFunctionKey = 63301;
public static final int NSFindPanelActionNext = 2;
public static final int NSFindPanelActionPrevious = 3;
public static final int NSFindPanelActionReplace = 5;
public static final int NSFindPanelActionReplaceAll = 4;
public static final int NSFindPanelActionReplaceAllInSelection = 8;
public static final int NSFindPanelActionReplaceAndFind = 6;
public static final int NSFindPanelActionSelectAll = 9;
public static final int NSFindPanelActionSelectAllInSelection = 10;
public static final int NSFindPanelActionSetFindString = 7;
public static final int NSFindPanelActionShowFindPanel = 1;
public static final int NSFindPanelSubstringMatchTypeContains = 0;
public static final int NSFindPanelSubstringMatchTypeEndsWith = 3;
public static final int NSFindPanelSubstringMatchTypeFullWord = 2;
public static final int NSFindPanelSubstringMatchTypeStartsWith = 1;
public static final int NSFitPagination = 1;
public static final int NSFixedPitchFontMask = 1024;
public static final int NSFlagsChanged = 12;
public static final int NSFlagsChangedMask = 4096;
public static final int NSFloatType = 3;
public static final int NSFloatingPointSamplesBitmapFormat = 4;
public static final int NSFloatingWindowLevel = 3;
public static final int NSFocusRingAbove = 2;
public static final int NSFocusRingBelow = 1;
public static final int NSFocusRingOnly = 0;
public static final int NSFocusRingTypeDefault = 0;
public static final int NSFocusRingTypeExterior = 2;
public static final int NSFocusRingTypeNone = 1;
public static final int NSFontAntialiasedIntegerAdvancementsRenderingMode = 3;
public static final int NSFontAntialiasedRenderingMode = 1;
public static final int NSFontBoldTrait = 2;
public static final int NSFontClarendonSerifsClass = 1073741824;
public static final int NSFontCollectionApplicationOnlyMask = 1;
public static final int NSFontCondensedTrait = 64;
public static final int NSFontDefaultRenderingMode = 0;
public static final int NSFontExpandedTrait = 32;
public static final int NSFontFamilyClassMask = -268435456;
public static final int NSFontFreeformSerifsClass = 1879048192;
public static final int NSFontIntegerAdvancementsRenderingMode = 2;
public static final int NSFontItalicTrait = 1;
public static final int NSFontModernSerifsClass = 805306368;
public static final int NSFontMonoSpaceTrait = 1024;
public static final int NSFontOldStyleSerifsClass = 268435456;
public static final int NSFontOrnamentalsClass = -1879048192;
public static final int NSFontPanelAllEffectsModeMask = 1048320;
public static final int NSFontPanelAllModesMask = -1;
public static final int NSFontPanelCollectionModeMask = 4;
public static final int NSFontPanelDocumentColorEffectModeMask = 2048;
public static final int NSFontPanelFaceModeMask = 1;
public static final int NSFontPanelShadowEffectModeMask = 4096;
public static final int NSFontPanelSizeModeMask = 2;
public static final int NSFontPanelStandardModesMask = 65535;
public static final int NSFontPanelStrikethroughEffectModeMask = 512;
public static final int NSFontPanelTextColorEffectModeMask = 1024;
public static final int NSFontPanelUnderlineEffectModeMask = 256;
public static final int NSFontSansSerifClass = -2147483648;
public static final int NSFontScriptsClass = -1610612736;
public static final int NSFontSlabSerifsClass = 1342177280;
public static final int NSFontSymbolicClass = -1073741824;
public static final int NSFontTransitionalSerifsClass = 536870912;
public static final int NSFontUIOptimizedTrait = 4096;
public static final int NSFontUnknownClass = 0;
public static final int NSFontVerticalTrait = 2048;
public static final int NSFormFeedCharacter = 12;
public static final int NSFunctionKeyMask = 8388608;
public static final int NSGIFFileType = 2;
public static final int NSGlyphAttributeBidiLevel = 2;
public static final int NSGlyphAttributeElastic = 1;
public static final int NSGlyphAttributeInscribe = 5;
public static final int NSGlyphAttributeSoft = 0;
public static final int NSGlyphInscribeAbove = 2;
public static final int NSGlyphInscribeBase = 0;
public static final int NSGlyphInscribeBelow = 1;
public static final int NSGlyphInscribeOverBelow = 4;
public static final int NSGlyphInscribeOverstrike = 3;
public static final int NSGradientConcaveStrong = 2;
public static final int NSGradientConcaveWeak = 1;
public static final int NSGradientConvexStrong = 4;
public static final int NSGradientConvexWeak = 3;
public static final int NSGradientDrawsAfterEndingLocation = 2;
public static final int NSGradientDrawsBeforeStartingLocation = 1;
public static final int NSGradientNone = 0;
public static final int NSGraphiteControlTint = 6;
public static final int NSGrayColorSpaceModel = 0;
public static final int NSGrayModeColorPanel = 0;
public static final int NSGrooveBorder = 3;
public static final int NSHSBModeColorPanel = 3;
public static final int NSHUDWindowMask = 8192;
public static final int NSHeavierFontAction = 5;
public static final int NSHelpButtonBezelStyle = 9;
public static final int NSHelpFunctionKey = 63302;
public static final int NSHelpKeyMask = 4194304;
public static final int NSHighlightModeMatrix = 1;
public static final int NSHomeFunctionKey = 63273;
public static final int NSHorizontalRuler = 0;
public static final int NSHourMinuteDatePickerElementFlag = 12;
public static final int NSHourMinuteSecondDatePickerElementFlag = 14;
public static final int NSIdentityMappingCharacterCollection = 0;
public static final int NSIllegalTextMovement = 0;
public static final int NSImageAbove = 5;
public static final int NSImageAlignBottom = 5;
public static final int NSImageAlignBottomLeft = 6;
public static final int NSImageAlignBottomRight = 7;
public static final int NSImageAlignCenter = 0;
public static final int NSImageAlignLeft = 4;
public static final int NSImageAlignRight = 8;
public static final int NSImageAlignTop = 1;
public static final int NSImageAlignTopLeft = 2;
public static final int NSImageAlignTopRight = 3;
public static final int NSImageBelow = 4;
public static final int NSImageCacheAlways = 1;
public static final int NSImageCacheBySize = 2;
public static final int NSImageCacheDefault = 0;
public static final int NSImageCacheNever = 3;
public static final int NSImageCellType = 2;
public static final int NSImageFrameButton = 4;
public static final int NSImageFrameGrayBezel = 2;
public static final int NSImageFrameGroove = 3;
public static final int NSImageFrameNone = 0;
public static final int NSImageFramePhoto = 1;
public static final int NSImageInterpolationDefault = 0;
public static final int NSImageInterpolationHigh = 3;
public static final int NSImageInterpolationLow = 2;
public static final int NSImageInterpolationNone = 1;
public static final int NSImageLeft = 2;
public static final int NSImageLoadStatusCancelled = 1;
public static final int NSImageLoadStatusCompleted = 0;
public static final int NSImageLoadStatusInvalidData = 2;
public static final int NSImageLoadStatusReadError = 4;
public static final int NSImageLoadStatusUnexpectedEOF = 3;
public static final int NSImageOnly = 1;
public static final int NSImageOverlaps = 6;
public static final int NSImageRepLoadStatusCompleted = -6;
public static final int NSImageRepLoadStatusInvalidData = -4;
public static final int NSImageRepLoadStatusReadingHeader = -2;
public static final int NSImageRepLoadStatusUnexpectedEOF = -5;
public static final int NSImageRepLoadStatusUnknownType = -1;
public static final int NSImageRepLoadStatusWillNeedAllData = -3;
public static final int NSImageRepMatchesDevice = 0;
public static final int NSImageRight = 3;
public static final int NSImageScaleAxesIndependently = 1;
public static final int NSImageScaleNone = 2;
public static final int NSImageScaleProportionallyDown = 0;
public static final int NSImageScaleProportionallyUpOrDown = 3;
public static final int NSIndexedColorSpaceModel = 5;
public static final int NSInformationalAlertStyle = 1;
public static final int NSInformationalRequest = 10;
public static final int NSInsertCharFunctionKey = 63293;
public static final int NSInsertFunctionKey = 63271;
public static final int NSInsertLineFunctionKey = 63291;
public static final int NSIntType = 1;
public static final int NSItalicFontMask = 1;
public static final int NSJPEG2000FileType = 5;
public static final int NSJPEGFileType = 3;
public static final int NSJustifiedTextAlignment = 3;
public static final int NSKeyDown = 10;
public static final int NSKeyDownMask = 1024;
public static final int NSKeyUp = 11;
public static final int NSKeyUpMask = 2048;
public static final int NSLABColorSpaceModel = 3;
public static final int NSLandscapeOrientation = 1;
public static final int NSLeftArrowFunctionKey = 63234;
public static final int NSLeftMouseDown = 1;
public static final int NSLeftMouseDownMask = 2;
public static final int NSLeftMouseDragged = 6;
public static final int NSLeftMouseDraggedMask = 64;
public static final int NSLeftMouseUp = 2;
public static final int NSLeftMouseUpMask = 4;
public static final int NSLeftTabStopType = 0;
public static final int NSLeftTabsBezelBorder = 1;
public static final int NSLeftTextAlignment = 0;
public static final int NSLeftTextMovement = 19;
public static final int NSLighterFontAction = 6;
public static final int NSLineBorder = 1;
public static final int NSLineBreakByCharWrapping = 1;
public static final int NSLineBreakByClipping = 2;
public static final int NSLineBreakByTruncatingHead = 3;
public static final int NSLineBreakByTruncatingMiddle = 5;
public static final int NSLineBreakByTruncatingTail = 4;
public static final int NSLineBreakByWordWrapping = 0;
public static final int NSLineDoesntMove = 0;
public static final int NSLineMovesDown = 3;
public static final int NSLineMovesLeft = 1;
public static final int NSLineMovesRight = 2;
public static final int NSLineMovesUp = 4;
public static final int NSLineSeparatorCharacter = 8232;
public static final int NSLineSweepDown = 2;
public static final int NSLineSweepLeft = 0;
public static final int NSLineSweepRight = 1;
public static final int NSLineSweepUp = 3;
public static final int NSLineToBezierPathElement = 1;
public static final int NSLinearSlider = 0;
public static final int NSListModeMatrix = 2;
public static final int NSMacintoshInterfaceStyle = 3;
public static final int NSMainMenuWindowLevel = 24;
public static final int NSMenuFunctionKey = 63285;
public static final int NSMiniControlSize = 2;
public static final int NSMiniaturizableWindowMask = 4;
public static final int NSMiterLineJoinStyle = 0;
public static final int NSMixedState = -1;
public static final int NSModalPanelWindowLevel = 8;
public static final int NSModeSwitchFunctionKey = 63303;
public static final int NSMomentaryChangeButton = 5;
public static final int NSMomentaryLight = 7;
public static final int NSMomentaryLightButton = 0;
public static final int NSMomentaryPushButton = 0;
public static final int NSMomentaryPushInButton = 7;
public static final int NSMouseEntered = 8;
public static final int NSMouseEnteredMask = 256;
public static final int NSMouseEventSubtype = 0;
public static final int NSMouseExited = 9;
public static final int NSMouseExitedMask = 512;
public static final int NSMouseMoved = 5;
public static final int NSMouseMovedMask = 32;
public static final int NSMoveToBezierPathElement = 0;
public static final int NSNarrowFontMask = 16;
public static final int NSNativeShortGlyphPacking = 5;
public static final int NSNaturalTextAlignment = 4;
public static final int NSNewlineCharacter = 10;
public static final int NSNextFunctionKey = 63296;
public static final int NSNextStepInterfaceStyle = 1;
public static final int NSNoBorder = 0;
public static final int NSNoCellMask = 0;
public static final int NSNoFontChangeAction = 0;
public static final int NSNoImage = 0;
public static final int NSNoInterfaceStyle = 0;
public static final int NSNoModeColorPanel = -1;
public static final int NSNoScrollerParts = 0;
public static final int NSNoTabsBezelBorder = 4;
public static final int NSNoTabsLineBorder = 5;
public static final int NSNoTabsNoBorder = 6;
public static final int NSNoTitle = 0;
public static final int NSNoUnderlineStyle = 0;
public static final int NSNonStandardCharacterSetFontMask = 8;
public static final int NSNonZeroWindingRule = 0;
public static final int NSNonactivatingPanelMask = 128;
public static final int NSNormalWindowLevel = 0;
public static final int NSNullCellType = 0;
public static final int NSNullGlyph = 0;
public static final int NSNumericPadKeyMask = 2097152;
public static final int NSOKButton = 1;
public static final int NSOPENGL_CURRENT_VERSION = 1;
public static final int NSOffState = 0;
public static final int NSOnOffButton = 6;
public static final int NSOnState = 1;
public static final int NSOnlyScrollerArrows = 1;
public static final int NSOpenGLCPRasterizationEnable = 221;
public static final int NSOpenGLCPStateValidation = 301;
public static final int NSOpenGLCPSurfaceOpacity = 236;
public static final int NSOpenGLCPSurfaceOrder = 235;
public static final int NSOpenGLCPSwapInterval = 222;
public static final int NSOpenGLCPSwapRectangle = 200;
public static final int NSOpenGLCPSwapRectangleEnable = 201;
public static final int NSOpenGLGOClearFormatCache = 502;
public static final int NSOpenGLGOFormatCacheSize = 501;
public static final int NSOpenGLGOResetLibrary = 504;
public static final int NSOpenGLGORetainRenderers = 503;
public static final int NSOpenGLPFAAccelerated = 73;
public static final int NSOpenGLPFAAccumSize = 14;
public static final int NSOpenGLPFAAllRenderers = 1;
public static final int NSOpenGLPFAAllowOfflineRenderers = 96;
public static final int NSOpenGLPFAAlphaSize = 11;
public static final int NSOpenGLPFAAuxBuffers = 7;
public static final int NSOpenGLPFAAuxDepthStencil = 57;
public static final int NSOpenGLPFABackingStore = 76;
public static final int NSOpenGLPFAClosestPolicy = 74;
public static final int NSOpenGLPFAColorFloat = 58;
public static final int NSOpenGLPFAColorSize = 8;
public static final int NSOpenGLPFACompliant = 83;
public static final int NSOpenGLPFADepthSize = 12;
public static final int NSOpenGLPFADoubleBuffer = 5;
public static final int NSOpenGLPFAFullScreen = 54;
public static final int NSOpenGLPFAMPSafe = 78;
public static final int NSOpenGLPFAMaximumPolicy = 52;
public static final int NSOpenGLPFAMinimumPolicy = 51;
public static final int NSOpenGLPFAMultiScreen = 81;
public static final int NSOpenGLPFAMultisample = 59;
public static final int NSOpenGLPFANoRecovery = 72;
public static final int NSOpenGLPFAOffScreen = 53;
public static final int NSOpenGLPFAPixelBuffer = 90;
public static final int NSOpenGLPFARendererID = 70;
public static final int NSOpenGLPFARobust = 75;
public static final int NSOpenGLPFASampleAlpha = 61;
public static final int NSOpenGLPFASampleBuffers = 55;
public static final int NSOpenGLPFASamples = 56;
public static final int NSOpenGLPFAScreenMask = 84;
public static final int NSOpenGLPFASingleRenderer = 71;
public static final int NSOpenGLPFAStencilSize = 13;
public static final int NSOpenGLPFAStereo = 6;
public static final int NSOpenGLPFASupersample = 60;
public static final int NSOpenGLPFAVirtualScreenCount = 128;
public static final int NSOpenGLPFAWindow = 80;
public static final int NSOtherMouseDown = 25;
public static final int NSOtherMouseDownMask = 33554432;
public static final int NSOtherMouseDragged = 27;
public static final int NSOtherMouseDraggedMask = 134217728;
public static final int NSOtherMouseUp = 26;
public static final int NSOtherMouseUpMask = 67108864;
public static final int NSOtherTextMovement = 0;
public static final int NSOutlineViewDropOnItemIndex = -1;
public static final int NSPNGFileType = 4;
public static final int NSPageDownFunctionKey = 63277;
public static final int NSPageUpFunctionKey = 63276;
public static final int NSParagraphSeparatorCharacter = 8233;
public static final int NSPathStyleNavigationBar = 1;
public static final int NSPathStylePopUp = 2;
public static final int NSPathStyleStandard = 0;
public static final int NSPatternColorSpaceModel = 6;
public static final int NSPauseFunctionKey = 63280;
public static final int NSPenLowerSideMask = 2;
public static final int NSPenPointingDevice = 1;
public static final int NSPenTipMask = 1;
public static final int NSPenUpperSideMask = 4;
public static final int NSPeriodic = 16;
public static final int NSPeriodicMask = 65536;
public static final int NSPlainTextTokenStyle = 1;
public static final int NSPopUpArrowAtBottom = 2;
public static final int NSPopUpArrowAtCenter = 1;
public static final int NSPopUpMenuWindowLevel = 101;
public static final int NSPopUpNoArrow = 0;
public static final int NSPortraitOrientation = 0;
public static final int NSPositiveDoubleType = 7;
public static final int NSPositiveFloatType = 4;
public static final int NSPositiveIntType = 2;
public static final int NSPosterFontMask = 256;
public static final int NSPowerOffEventType = 1;
public static final int NSPressedTab = 2;
public static final int NSPrevFunctionKey = 63295;
public static final int NSPrintFunctionKey = 63288;
public static final int NSPrintPanelShowsCopies = 1;
public static final int NSPrintPanelShowsOrientation = 8;
public static final int NSPrintPanelShowsPageRange = 2;
public static final int NSPrintPanelShowsPageSetupAccessory = 256;
public static final int NSPrintPanelShowsPaperSize = 4;
public static final int NSPrintPanelShowsPreview = 131072;
public static final int NSPrintPanelShowsScaling = 16;
public static final int NSPrintScreenFunctionKey = 63278;
public static final int NSPrinterTableError = 2;
public static final int NSPrinterTableNotFound = 1;
public static final int NSPrinterTableOK = 0;
public static final int NSPrintingCancelled = 0;
public static final int NSPrintingFailure = 3;
public static final int NSPrintingReplyLater = 2;
public static final int NSPrintingSuccess = 1;
public static final int NSProgressIndicatorBarStyle = 0;
public static final int NSProgressIndicatorPreferredAquaThickness = 12;
public static final int NSProgressIndicatorPreferredLargeThickness = 18;
public static final int NSProgressIndicatorPreferredSmallThickness = 10;
public static final int NSProgressIndicatorPreferredThickness = 14;
public static final int NSProgressIndicatorSpinningStyle = 1;
public static final int NSPushInCell = 2;
public static final int NSPushInCellMask = 2;
public static final int NSPushOnPushOffButton = 1;
public static final int NSQTMovieLoopingBackAndForthPlayback = 2;
public static final int NSQTMovieLoopingPlayback = 1;
public static final int NSQTMovieNormalPlayback = 0;
public static final int NSRGBColorSpaceModel = 1;
public static final int NSRGBModeColorPanel = 1;
public static final int NSRadioButton = 4;
public static final int NSRadioModeMatrix = 0;
public static final int NSRangeDateMode = 1;
public static final int NSRatingLevelIndicatorStyle = 3;
public static final int NSRecessedBezelStyle = 13;
public static final int NSRedoFunctionKey = 63300;
public static final int NSRegularControlSize = 0;
public static final int NSRegularSquareBezelStyle = 2;
public static final int NSRelevancyLevelIndicatorStyle = 0;
public static final int NSRemoveTraitFontAction = 7;
public static final int NSResetCursorRectsRunLoopOrdering = 700000;
public static final int NSResetFunctionKey = 63283;
public static final int NSResizableWindowMask = 8;
public static final int NSReturnTextMovement = 16;
public static final int NSRightArrowFunctionKey = 63235;
public static final int NSRightMouseDown = 3;
public static final int NSRightMouseDownMask = 8;
public static final int NSRightMouseDragged = 7;
public static final int NSRightMouseDraggedMask = 128;
public static final int NSRightMouseUp = 4;
public static final int NSRightMouseUpMask = 16;
public static final int NSRightTabStopType = 1;
public static final int NSRightTabsBezelBorder = 3;
public static final int NSRightTextAlignment = 1;
public static final int NSRightTextMovement = 20;
public static final int NSRoundLineCapStyle = 1;
public static final int NSRoundLineJoinStyle = 1;
public static final int NSRoundRectBezelStyle = 12;
public static final int NSRoundedBezelStyle = 1;
public static final int NSRoundedDisclosureBezelStyle = 14;
public static final int NSRoundedTokenStyle = 2;
public static final int NSRuleEditorNestingModeCompound = 2;
public static final int NSRuleEditorNestingModeList = 1;
public static final int NSRuleEditorNestingModeSimple = 3;
public static final int NSRuleEditorNestingModeSingle = 0;
public static final int NSRuleEditorRowTypeCompound = 1;
public static final int NSRuleEditorRowTypeSimple = 0;
public static final int NSRunAbortedResponse = -1001;
public static final int NSRunContinuesResponse = -1002;
public static final int NSRunStoppedResponse = -1000;
public static final int NSSaveAsOperation = 1;
public static final int NSSaveOperation = 0;
public static final int NSSaveToOperation = 2;
public static final int NSScaleNone = 2;
public static final int NSScaleProportionally = 0;
public static final int NSScaleToFit = 1;
public static final int NSScreenChangedEventType = 8;
public static final int NSScreenSaverWindowLevel = 1000;
public static final int NSScrollLockFunctionKey = 63279;
public static final int NSScrollWheel = 22;
public static final int NSScrollWheelMask = 4194304;
public static final int NSScrollerArrowsDefaultSetting = 0;
public static final int NSScrollerArrowsMaxEnd = 0;
public static final int NSScrollerArrowsMinEnd = 1;
public static final int NSScrollerArrowsNone = 2;
public static final int NSScrollerDecrementArrow = 1;
public static final int NSScrollerDecrementLine = 4;
public static final int NSScrollerDecrementPage = 1;
public static final int NSScrollerIncrementArrow = 0;
public static final int NSScrollerIncrementLine = 5;
public static final int NSScrollerIncrementPage = 3;
public static final int NSScrollerKnob = 2;
public static final int NSScrollerKnobSlot = 6;
public static final int NSScrollerNoPart = 0;
public static final int NSSearchFieldClearRecentsMenuItemTag = 1002;
public static final int NSSearchFieldNoRecentsMenuItemTag = 1003;
public static final int NSSearchFieldRecentsMenuItemTag = 1001;
public static final int NSSearchFieldRecentsTitleMenuItemTag = 1000;
public static final int NSSegmentStyleAutomatic = 0;
public static final int NSSegmentStyleCapsule = 5;
public static final int NSSegmentStyleRoundRect = 3;
public static final int NSSegmentStyleRounded = 1;
public static final int NSSegmentStyleSmallSquare = 6;
public static final int NSSegmentStyleTexturedRounded = 2;
public static final int NSSegmentStyleTexturedSquare = 4;
public static final int NSSegmentSwitchTrackingMomentary = 2;
public static final int NSSegmentSwitchTrackingSelectAny = 1;
public static final int NSSegmentSwitchTrackingSelectOne = 0;
public static final int NSSelectByCharacter = 0;
public static final int NSSelectByParagraph = 2;
public static final int NSSelectByWord = 1;
public static final int NSSelectFunctionKey = 63297;
public static final int NSSelectedTab = 0;
public static final int NSSelectingNext = 1;
public static final int NSSelectingPrevious = 2;
public static final int NSSelectionAffinityDownstream = 1;
public static final int NSSelectionAffinityUpstream = 0;
public static final int NSServiceApplicationLaunchFailedError = 66561;
public static final int NSServiceApplicationNotFoundError = 66560;
public static final int NSServiceErrorMaximum = 66817;
public static final int NSServiceErrorMinimum = 66560;
public static final int NSServiceInvalidPasteboardDataError = 66563;
public static final int NSServiceMalformedServiceDictionaryError = 66564;
public static final int NSServiceMiscellaneousError = 66800;
public static final int NSServiceRequestTimedOutError = 66562;
public static final int NSShadowlessSquareBezelStyle = 6;
public static final int NSShiftKeyMask = 131072;
public static final int NSShowControlGlyphs = 1;
public static final int NSShowInvisibleGlyphs = 2;
public static final int NSSingleDateMode = 0;
public static final int NSSingleUnderlineStyle = 1;
public static final int NSSizeDownFontAction = 4;
public static final int NSSizeUpFontAction = 3;
public static final int NSSmallCapsFontMask = 128;
public static final int NSSmallControlSize = 1;
public static final int NSSmallIconButtonBezelStyle = 2;
public static final int NSSmallSquareBezelStyle = 10;
public static final int NSSpecialPageOrder = 0;
public static final int NSSpeechImmediateBoundary = 0;
public static final int NSSpeechSentenceBoundary = 2;
public static final int NSSpeechWordBoundary = 1;
public static final int NSSpellingStateGrammarFlag = 2;
public static final int NSSpellingStateSpellingFlag = 1;
public static final int NSSplitViewDividerStyleThick = 1;
public static final int NSSplitViewDividerStyleThin = 2;
public static final int NSSquareLineCapStyle = 2;
public static final int NSSquareStatusItemLength = -2;
public static final int NSStatusWindowLevel = 25;
public static final int NSStopFunctionKey = 63284;
public static final int NSStringDrawingDisableScreenFontSubstitution = 4;
public static final int NSStringDrawingOneShot = 16;
public static final int NSStringDrawingTruncatesLastVisibleLine = 32;
public static final int NSStringDrawingUsesDeviceMetrics = 8;
public static final int NSStringDrawingUsesFontLeading = 2;
public static final int NSStringDrawingUsesLineFragmentOrigin = 1;
public static final int NSSubmenuWindowLevel = 3;
public static final int NSSwitchButton = 3;
public static final int NSSysReqFunctionKey = 63281;
public static final int NSSystemDefined = 14;
public static final int NSSystemDefinedMask = 16384;
public static final int NSSystemFunctionKey = 63287;
public static final int NSTIFFCompressionCCITTFAX3 = 3;
public static final int NSTIFFCompressionCCITTFAX4 = 4;
public static final int NSTIFFCompressionJPEG = 6;
public static final int NSTIFFCompressionLZW = 5;
public static final int NSTIFFCompressionNEXT = 32766;
public static final int NSTIFFCompressionNone = 1;
public static final int NSTIFFCompressionOldJPEG = 32865;
public static final int NSTIFFCompressionPackBits = 32773;
public static final int NSTIFFFileType = 0;
public static final int NSTabCharacter = 9;
public static final int NSTabTextMovement = 17;
public static final int NSTableColumnAutoresizingMask = 1;
public static final int NSTableColumnNoResizing = 0;
public static final int NSTableColumnUserResizingMask = 2;
public static final int NSTableViewDropAbove = 1;
public static final int NSTableViewDropOn = 0;
public static final int NSTableViewFirstColumnOnlyAutoresizingStyle = 5;
public static final int NSTableViewGridNone = 0;
public static final int NSTableViewLastColumnOnlyAutoresizingStyle = 4;
public static final int NSTableViewNoColumnAutoresizing = 0;
public static final int NSTableViewReverseSequentialColumnAutoresizingStyle = 3;
public static final int NSTableViewSelectionHighlightStyleRegular = 0;
public static final int NSTableViewSelectionHighlightStyleSourceList = 1;
public static final int NSTableViewSequentialColumnAutoresizingStyle = 2;
public static final int NSTableViewSolidHorizontalGridLineMask = 2;
public static final int NSTableViewSolidVerticalGridLineMask = 1;
public static final int NSTableViewUniformColumnAutoresizingStyle = 1;
public static final int NSTabletPoint = 23;
public static final int NSTabletPointEventSubtype = 1;
public static final int NSTabletPointMask = 8388608;
public static final int NSTabletProximity = 24;
public static final int NSTabletProximityEventSubtype = 2;
public static final int NSTabletProximityMask = 16777216;
public static final int NSTerminateCancel = 0;
public static final int NSTerminateLater = 2;
public static final int NSTerminateNow = 1;
public static final int NSTextBlockAbsoluteValueType = 0;
public static final int NSTextBlockBaselineAlignment = 3;
public static final int NSTextBlockBorder = 0;
public static final int NSTextBlockBottomAlignment = 2;
public static final int NSTextBlockHeight = 4;
public static final int NSTextBlockMargin = 1;
public static final int NSTextBlockMaximumHeight = 6;
public static final int NSTextBlockMaximumWidth = 2;
public static final int NSTextBlockMiddleAlignment = 1;
public static final int NSTextBlockMinimumHeight = 5;
public static final int NSTextBlockMinimumWidth = 1;
public static final int NSTextBlockPadding = -1;
public static final int NSTextBlockPercentageValueType = 1;
public static final int NSTextBlockTopAlignment = 0;
public static final int NSTextBlockWidth = 0;
public static final int NSTextCellType = 1;
public static final int NSTextFieldAndStepperDatePickerStyle = 0;
public static final int NSTextFieldDatePickerStyle = 2;
public static final int NSTextFieldRoundedBezel = 1;
public static final int NSTextFieldSquareBezel = 0;
public static final int NSTextListPrependEnclosingMarker = 1;
public static final int NSTextReadInapplicableDocumentTypeError = 65806;
public static final int NSTextReadWriteErrorMaximum = 66303;
public static final int NSTextReadWriteErrorMinimum = 65792;
public static final int NSTextStorageEditedAttributes = 1;
public static final int NSTextStorageEditedCharacters = 2;
public static final int NSTextTableAutomaticLayoutAlgorithm = 0;
public static final int NSTextTableFixedLayoutAlgorithm = 1;
public static final int NSTextWriteInapplicableDocumentTypeError = 66062;
public static final int NSTexturedBackgroundWindowMask = 256;
public static final int NSTexturedRoundedBezelStyle = 11;
public static final int NSTexturedSquareBezelStyle = 8;
public static final int NSThickSquareBezelStyle = 3;
public static final int NSThickerSquareBezelStyle = 4;
public static final int NSTickMarkAbove = 1;
public static final int NSTickMarkBelow = 0;
public static final int NSTickMarkLeft = 1;
public static final int NSTickMarkRight = 0;
public static final int NSTimeZoneDatePickerElementFlag = 16;
public static final int NSTitledWindowMask = 1;
public static final int NSToggleButton = 2;
public static final int NSToolbarDisplayModeDefault = 0;
public static final int NSToolbarDisplayModeIconAndLabel = 1;
public static final int NSToolbarDisplayModeIconOnly = 2;
public static final int NSToolbarDisplayModeLabelOnly = 3;
public static final int NSToolbarItemVisibilityPriorityHigh = 1000;
public static final int NSToolbarItemVisibilityPriorityLow = -1000;
public static final int NSToolbarItemVisibilityPriorityStandard = 0;
public static final int NSToolbarItemVisibilityPriorityUser = 2000;
public static final int NSToolbarSizeModeDefault = 0;
public static final int NSToolbarSizeModeRegular = 1;
public static final int NSToolbarSizeModeSmall = 2;
public static final int NSTopTabsBezelBorder = 0;
public static final int NSTornOffMenuWindowLevel = 3;
public static final int NSTrackModeMatrix = 3;
public static final int NSTrackingActiveAlways = 128;
public static final int NSTrackingActiveInActiveApp = 64;
public static final int NSTrackingActiveInKeyWindow = 32;
public static final int NSTrackingActiveWhenFirstResponder = 16;
public static final int NSTrackingAssumeInside = 256;
public static final int NSTrackingCursorUpdate = 4;
public static final int NSTrackingEnabledDuringMouseDrag = 1024;
public static final int NSTrackingInVisibleRect = 512;
public static final int NSTrackingMouseEnteredAndExited = 1;
public static final int NSTrackingMouseMoved = 2;
public static final int NSTypesetterBehavior_10_2 = 2;
public static final int NSTypesetterBehavior_10_2_WithCompatibility = 1;
public static final int NSTypesetterBehavior_10_3 = 3;
public static final int NSTypesetterBehavior_10_4 = 4;
public static final int NSTypesetterContainerBreakAction = 32;
public static final int NSTypesetterHorizontalTabAction = 4;
public static final int NSTypesetterLatestBehavior = -1;
public static final int NSTypesetterLineBreakAction = 8;
public static final int NSTypesetterOriginalBehavior = 0;
public static final int NSTypesetterParagraphBreakAction = 16;
public static final int NSTypesetterWhitespaceAction = 2;
public static final int NSTypesetterZeroAdvancementAction = 1;
public static final int NSUnboldFontMask = 4;
public static final int NSUnderlinePatternDash = 512;
public static final int NSUnderlinePatternDashDot = 768;
public static final int NSUnderlinePatternDashDotDot = 1024;
public static final int NSUnderlinePatternDot = 256;
public static final int NSUnderlinePatternSolid = 0;
public static final int NSUnderlineStyleDouble = 9;
public static final int NSUnderlineStyleNone = 0;
public static final int NSUnderlineStyleSingle = 1;
public static final int NSUnderlineStyleThick = 2;
public static final int NSUndoFunctionKey = 63299;
public static final int NSUnifiedTitleAndToolbarWindowMask = 4096;
public static final int NSUnitalicFontMask = 16777216;
public static final int NSUnknownColorSpaceModel = -1;
public static final int NSUnknownPageOrder = 2;
public static final int NSUnknownPointingDevice = 0;
public static final int NSUnscaledWindowMask = 2048;
public static final int NSUpArrowFunctionKey = 63232;
public static final int NSUpTextMovement = 21;
public static final int NSUpdateWindowsRunLoopOrdering = 500000;
public static final int NSUserFunctionKey = 63286;
public static final int NSUtilityWindowMask = 16;
public static final int NSVariableStatusItemLength = -1;
public static final int NSVerticalRuler = 1;
public static final int NSViaPanelFontAction = 1;
public static final int NSViewHeightSizable = 16;
public static final int NSViewMaxXMargin = 4;
public static final int NSViewMaxYMargin = 32;
public static final int NSViewMinXMargin = 1;
public static final int NSViewMinYMargin = 8;
public static final int NSViewNotSizable = 0;
public static final int NSViewWidthSizable = 2;
public static final int NSWantsBidiLevels = 4;
public static final int NSWarningAlertStyle = 0;
public static final int NSWheelModeColorPanel = 6;
public static final int NSWindowAbove = 1;
public static final int NSWindowBackingLocationDefault = 0;
public static final int NSWindowBackingLocationMainMemory = 2;
public static final int NSWindowBackingLocationVideoMemory = 1;
public static final int NSWindowBelow = -1;
public static final int NSWindowCloseButton = 0;
public static final int NSWindowCollectionBehaviorCanJoinAllSpaces = 1;
public static final int NSWindowCollectionBehaviorDefault = 0;
public static final int NSWindowCollectionBehaviorMoveToActiveSpace = 2;
public static final int NSWindowDocumentIconButton = 4;
public static final int NSWindowExposedEventType = 0;
public static final int NSWindowMiniaturizeButton = 1;
public static final int NSWindowMovedEventType = 4;
public static final int NSWindowOut = 0;
public static final int NSWindowSharingNone = 0;
public static final int NSWindowSharingReadOnly = 1;
public static final int NSWindowSharingReadWrite = 2;
public static final int NSWindowToolbarButton = 3;
public static final int NSWindowZoomButton = 2;
public static final int NSWindows95InterfaceStyle = 2;
public static final int NSWorkspaceLaunchAllowingClassicStartup = 131072;
public static final int NSWorkspaceLaunchAndHide = 1048576;
public static final int NSWorkspaceLaunchAndHideOthers = 2097152;
public static final int NSWorkspaceLaunchAndPrint = 2;
public static final int NSWorkspaceLaunchAsync = 65536;
public static final int NSWorkspaceLaunchDefault = 196608;
public static final int NSWorkspaceLaunchInhibitingBackgroundOnly = 128;
public static final int NSWorkspaceLaunchNewInstance = 524288;
public static final int NSWorkspaceLaunchPreferringClassic = 262144;
public static final int NSWorkspaceLaunchWithoutActivation = 512;
public static final int NSWorkspaceLaunchWithoutAddingToRecents = 256;
public static final int NSWritingDirectionLeftToRight = 0;
public static final int NSWritingDirectionNatural = -1;
public static final int NSWritingDirectionRightToLeft = 1;
public static final int NSYearMonthDatePickerElementFlag = 192;
public static final int NSYearMonthDayDatePickerElementFlag = 224;
public static final int kCFStringEncodingUTF8 = 134217984;
public static final int NSASCIIStringEncoding = 1;
public static final int NSAdminApplicationDirectory = 4;
public static final int NSAggregateExpressionType = 14;
public static final int NSAllApplicationsDirectory = 100;
public static final int NSAllDomainsMask = 65535;
public static final int NSAllLibrariesDirectory = 101;
public static final int NSAllPredicateModifier = 1;
public static final int NSAnchoredSearch = 8;
public static final int NSAndPredicateType = 1;
public static final int NSAnyPredicateModifier = 2;
public static final int NSApplicationDirectory = 1;
public static final int NSApplicationSupportDirectory = 14;
public static final int NSArgumentEvaluationScriptError = 3;
public static final int NSArgumentsWrongScriptError = 6;
public static final int NSAtomicWrite = 1;
public static final int NSBackwardsSearch = 4;
public static final int NSBeginsWithComparison = 5;
public static final int NSBeginsWithPredicateOperatorType = 8;
public static final int NSBetweenPredicateOperatorType = 100;
public static final int NSBundleExecutableArchitectureI386 = 7;
public static final int NSBundleExecutableArchitecturePPC = 18;
public static final int NSBundleExecutableArchitecturePPC64 = 16777234;
public static final int NSBundleExecutableArchitectureX86_64 = 16777223;
public static final int NSCachesDirectory = 13;
public static final int NSCalculationDivideByZero = 4;
public static final int NSCalculationLossOfPrecision = 1;
public static final int NSCalculationNoError = 0;
public static final int NSCalculationOverflow = 3;
public static final int NSCalculationUnderflow = 2;
public static final int NSCannotCreateScriptCommandError = 10;
public static final int NSCaseInsensitivePredicateOption = 1;
public static final int NSCaseInsensitiveSearch = 1;
public static final int NSCollectorDisabledOption = 2;
public static final int NSConstantValueExpressionType = 0;
public static final int NSContainerSpecifierError = 2;
public static final int NSContainsComparison = 7;
public static final int NSContainsPredicateOperatorType = 99;
public static final int NSCoreServiceDirectory = 10;
public static final int NSCustomSelectorPredicateOperatorType = 11;
public static final int NSDateFormatterBehavior10_0 = 1000;
public static final int NSDateFormatterBehavior10_4 = 1040;
public static final int NSDateFormatterBehaviorDefault = 0;
public static final int NSDateFormatterFullStyle = 4;
public static final int NSDateFormatterLongStyle = 3;
public static final int NSDateFormatterMediumStyle = 2;
public static final int NSDateFormatterNoStyle = 0;
public static final int NSDateFormatterShortStyle = 1;
public static final int NSDayCalendarUnit = 16;
public static final int NSDecimalMaxSize = 8;
public static final int NSDecimalNoScale = 32767;
public static final int NSDemoApplicationDirectory = 2;
public static final int NSDesktopDirectory = 12;
public static final int NSDeveloperApplicationDirectory = 3;
public static final int NSDeveloperDirectory = 6;
public static final int NSDiacriticInsensitivePredicateOption = 2;
public static final int NSDiacriticInsensitiveSearch = 128;
public static final int NSDirectPredicateModifier = 0;
public static final int NSDocumentDirectory = 9;
public static final int NSDocumentationDirectory = 8;
public static final int NSDownloadsDirectory = 15;
public static final int NSEndsWithComparison = 6;
public static final int NSEndsWithPredicateOperatorType = 9;
public static final int NSEqualToComparison = 0;
public static final int NSEqualToPredicateOperatorType = 4;
public static final int NSEraCalendarUnit = 2;
public static final int NSEvaluatedObjectExpressionType = 1;
public static final int NSEverySubelement = 1;
public static final int NSExecutableArchitectureMismatchError = 3585;
public static final int NSExecutableErrorMaximum = 3839;
public static final int NSExecutableErrorMinimum = 3584;
public static final int NSExecutableLinkError = 3588;
public static final int NSExecutableLoadError = 3587;
public static final int NSExecutableNotLoadableError = 3584;
public static final int NSExecutableRuntimeMismatchError = 3586;
public static final int NSFileErrorMaximum = 1023;
public static final int NSFileErrorMinimum = 0;
public static final int NSFileLockingError = 255;
public static final int NSFileNoSuchFileError = 4;
public static final int NSFileReadCorruptFileError = 259;
public static final int NSFileReadInapplicableStringEncodingError = 261;
public static final int NSFileReadInvalidFileNameError = 258;
public static final int NSFileReadNoPermissionError = 257;
public static final int NSFileReadNoSuchFileError = 260;
public static final int NSFileReadTooLargeError = 263;
public static final int NSFileReadUnknownError = 256;
public static final int NSFileReadUnknownStringEncodingError = 264;
public static final int NSFileReadUnsupportedSchemeError = 262;
public static final int NSFileWriteInapplicableStringEncodingError = 517;
public static final int NSFileWriteInvalidFileNameError = 514;
public static final int NSFileWriteNoPermissionError = 513;
public static final int NSFileWriteOutOfSpaceError = 640;
public static final int NSFileWriteUnknownError = 512;
public static final int NSFileWriteUnsupportedSchemeError = 518;
public static final int NSForcedOrderingSearch = 512;
public static final int NSFormattingError = 2048;
public static final int NSFormattingErrorMaximum = 2559;
public static final int NSFormattingErrorMinimum = 2048;
public static final double NSFoundationVersionNumber10_0 = 397.39999999999998;
public static final double NSFoundationVersionNumber10_1 = 425.00000000000000;
public static final double NSFoundationVersionNumber10_1_1 = 425.00000000000000;
public static final double NSFoundationVersionNumber10_1_2 = 425.00000000000000;
public static final double NSFoundationVersionNumber10_1_3 = 425.00000000000000;
public static final double NSFoundationVersionNumber10_1_4 = 425.00000000000000;
public static final double NSFoundationVersionNumber10_2 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_1 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_2 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_3 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_4 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_5 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_6 = 462.00000000000000;
public static final double NSFoundationVersionNumber10_2_7 = 462.69999999999999;
public static final double NSFoundationVersionNumber10_2_8 = 462.69999999999999;
public static final double NSFoundationVersionNumber10_3 = 500.00000000000000;
public static final double NSFoundationVersionNumber10_3_1 = 500.00000000000000;
public static final double NSFoundationVersionNumber10_3_2 = 500.30000000000001;
public static final double NSFoundationVersionNumber10_3_3 = 500.54000000000002;
public static final double NSFoundationVersionNumber10_3_4 = 500.56000000000000;
public static final double NSFoundationVersionNumber10_3_5 = 500.56000000000000;
public static final double NSFoundationVersionNumber10_3_6 = 500.56000000000000;
public static final double NSFoundationVersionNumber10_3_7 = 500.56000000000000;
public static final double NSFoundationVersionNumber10_3_8 = 500.56000000000000;
public static final double NSFoundationVersionNumber10_3_9 = 500.57999999999998;
public static final double NSFoundationVersionNumber10_4 = 567.00000000000000;
public static final double NSFoundationVersionNumber10_4_1 = 567.00000000000000;
public static final double NSFoundationVersionNumber10_4_10 = 567.28999999999996;
public static final double NSFoundationVersionNumber10_4_11 = 567.36000000000001;
public static final double NSFoundationVersionNumber10_4_2 = 567.12000000000000;
public static final double NSFoundationVersionNumber10_4_3 = 567.21000000000004;
public static final double NSFoundationVersionNumber10_4_4_Intel = 567.23000000000002;
public static final double NSFoundationVersionNumber10_4_4_PowerPC = 567.21000000000004;
public static final double NSFoundationVersionNumber10_4_5 = 567.25000000000000;
public static final double NSFoundationVersionNumber10_4_6 = 567.25999999999999;
public static final double NSFoundationVersionNumber10_4_7 = 567.26999999999998;
public static final double NSFoundationVersionNumber10_4_8 = 567.27999999999997;
public static final double NSFoundationVersionNumber10_4_9 = 567.28999999999996;
public static final int NSFoundationVersionWithFileManagerResourceForkSupport = 412;
public static final int NSFunctionExpressionType = 4;
public static final int NSGreaterThanComparison = 4;
public static final int NSGreaterThanOrEqualToComparison = 3;
public static final int NSGreaterThanOrEqualToPredicateOperatorType = 3;
public static final int NSGreaterThanPredicateOperatorType = 2;
public static final int NSHPUXOperatingSystem = 4;
public static final int NSHTTPCookieAcceptPolicyAlways = 0;
public static final int NSHTTPCookieAcceptPolicyNever = 1;
public static final int NSHTTPCookieAcceptPolicyOnlyFromMainDocumentDomain = 2;
public static final int NSHashTableCopyIn = 65536;
public static final int NSHashTableObjectPointerPersonality = 512;
public static final int NSHashTableStrongMemory = 0;
public static final int NSHashTableZeroingWeakMemory = 1;
public static final int NSHourCalendarUnit = 32;
public static final int NSINTEGER_DEFINED = 1;
public static final int NSISO2022JPStringEncoding = 21;
public static final int NSISOLatin1StringEncoding = 5;
public static final int NSISOLatin2StringEncoding = 9;
public static final int NSInPredicateOperatorType = 10;
public static final int NSIndexSubelement = 0;
public static final int NSIntegerMax = 2147483647;
public static final int NSIntegerMin = -2147483648;
public static final int NSInternalScriptError = 8;
public static final int NSInternalSpecifierError = 5;
public static final int NSIntersectSetExpressionType = 6;
public static final int NSInvalidIndexSpecifierError = 4;
public static final int NSJapaneseEUCStringEncoding = 3;
public static final int NSKeyPathExpressionType = 3;
public static final int NSKeySpecifierEvaluationScriptError = 2;
public static final int NSKeyValueChangeInsertion = 2;
public static final int NSKeyValueChangeRemoval = 3;
public static final int NSKeyValueChangeReplacement = 4;
public static final int NSKeyValueChangeSetting = 1;
public static final int NSKeyValueIntersectSetMutation = 3;
public static final int NSKeyValueMinusSetMutation = 2;
public static final int NSKeyValueObservingOptionInitial = 4;
public static final int NSKeyValueObservingOptionNew = 1;
public static final int NSKeyValueObservingOptionOld = 2;
public static final int NSKeyValueObservingOptionPrior = 8;
public static final int NSKeyValueSetSetMutation = 4;
public static final int NSKeyValueUnionSetMutation = 1;
public static final int NSKeyValueValidationError = 1024;
public static final int NSLessThanComparison = 2;
public static final int NSLessThanOrEqualToComparison = 1;
public static final int NSLessThanOrEqualToPredicateOperatorType = 1;
public static final int NSLessThanPredicateOperatorType = 0;
public static final int NSLibraryDirectory = 5;
public static final int NSLikePredicateOperatorType = 7;
public static final int NSLiteralSearch = 2;
public static final int NSLocalDomainMask = 2;
public static final int NSMACHOperatingSystem = 5;
public static final int NSMacOSRomanStringEncoding = 30;
public static final int NSMachPortDeallocateNone = 0;
public static final int NSMachPortDeallocateReceiveRight = 2;
public static final int NSMachPortDeallocateSendRight = 1;
public static final int NSMapTableCopyIn = 65536;
public static final int NSMapTableObjectPointerPersonality = 512;
public static final int NSMapTableStrongMemory = 0;
public static final int NSMapTableZeroingWeakMemory = 1;
public static final int NSMappedRead = 1;
public static final int NSMatchesPredicateOperatorType = 6;
public static final int NSMaxXEdge = 2;
public static final int NSMaxYEdge = 3;
public static final int NSMiddleSubelement = 2;
public static final int NSMinXEdge = 0;
public static final int NSMinYEdge = 1;
public static final int NSMinusSetExpressionType = 7;
public static final int NSMinuteCalendarUnit = 64;
public static final int NSMonthCalendarUnit = 8;
public static final int NSNEXTSTEPStringEncoding = 2;
public static final int NSNetServiceNoAutoRename = 1;
public static final int NSNetServicesActivityInProgress = -72003;
public static final int NSNetServicesBadArgumentError = -72004;
public static final int NSNetServicesCancelledError = -72005;
public static final int NSNetServicesCollisionError = -72001;
public static final int NSNetServicesInvalidError = -72006;
public static final int NSNetServicesNotFoundError = -72002;
public static final int NSNetServicesTimeoutError = -72007;
public static final int NSNetServicesUnknownError = -72000;
public static final int NSNetworkDomainMask = 4;
public static final int NSNoScriptError = 0;
public static final int NSNoSpecifierError = 0;
public static final int NSNoSubelement = 4;
public static final int NSNoTopLevelContainersSpecifierError = 1;
public static final int NSNonLossyASCIIStringEncoding = 7;
public static final int NSNotEqualToPredicateOperatorType = 5;
public static final int NSNotFound = 2147483647;
public static final int NSNotPredicateType = 0;
public static final int NSNotificationCoalescingOnName = 1;
public static final int NSNotificationCoalescingOnSender = 2;
public static final int NSNotificationDeliverImmediately = 1;
public static final int NSNotificationNoCoalescing = 0;
public static final int NSNotificationPostToAllSessions = 2;
public static final int NSNotificationSuspensionBehaviorCoalesce = 2;
public static final int NSNotificationSuspensionBehaviorDeliverImmediately = 4;
public static final int NSNotificationSuspensionBehaviorDrop = 1;
public static final int NSNotificationSuspensionBehaviorHold = 3;
public static final int NSNumberFormatterBehavior10_0 = 1000;
public static final int NSNumberFormatterBehavior10_4 = 1040;
public static final int NSNumberFormatterBehaviorDefault = 0;
public static final int NSNumberFormatterCurrencyStyle = 2;
public static final int NSNumberFormatterDecimalStyle = 1;
public static final int NSNumberFormatterNoStyle = 0;
public static final int NSNumberFormatterPadAfterPrefix = 1;
public static final int NSNumberFormatterPadAfterSuffix = 3;
public static final int NSNumberFormatterPadBeforePrefix = 0;
public static final int NSNumberFormatterPadBeforeSuffix = 2;
public static final int NSNumberFormatterPercentStyle = 3;
public static final int NSNumberFormatterRoundCeiling = 0;
public static final int NSNumberFormatterRoundDown = 2;
public static final int NSNumberFormatterRoundFloor = 1;
public static final int NSNumberFormatterRoundHalfDown = 5;
public static final int NSNumberFormatterRoundHalfEven = 4;
public static final int NSNumberFormatterRoundHalfUp = 6;
public static final int NSNumberFormatterRoundUp = 3;
public static final int NSNumberFormatterScientificStyle = 4;
public static final int NSNumberFormatterSpellOutStyle = 5;
public static final int NSNumericSearch = 64;
public static final int NSOSF1OperatingSystem = 7;
public static final int NSObjCArrayType = 91;
public static final int NSObjCBitfield = 98;
public static final int NSObjCBoolType = 66;
public static final int NSObjCCharType = 99;
public static final int NSObjCDoubleType = 100;
public static final int NSObjCFloatType = 102;
public static final int NSObjCLongType = 108;
public static final int NSObjCLonglongType = 113;
public static final int NSObjCNoType = 0;
public static final int NSObjCObjectType = 64;
public static final int NSObjCPointerType = 94;
public static final int NSObjCSelectorType = 58;
public static final int NSObjCShortType = 115;
public static final int NSObjCStringType = 42;
public static final int NSObjCStructType = 123;
public static final int NSObjCUnionType = 40;
public static final int NSObjCVoidType = 118;
public static final int NSObjectAutoreleasedEvent = 3;
public static final int NSObjectExtraRefDecrementedEvent = 5;
public static final int NSObjectExtraRefIncrementedEvent = 4;
public static final int NSObjectInternalRefDecrementedEvent = 7;
public static final int NSObjectInternalRefIncrementedEvent = 6;
public static final int NSOpenStepUnicodeReservedBase = 62464;
public static final int NSOperationNotSupportedForKeyScriptError = 9;
public static final int NSOperationNotSupportedForKeySpecifierError = 6;
public static final int NSOperationQueueDefaultMaxConcurrentOperationCount = -1;
public static final int NSOperationQueuePriorityHigh = 4;
public static final int NSOperationQueuePriorityLow = -4;
public static final int NSOperationQueuePriorityNormal = 0;
public static final int NSOperationQueuePriorityVeryHigh = 8;
public static final int NSOperationQueuePriorityVeryLow = -8;
public static final int NSOrPredicateType = 2;
public static final int NSOrderedAscending = -1;
public static final int NSOrderedDescending = 1;
public static final int NSOrderedSame = 0;
public static final int NSPointerFunctionsCStringPersonality = 768;
public static final int NSPointerFunctionsCopyIn = 65536;
public static final int NSPointerFunctionsIntegerPersonality = 1280;
public static final int NSPointerFunctionsMachVirtualMemory = 4;
public static final int NSPointerFunctionsMallocMemory = 3;
public static final int NSPointerFunctionsObjectPersonality = 0;
public static final int NSPointerFunctionsObjectPointerPersonality = 512;
public static final int NSPointerFunctionsOpaqueMemory = 2;
public static final int NSPointerFunctionsOpaquePersonality = 256;
public static final int NSPointerFunctionsStrongMemory = 0;
public static final int NSPointerFunctionsStructPersonality = 1024;
public static final int NSPointerFunctionsZeroingWeakMemory = 1;
public static final int NSPositionAfter = 0;
public static final int NSPositionBefore = 1;
public static final int NSPositionBeginning = 2;
public static final int NSPositionEnd = 3;
public static final int NSPositionReplace = 4;
public static final int NSPostASAP = 2;
public static final int NSPostNow = 3;
public static final int NSPostWhenIdle = 1;
public static final int NSPropertyListBinaryFormat_v1_0 = 200;
public static final int NSPropertyListImmutable = 0;
public static final int NSPropertyListMutableContainers = 1;
public static final int NSPropertyListMutableContainersAndLeaves = 2;
public static final int NSPropertyListOpenStepFormat = 1;
public static final int NSPropertyListXMLFormat_v1_0 = 100;
public static final int NSRandomSubelement = 3;
public static final int NSReceiverEvaluationScriptError = 1;
public static final int NSReceiversCantHandleCommandScriptError = 4;
public static final int NSRelativeAfter = 0;
public static final int NSRelativeBefore = 1;
public static final int NSRequiredArgumentsMissingScriptError = 5;
public static final int NSRoundBankers = 3;
public static final int NSRoundDown = 1;
public static final int NSRoundPlain = 0;
public static final int NSRoundUp = 2;
public static final int NSSaveOptionsAsk = 2;
public static final int NSSaveOptionsNo = 1;
public static final int NSSaveOptionsYes = 0;
public static final int NSScannedOption = 1;
public static final int NSSecondCalendarUnit = 128;
public static final int NSShiftJISStringEncoding = 8;
public static final int NSSolarisOperatingSystem = 3;
public static final int NSStreamEventEndEncountered = 16;
public static final int NSStreamEventErrorOccurred = 8;
public static final int NSStreamEventHasBytesAvailable = 2;
public static final int NSStreamEventHasSpaceAvailable = 4;
public static final int NSStreamEventNone = 0;
public static final int NSStreamEventOpenCompleted = 1;
public static final int NSStreamStatusAtEnd = 5;
public static final int NSStreamStatusClosed = 6;
public static final int NSStreamStatusError = 7;
public static final int NSStreamStatusNotOpen = 0;
public static final int NSStreamStatusOpen = 2;
public static final int NSStreamStatusOpening = 1;
public static final int NSStreamStatusReading = 3;
public static final int NSStreamStatusWriting = 4;
public static final int NSStringEncodingConversionAllowLossy = 1;
public static final int NSStringEncodingConversionExternalRepresentation = 2;
public static final int NSSubqueryExpressionType = 13;
public static final int NSSunOSOperatingSystem = 6;
public static final int NSSymbolStringEncoding = 6;
public static final int NSSystemDomainMask = 8;
public static final double NSTimeIntervalSince1970 = 978307200.00000000;
public static final int NSTimeZoneNameStyleDaylightSaving = 2;
public static final int NSTimeZoneNameStyleShortDaylightSaving = 3;
public static final int NSTimeZoneNameStyleShortStandard = 1;
public static final int NSTimeZoneNameStyleStandard = 0;
public static final long NSUIntegerMax = 4294967295L;
public static final int NSURLCacheStorageAllowed = 0;
public static final int NSURLCacheStorageAllowedInMemoryOnly = 1;
public static final int NSURLCacheStorageNotAllowed = 2;
public static final int NSURLCredentialPersistenceForSession = 1;
public static final int NSURLCredentialPersistenceNone = 0;
public static final int NSURLCredentialPersistencePermanent = 2;
public static final int NSURLErrorBadServerResponse = -1011;
public static final int NSURLErrorBadURL = -1000;
public static final int NSURLErrorCancelled = -999;
public static final int NSURLErrorCannotCloseFile = -3002;
public static final int NSURLErrorCannotConnectToHost = -1004;
public static final int NSURLErrorCannotCreateFile = -3000;
public static final int NSURLErrorCannotDecodeContentData = -1016;
public static final int NSURLErrorCannotDecodeRawData = -1015;
public static final int NSURLErrorCannotFindHost = -1003;
public static final int NSURLErrorCannotLoadFromNetwork = -2000;
public static final int NSURLErrorCannotMoveFile = -3005;
public static final int NSURLErrorCannotOpenFile = -3001;
public static final int NSURLErrorCannotParseResponse = -1017;
public static final int NSURLErrorCannotRemoveFile = -3004;
public static final int NSURLErrorCannotWriteToFile = -3003;
public static final int NSURLErrorClientCertificateRejected = -1205;
public static final int NSURLErrorDNSLookupFailed = -1006;
public static final int NSURLErrorDataLengthExceedsMaximum = -1103;
public static final int NSURLErrorDownloadDecodingFailedMidStream = -3006;
public static final int NSURLErrorDownloadDecodingFailedToComplete = -3007;
public static final int NSURLErrorFileDoesNotExist = -1100;
public static final int NSURLErrorFileIsDirectory = -1101;
public static final int NSURLErrorHTTPTooManyRedirects = -1007;
public static final int NSURLErrorNetworkConnectionLost = -1005;
public static final int NSURLErrorNoPermissionsToReadFile = -1102;
public static final int NSURLErrorNotConnectedToInternet = -1009;
public static final int NSURLErrorRedirectToNonExistentLocation = -1010;
public static final int NSURLErrorResourceUnavailable = -1008;
public static final int NSURLErrorSecureConnectionFailed = -1200;
public static final int NSURLErrorServerCertificateHasBadDate = -1201;
public static final int NSURLErrorServerCertificateHasUnknownRoot = -1203;
public static final int NSURLErrorServerCertificateNotYetValid = -1204;
public static final int NSURLErrorServerCertificateUntrusted = -1202;
public static final int NSURLErrorTimedOut = -1001;
public static final int NSURLErrorUnknown = -1;
public static final int NSURLErrorUnsupportedURL = -1002;
public static final int NSURLErrorUserAuthenticationRequired = -1013;
public static final int NSURLErrorUserCancelledAuthentication = -1012;
public static final int NSURLErrorZeroByteResource = -1014;
public static final int NSURLHandleLoadFailed = 3;
public static final int NSURLHandleLoadInProgress = 2;
public static final int NSURLHandleLoadSucceeded = 1;
public static final int NSURLHandleNotLoaded = 0;
public static final int NSURLRequestReloadIgnoringCacheData = 1;
public static final int NSURLRequestReloadIgnoringLocalAndRemoteCacheData = 4;
public static final int NSURLRequestReloadIgnoringLocalCacheData = 1;
public static final int NSURLRequestReloadRevalidatingCacheData = 5;
public static final int NSURLRequestReturnCacheDataDontLoad = 3;
public static final int NSURLRequestReturnCacheDataElseLoad = 2;
public static final int NSURLRequestUseProtocolCachePolicy = 0;
public static final int NSUTF16BigEndianStringEncoding = -1879047936;
public static final int NSUTF16LittleEndianStringEncoding = -1811939072;
public static final int NSUTF16StringEncoding = 10;
public static final int NSUTF32BigEndianStringEncoding = -1744830208;
public static final int NSUTF32LittleEndianStringEncoding = -1677721344;
public static final int NSUTF32StringEncoding = -1946156800;
public static final int NSUTF8StringEncoding = 4;
public static final int NSUncachedRead = 2;
public static final int NSUndefinedDateComponent = 2147483647;
public static final int NSUndoCloseGroupingRunLoopOrdering = 350000;
public static final int NSUnicodeStringEncoding = 10;
public static final int NSUnionSetExpressionType = 5;
public static final int NSUnknownKeyScriptError = 7;
public static final int NSUnknownKeySpecifierError = 3;
public static final int NSUserCancelledError = 3072;
public static final int NSUserDirectory = 7;
public static final int NSUserDomainMask = 1;
public static final int NSValidationErrorMaximum = 2047;
public static final int NSValidationErrorMinimum = 1024;
public static final int NSVariableExpressionType = 2;
public static final int NSWeekCalendarUnit = 256;
public static final int NSWeekdayCalendarUnit = 512;
public static final int NSWeekdayOrdinalCalendarUnit = 1024;
public static final int NSWidthInsensitiveSearch = 256;
public static final int NSWindows95OperatingSystem = 2;
public static final int NSWindowsCP1250StringEncoding = 15;
public static final int NSWindowsCP1251StringEncoding = 11;
public static final int NSWindowsCP1252StringEncoding = 12;
public static final int NSWindowsCP1253StringEncoding = 13;
public static final int NSWindowsCP1254StringEncoding = 14;
public static final int NSWindowsNTOperatingSystem = 1;
public static final int NSWrapCalendarComponents = 1;
public static final int NSXMLAttributeCDATAKind = 6;
public static final int NSXMLAttributeDeclarationKind = 10;
public static final int NSXMLAttributeEntitiesKind = 11;
public static final int NSXMLAttributeEntityKind = 10;
public static final int NSXMLAttributeEnumerationKind = 14;
public static final int NSXMLAttributeIDKind = 7;
public static final int NSXMLAttributeIDRefKind = 8;
public static final int NSXMLAttributeIDRefsKind = 9;
public static final int NSXMLAttributeKind = 3;
public static final int NSXMLAttributeNMTokenKind = 12;
public static final int NSXMLAttributeNMTokensKind = 13;
public static final int NSXMLAttributeNotationKind = 15;
public static final int NSXMLCommentKind = 6;
public static final int NSXMLDTDKind = 8;
public static final int NSXMLDocumentHTMLKind = 2;
public static final int NSXMLDocumentIncludeContentTypeDeclaration = 262144;
public static final int NSXMLDocumentKind = 1;
public static final int NSXMLDocumentTextKind = 3;
public static final int NSXMLDocumentTidyHTML = 512;
public static final int NSXMLDocumentTidyXML = 1024;
public static final int NSXMLDocumentValidate = 8192;
public static final int NSXMLDocumentXHTMLKind = 1;
public static final int NSXMLDocumentXInclude = 65536;
public static final int NSXMLDocumentXMLKind = 0;
public static final int NSXMLElementDeclarationAnyKind = 18;
public static final int NSXMLElementDeclarationElementKind = 20;
public static final int NSXMLElementDeclarationEmptyKind = 17;
public static final int NSXMLElementDeclarationKind = 11;
public static final int NSXMLElementDeclarationMixedKind = 19;
public static final int NSXMLElementDeclarationUndefinedKind = 16;
public static final int NSXMLElementKind = 2;
public static final int NSXMLEntityDeclarationKind = 9;
public static final int NSXMLEntityGeneralKind = 1;
public static final int NSXMLEntityParameterKind = 4;
public static final int NSXMLEntityParsedKind = 2;
public static final int NSXMLEntityPredefined = 5;
public static final int NSXMLEntityUnparsedKind = 3;
public static final int NSXMLInvalidKind = 0;
public static final int NSXMLNamespaceKind = 4;
public static final int NSXMLNodeCompactEmptyElement = 4;
public static final int NSXMLNodeExpandEmptyElement = 2;
public static final int NSXMLNodeIsCDATA = 1;
public static final int NSXMLNodeOptionsNone = 0;
public static final int NSXMLNodePreserveAll = -1048546;
public static final int NSXMLNodePreserveAttributeOrder = 2097152;
public static final int NSXMLNodePreserveCDATA = 16777216;
public static final int NSXMLNodePreserveCharacterReferences = 134217728;
public static final int NSXMLNodePreserveDTD = 67108864;
public static final int NSXMLNodePreserveEmptyElements = 6;
public static final int NSXMLNodePreserveEntities = 4194304;
public static final int NSXMLNodePreserveNamespaceOrder = 1048576;
public static final int NSXMLNodePreservePrefixes = 8388608;
public static final int NSXMLNodePreserveQuotes = 24;
public static final int NSXMLNodePreserveWhitespace = 33554432;
public static final int NSXMLNodePrettyPrint = 131072;
public static final int NSXMLNodeUseDoubleQuotes = 16;
public static final int NSXMLNodeUseSingleQuotes = 8;
public static final int NSXMLNotationDeclarationKind = 12;
public static final int NSXMLParserAttributeHasNoValueError = 41;
public static final int NSXMLParserAttributeListNotFinishedError = 51;
public static final int NSXMLParserAttributeListNotStartedError = 50;
public static final int NSXMLParserAttributeNotFinishedError = 40;
public static final int NSXMLParserAttributeNotStartedError = 39;
public static final int NSXMLParserAttributeRedefinedError = 42;
public static final int NSXMLParserCDATANotFinishedError = 63;
public static final int NSXMLParserCharacterRefAtEOFError = 10;
public static final int NSXMLParserCharacterRefInDTDError = 13;
public static final int NSXMLParserCharacterRefInEpilogError = 12;
public static final int NSXMLParserCharacterRefInPrologError = 11;
public static final int NSXMLParserCommentContainsDoubleHyphenError = 80;
public static final int NSXMLParserCommentNotFinishedError = 45;
public static final int NSXMLParserConditionalSectionNotFinishedError = 59;
public static final int NSXMLParserConditionalSectionNotStartedError = 58;
public static final int NSXMLParserDOCTYPEDeclNotFinishedError = 61;
public static final int NSXMLParserDelegateAbortedParseError = 512;
public static final int NSXMLParserDocumentStartError = 3;
public static final int NSXMLParserElementContentDeclNotFinishedError = 55;
public static final int NSXMLParserElementContentDeclNotStartedError = 54;
public static final int NSXMLParserEmptyDocumentError = 4;
public static final int NSXMLParserEncodingNotSupportedError = 32;
public static final int NSXMLParserEntityBoundaryError = 90;
public static final int NSXMLParserEntityIsExternalError = 29;
public static final int NSXMLParserEntityIsParameterError = 30;
public static final int NSXMLParserEntityNotFinishedError = 37;
public static final int NSXMLParserEntityNotStartedError = 36;
public static final int NSXMLParserEntityRefAtEOFError = 14;
public static final int NSXMLParserEntityRefInDTDError = 17;
public static final int NSXMLParserEntityRefInEpilogError = 16;
public static final int NSXMLParserEntityRefInPrologError = 15;
public static final int NSXMLParserEntityRefLoopError = 89;
public static final int NSXMLParserEntityReferenceMissingSemiError = 23;
public static final int NSXMLParserEntityReferenceWithoutNameError = 22;
public static final int NSXMLParserEntityValueRequiredError = 84;
public static final int NSXMLParserEqualExpectedError = 75;
public static final int NSXMLParserExternalStandaloneEntityError = 82;
public static final int NSXMLParserExternalSubsetNotFinishedError = 60;
public static final int NSXMLParserExtraContentError = 86;
public static final int NSXMLParserGTRequiredError = 73;
public static final int NSXMLParserInternalError = 1;
public static final int NSXMLParserInvalidCharacterError = 9;
public static final int NSXMLParserInvalidCharacterInEntityError = 87;
public static final int NSXMLParserInvalidCharacterRefError = 8;
public static final int NSXMLParserInvalidConditionalSectionError = 83;
public static final int NSXMLParserInvalidDecimalCharacterRefError = 7;
public static final int NSXMLParserInvalidEncodingError = 81;
public static final int NSXMLParserInvalidEncodingNameError = 79;
public static final int NSXMLParserInvalidHexCharacterRefError = 6;
public static final int NSXMLParserInvalidURIError = 91;
public static final int NSXMLParserLTRequiredError = 72;
public static final int NSXMLParserLTSlashRequiredError = 74;
public static final int NSXMLParserLessThanSymbolInAttributeError = 38;
public static final int NSXMLParserLiteralNotFinishedError = 44;
public static final int NSXMLParserLiteralNotStartedError = 43;
public static final int NSXMLParserMisplacedCDATAEndStringError = 62;
public static final int NSXMLParserMisplacedXMLDeclarationError = 64;
public static final int NSXMLParserMixedContentDeclNotFinishedError = 53;
public static final int NSXMLParserMixedContentDeclNotStartedError = 52;
public static final int NSXMLParserNAMERequiredError = 68;
public static final int NSXMLParserNMTOKENRequiredError = 67;
public static final int NSXMLParserNamespaceDeclarationError = 35;
public static final int NSXMLParserNoDTDError = 94;
public static final int NSXMLParserNotWellBalancedError = 85;
public static final int NSXMLParserNotationNotFinishedError = 49;
public static final int NSXMLParserNotationNotStartedError = 48;
public static final int NSXMLParserOutOfMemoryError = 2;
public static final int NSXMLParserPCDATARequiredError = 69;
public static final int NSXMLParserParsedEntityRefAtEOFError = 18;
public static final int NSXMLParserParsedEntityRefInEpilogError = 20;
public static final int NSXMLParserParsedEntityRefInInternalError = 88;
public static final int NSXMLParserParsedEntityRefInInternalSubsetError = 21;
public static final int NSXMLParserParsedEntityRefInPrologError = 19;
public static final int NSXMLParserParsedEntityRefMissingSemiError = 25;
public static final int NSXMLParserParsedEntityRefNoNameError = 24;
public static final int NSXMLParserPrematureDocumentEndError = 5;
public static final int NSXMLParserProcessingInstructionNotFinishedError = 47;
public static final int NSXMLParserProcessingInstructionNotStartedError = 46;
public static final int NSXMLParserPublicIdentifierRequiredError = 71;
public static final int NSXMLParserSeparatorRequiredError = 66;
public static final int NSXMLParserSpaceRequiredError = 65;
public static final int NSXMLParserStandaloneValueError = 78;
public static final int NSXMLParserStringNotClosedError = 34;
public static final int NSXMLParserStringNotStartedError = 33;
public static final int NSXMLParserTagNameMismatchError = 76;
public static final int NSXMLParserURIFragmentError = 92;
public static final int NSXMLParserURIRequiredError = 70;
public static final int NSXMLParserUndeclaredEntityError = 26;
public static final int NSXMLParserUnfinishedTagError = 77;
public static final int NSXMLParserUnknownEncodingError = 31;
public static final int NSXMLParserUnparsedEntityError = 28;
public static final int NSXMLParserXMLDeclNotFinishedError = 57;
public static final int NSXMLParserXMLDeclNotStartedError = 56;
public static final int NSXMLProcessingInstructionKind = 5;
public static final int NSXMLTextKind = 7;
public static final int NSYearCalendarUnit = 4;
public static final int NS_BigEndian = 2;
public static final int NS_LittleEndian = 1;
public static final int NS_UNICHAR_IS_EIGHT_BIT = 0;
public static final int NS_UnknownByteOrder = 0;
public static final int DOM_ADDITION = 2;
public static final int DOM_ANY_TYPE = 0;
public static final int DOM_ANY_UNORDERED_NODE_TYPE = 8;
public static final int DOM_ATTRIBUTE_NODE = 2;
public static final int DOM_AT_TARGET = 2;
public static final int DOM_BAD_BOUNDARYPOINTS_ERR = 1;
public static final int DOM_BOOLEAN_TYPE = 3;
public static final int DOM_BOTH = 2;
public static final int DOM_BUBBLING_PHASE = 3;
public static final int DOM_CAPTURING_PHASE = 1;
public static final int DOM_CDATA_SECTION_NODE = 4;
public static final int DOM_CHARSET_RULE = 2;
public static final int DOM_COMMENT_NODE = 8;
public static final int DOM_CSS_ATTR = 22;
public static final int DOM_CSS_CM = 6;
public static final int DOM_CSS_COUNTER = 23;
public static final int DOM_CSS_CUSTOM = 3;
public static final int DOM_CSS_DEG = 11;
public static final int DOM_CSS_DIMENSION = 18;
public static final int DOM_CSS_EMS = 3;
public static final int DOM_CSS_EXS = 4;
public static final int DOM_CSS_GRAD = 13;
public static final int DOM_CSS_HZ = 16;
public static final int DOM_CSS_IDENT = 21;
public static final int DOM_CSS_IN = 8;
public static final int DOM_CSS_INHERIT = 0;
public static final int DOM_CSS_KHZ = 17;
public static final int DOM_CSS_MM = 7;
public static final int DOM_CSS_MS = 14;
public static final int DOM_CSS_NUMBER = 1;
public static final int DOM_CSS_PC = 10;
public static final int DOM_CSS_PERCENTAGE = 2;
public static final int DOM_CSS_PRIMITIVE_VALUE = 1;
public static final int DOM_CSS_PT = 9;
public static final int DOM_CSS_PX = 5;
public static final int DOM_CSS_RAD = 12;
public static final int DOM_CSS_RECT = 24;
public static final int DOM_CSS_RGBCOLOR = 25;
public static final int DOM_CSS_S = 15;
public static final int DOM_CSS_STRING = 19;
public static final int DOM_CSS_UNKNOWN = 0;
public static final int DOM_CSS_URI = 20;
public static final int DOM_CSS_VALUE_LIST = 2;
public static final int DOM_DOCUMENT_FRAGMENT_NODE = 11;
public static final int DOM_DOCUMENT_NODE = 9;
public static final int DOM_DOCUMENT_TYPE_NODE = 10;
public static final int DOM_DOMSTRING_SIZE_ERR = 2;
public static final int DOM_ELEMENT_NODE = 1;
public static final int DOM_END_TO_END = 2;
public static final int DOM_END_TO_START = 3;
public static final int DOM_ENTITY_NODE = 6;
public static final int DOM_ENTITY_REFERENCE_NODE = 5;
public static final int DOM_FILTER_ACCEPT = 1;
public static final int DOM_FILTER_REJECT = 2;
public static final int DOM_FILTER_SKIP = 3;
public static final int DOM_FIRST_ORDERED_NODE_TYPE = 9;
public static final int DOM_FONT_FACE_RULE = 5;
public static final int DOM_HIERARCHY_REQUEST_ERR = 3;
public static final int DOM_HORIZONTAL = 0;
public static final int DOM_IMPORT_RULE = 3;
public static final int DOM_INDEX_SIZE_ERR = 1;
public static final int DOM_INUSE_ATTRIBUTE_ERR = 10;
public static final int DOM_INVALID_ACCESS_ERR = 15;
public static final int DOM_INVALID_CHARACTER_ERR = 5;
public static final int DOM_INVALID_EXPRESSION_ERR = 51;
public static final int DOM_INVALID_MODIFICATION_ERR = 13;
public static final int DOM_INVALID_NODE_TYPE_ERR = 2;
public static final int DOM_INVALID_STATE_ERR = 11;
public static final int DOM_KEY_LOCATION_LEFT = 1;
public static final int DOM_KEY_LOCATION_NUMPAD = 3;
public static final int DOM_KEY_LOCATION_RIGHT = 2;
public static final int DOM_KEY_LOCATION_STANDARD = 0;
public static final int DOM_MEDIA_RULE = 4;
public static final int DOM_MODIFICATION = 1;
public static final int DOM_NAMESPACE_ERR = 14;
public static final int DOM_NODE_AFTER = 1;
public static final int DOM_NODE_BEFORE = 0;
public static final int DOM_NODE_BEFORE_AND_AFTER = 2;
public static final int DOM_NODE_INSIDE = 3;
public static final int DOM_NOTATION_NODE = 12;
public static final int DOM_NOT_FOUND_ERR = 8;
public static final int DOM_NOT_SUPPORTED_ERR = 9;
public static final int DOM_NO_DATA_ALLOWED_ERR = 6;
public static final int DOM_NO_MODIFICATION_ALLOWED_ERR = 7;
public static final int DOM_NUMBER_TYPE = 1;
public static final int DOM_ORDERED_NODE_ITERATOR_TYPE = 5;
public static final int DOM_ORDERED_NODE_SNAPSHOT_TYPE = 7;
public static final int DOM_PAGE_RULE = 6;
public static final int DOM_PROCESSING_INSTRUCTION_NODE = 7;
public static final int DOM_REMOVAL = 3;
public static final int DOM_SHOW_ALL = -1;
public static final int DOM_SHOW_ATTRIBUTE = 2;
public static final int DOM_SHOW_CDATA_SECTION = 8;
public static final int DOM_SHOW_COMMENT = 128;
public static final int DOM_SHOW_DOCUMENT = 256;
public static final int DOM_SHOW_DOCUMENT_FRAGMENT = 1024;
public static final int DOM_SHOW_DOCUMENT_TYPE = 512;
public static final int DOM_SHOW_ELEMENT = 1;
public static final int DOM_SHOW_ENTITY = 32;
public static final int DOM_SHOW_ENTITY_REFERENCE = 16;
public static final int DOM_SHOW_NOTATION = 2048;
public static final int DOM_SHOW_PROCESSING_INSTRUCTION = 64;
public static final int DOM_SHOW_TEXT = 4;
public static final int DOM_START_TO_END = 1;
public static final int DOM_START_TO_START = 0;
public static final int DOM_STRING_TYPE = 2;
public static final int DOM_STYLE_RULE = 1;
public static final int DOM_SYNTAX_ERR = 12;
public static final int DOM_TEXT_NODE = 3;
public static final int DOM_TYPE_ERR = 52;
public static final int DOM_UNKNOWN_RULE = 0;
public static final int DOM_UNORDERED_NODE_ITERATOR_TYPE = 4;
public static final int DOM_UNORDERED_NODE_SNAPSHOT_TYPE = 6;
public static final int DOM_UNSPECIFIED_EVENT_TYPE_ERR = 0;
public static final int DOM_VERTICAL = 1;
public static final int DOM_WRONG_DOCUMENT_ERR = 4;
public static final int WebCacheModelDocumentBrowser = 1;
public static final int WebCacheModelDocumentViewer = 0;
public static final int WebCacheModelPrimaryWebBrowser = 2;
public static final int WebDragDestinationActionAny = -1;
public static final int WebDragDestinationActionDHTML = 1;
public static final int WebDragDestinationActionEdit = 2;
public static final int WebDragDestinationActionLoad = 4;
public static final int WebDragDestinationActionNone = 0;
public static final int WebDragSourceActionAny = -1;
public static final int WebDragSourceActionDHTML = 1;
public static final int WebDragSourceActionImage = 2;
public static final int WebDragSourceActionLink = 4;
public static final int WebDragSourceActionNone = 0;
public static final int WebDragSourceActionSelection = 8;
public static final int WebJNIReturnTypeBoolean = 3;
public static final int WebJNIReturnTypeByte = 4;
public static final int WebJNIReturnTypeChar = 5;
public static final int WebJNIReturnTypeDouble = 10;
public static final int WebJNIReturnTypeFloat = 9;
public static final int WebJNIReturnTypeInt = 7;
public static final int WebJNIReturnTypeInvalid = 0;
public static final int WebJNIReturnTypeLong = 8;
public static final int WebJNIReturnTypeObject = 2;
public static final int WebJNIReturnTypeShort = 6;
public static final int WebJNIReturnTypeVoid = 1;
public static final int WebKitErrorCannotFindPlugIn = 200;
public static final int WebKitErrorCannotLoadPlugIn = 201;
public static final int WebKitErrorCannotShowMIMEType = 100;
public static final int WebKitErrorCannotShowURL = 101;
public static final int WebKitErrorFrameLoadInterruptedByPolicyChange = 102;
public static final int WebKitErrorJavaUnavailable = 202;
public static final int WebMenuItemPDFActualSize = 24;
public static final int WebMenuItemPDFAutoSize = 27;
public static final int WebMenuItemPDFContinuous = 30;
public static final int WebMenuItemPDFFacingPages = 29;
public static final int WebMenuItemPDFNextPage = 31;
public static final int WebMenuItemPDFPreviousPage = 32;
public static final int WebMenuItemPDFSinglePage = 28;
public static final int WebMenuItemPDFZoomIn = 25;
public static final int WebMenuItemPDFZoomOut = 26;
public static final int WebMenuItemTagCopy = 8;
public static final int WebMenuItemTagCopyImageToClipboard = 6;
public static final int WebMenuItemTagCopyLinkToClipboard = 3;
public static final int WebMenuItemTagCut = 13;
public static final int WebMenuItemTagDownloadImageToDisk = 5;
public static final int WebMenuItemTagDownloadLinkToDisk = 2;
public static final int WebMenuItemTagGoBack = 9;
public static final int WebMenuItemTagGoForward = 10;
public static final int WebMenuItemTagIgnoreSpelling = 17;
public static final int WebMenuItemTagLearnSpelling = 18;
public static final int WebMenuItemTagLookUpInDictionary = 22;
public static final int WebMenuItemTagNoGuessesFound = 16;
public static final int WebMenuItemTagOpenFrameInNewWindow = 7;
public static final int WebMenuItemTagOpenImageInNewWindow = 4;
public static final int WebMenuItemTagOpenLinkInNewWindow = 1;
public static final int WebMenuItemTagOpenWithDefaultApplication = 23;
public static final int WebMenuItemTagOther = 19;
public static final int WebMenuItemTagPaste = 14;
public static final int WebMenuItemTagReload = 12;
public static final int WebMenuItemTagSearchInSpotlight = 20;
public static final int WebMenuItemTagSearchWeb = 21;
public static final int WebMenuItemTagSpellingGuess = 15;
public static final int WebMenuItemTagStop = 11;
public static final int WebNavigationTypeBackForward = 2;
public static final int WebNavigationTypeFormResubmitted = 4;
public static final int WebNavigationTypeFormSubmitted = 1;
public static final int WebNavigationTypeLinkClicked = 0;
public static final int WebNavigationTypeOther = 5;
public static final int WebNavigationTypeReload = 3;
public static final int WebViewInsertActionDropped = 2;
public static final int WebViewInsertActionPasted = 1;
public static final int WebViewInsertActionTyped = 0;

/** Globals */
/** @method flags=const */
alias Cocoa.NSAccessibilityButtonRole NSAccessibilityButtonRole_;
public static const NSString NSAccessibilityButtonRole = new NSString(NSAccessibilityButtonRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityCheckBoxRole NSAccessibilityCheckBoxRole_;
public static const NSString NSAccessibilityCheckBoxRole = new NSString(NSAccessibilityCheckBoxRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityChildrenAttribute NSAccessibilityChildrenAttribute_;
public static const NSString NSAccessibilityChildrenAttribute = new NSString(NSAccessibilityChildrenAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityColumnRole NSAccessibilityColumnRole_;
public static const NSString NSAccessibilityColumnRole = new NSString(NSAccessibilityColumnRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityComboBoxRole NSAccessibilityComboBoxRole_;
public static const NSString NSAccessibilityComboBoxRole = new NSString(NSAccessibilityComboBoxRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityConfirmAction NSAccessibilityConfirmAction_;
public static const NSString NSAccessibilityConfirmAction = new NSString(NSAccessibilityConfirmAction_);
/** @method flags=const */
alias Cocoa.NSAccessibilityContentsAttribute NSAccessibilityContentsAttribute_;
public static const NSString NSAccessibilityContentsAttribute = new NSString(NSAccessibilityContentsAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityDescriptionAttribute NSAccessibilityDescriptionAttribute_;
public static const NSString NSAccessibilityDescriptionAttribute = new NSString(NSAccessibilityDescriptionAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityDialogSubrole NSAccessibilityDialogSubrole_;
public static const NSString NSAccessibilityDialogSubrole = new NSString(NSAccessibilityDialogSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityEnabledAttribute NSAccessibilityEnabledAttribute_;
public static const NSString NSAccessibilityEnabledAttribute = new NSString(NSAccessibilityEnabledAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityExpandedAttribute NSAccessibilityExpandedAttribute_;
public static const NSString NSAccessibilityExpandedAttribute = new NSString(NSAccessibilityExpandedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityFloatingWindowSubrole NSAccessibilityFloatingWindowSubrole_;
public static const NSString NSAccessibilityFloatingWindowSubrole = new NSString(NSAccessibilityFloatingWindowSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityFocusedAttribute NSAccessibilityFocusedAttribute_;
public static const NSString NSAccessibilityFocusedAttribute = new NSString(NSAccessibilityFocusedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityFocusedUIElementChangedNotification NSAccessibilityFocusedUIElementChangedNotification_;
public static const NSString NSAccessibilityFocusedUIElementChangedNotification = new NSString(NSAccessibilityFocusedUIElementChangedNotification_);
/** @method flags=const */
alias Cocoa.NSAccessibilityGridRole NSAccessibilityGridRole_;
public static const NSString NSAccessibilityGridRole = new NSString(NSAccessibilityGridRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityGroupRole NSAccessibilityGroupRole_;
public static const NSString NSAccessibilityGroupRole = new NSString(NSAccessibilityGroupRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityHelpAttribute NSAccessibilityHelpAttribute_;
public static const NSString NSAccessibilityHelpAttribute = new NSString(NSAccessibilityHelpAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityHelpTagRole NSAccessibilityHelpTagRole_;
public static const NSString NSAccessibilityHelpTagRole = new NSString(NSAccessibilityHelpTagRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityHorizontalOrientationValue NSAccessibilityHorizontalOrientationValue_;
public static const NSString NSAccessibilityHorizontalOrientationValue = new NSString(NSAccessibilityHorizontalOrientationValue_);
/** @method flags=const */
alias Cocoa.NSAccessibilityHorizontalScrollBarAttribute NSAccessibilityHorizontalScrollBarAttribute_;
public static const NSString NSAccessibilityHorizontalScrollBarAttribute = new NSString(NSAccessibilityHorizontalScrollBarAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityImageRole NSAccessibilityImageRole_;
public static const NSString NSAccessibilityImageRole = new NSString(NSAccessibilityImageRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityIncrementorRole NSAccessibilityIncrementorRole_;
public static const NSString NSAccessibilityIncrementorRole = new NSString(NSAccessibilityIncrementorRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityInsertionPointLineNumberAttribute NSAccessibilityInsertionPointLineNumberAttribute_;
public static const NSString NSAccessibilityInsertionPointLineNumberAttribute = new NSString(NSAccessibilityInsertionPointLineNumberAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityLabelValueAttribute NSAccessibilityLabelValueAttribute_;
public static const NSString NSAccessibilityLabelValueAttribute = new NSString(NSAccessibilityLabelValueAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityLineForIndexParameterizedAttribute NSAccessibilityLineForIndexParameterizedAttribute_;
public static const NSString NSAccessibilityLineForIndexParameterizedAttribute = new NSString(NSAccessibilityLineForIndexParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityLinkRole NSAccessibilityLinkRole_;
public static const NSString NSAccessibilityLinkRole = new NSString(NSAccessibilityLinkRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityLinkTextAttribute NSAccessibilityLinkTextAttribute_;
public static const NSString NSAccessibilityLinkTextAttribute = new NSString(NSAccessibilityLinkTextAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityListRole NSAccessibilityListRole_;
public static const NSString NSAccessibilityListRole = new NSString(NSAccessibilityListRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityMaxValueAttribute NSAccessibilityMaxValueAttribute_;
public static const NSString NSAccessibilityMaxValueAttribute = new NSString(NSAccessibilityMaxValueAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuBarRole NSAccessibilityMenuBarRole_;
public static const NSString NSAccessibilityMenuBarRole = new NSString(NSAccessibilityMenuBarRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuButtonRole NSAccessibilityMenuButtonRole_;
public static const NSString NSAccessibilityMenuButtonRole = new NSString(NSAccessibilityMenuButtonRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuItemRole NSAccessibilityMenuItemRole_;
public static const NSString NSAccessibilityMenuItemRole = new NSString(NSAccessibilityMenuItemRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuRole NSAccessibilityMenuRole_;
public static const NSString NSAccessibilityMenuRole = new NSString(NSAccessibilityMenuRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityMinValueAttribute NSAccessibilityMinValueAttribute_;
public static const NSString NSAccessibilityMinValueAttribute = new NSString(NSAccessibilityMinValueAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityNextContentsAttribute NSAccessibilityNextContentsAttribute_;
public static const NSString NSAccessibilityNextContentsAttribute = new NSString(NSAccessibilityNextContentsAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityNumberOfCharactersAttribute NSAccessibilityNumberOfCharactersAttribute_;
public static const NSString NSAccessibilityNumberOfCharactersAttribute = new NSString(NSAccessibilityNumberOfCharactersAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityOrientationAttribute NSAccessibilityOrientationAttribute_;
public static const NSString NSAccessibilityOrientationAttribute = new NSString(NSAccessibilityOrientationAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityOutlineRole NSAccessibilityOutlineRole_;
public static const NSString NSAccessibilityOutlineRole = new NSString(NSAccessibilityOutlineRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityOutlineRowSubrole NSAccessibilityOutlineRowSubrole_;
public static const NSString NSAccessibilityOutlineRowSubrole = new NSString(NSAccessibilityOutlineRowSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityParentAttribute NSAccessibilityParentAttribute_;
public static const NSString NSAccessibilityParentAttribute = new NSString(NSAccessibilityParentAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityPopUpButtonRole NSAccessibilityPopUpButtonRole_;
public static const NSString NSAccessibilityPopUpButtonRole = new NSString(NSAccessibilityPopUpButtonRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityPositionAttribute NSAccessibilityPositionAttribute_;
public static const NSString NSAccessibilityPositionAttribute = new NSString(NSAccessibilityPositionAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityPressAction NSAccessibilityPressAction_;
public static const NSString NSAccessibilityPressAction = new NSString(NSAccessibilityPressAction_);
/** @method flags=const */
alias Cocoa.NSAccessibilityPreviousContentsAttribute NSAccessibilityPreviousContentsAttribute_;
public static const NSString NSAccessibilityPreviousContentsAttribute = new NSString(NSAccessibilityPreviousContentsAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityProgressIndicatorRole NSAccessibilityProgressIndicatorRole_;
public static const NSString NSAccessibilityProgressIndicatorRole = new NSString(NSAccessibilityProgressIndicatorRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRTFForRangeParameterizedAttribute NSAccessibilityRTFForRangeParameterizedAttribute_;
public static const NSString NSAccessibilityRTFForRangeParameterizedAttribute = new NSString(NSAccessibilityRTFForRangeParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRadioButtonRole NSAccessibilityRadioButtonRole_;
public static const NSString NSAccessibilityRadioButtonRole = new NSString(NSAccessibilityRadioButtonRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRadioGroupRole NSAccessibilityRadioGroupRole_;
public static const NSString NSAccessibilityRadioGroupRole = new NSString(NSAccessibilityRadioGroupRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRangeForIndexParameterizedAttribute NSAccessibilityRangeForIndexParameterizedAttribute_;
public static const NSString NSAccessibilityRangeForIndexParameterizedAttribute = new NSString(NSAccessibilityRangeForIndexParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRangeForLineParameterizedAttribute NSAccessibilityRangeForLineParameterizedAttribute_;
public static const NSString NSAccessibilityRangeForLineParameterizedAttribute = new NSString(NSAccessibilityRangeForLineParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRangeForPositionParameterizedAttribute NSAccessibilityRangeForPositionParameterizedAttribute_;
public static const NSString NSAccessibilityRangeForPositionParameterizedAttribute = new NSString(NSAccessibilityRangeForPositionParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRoleAttribute NSAccessibilityRoleAttribute_;
public static const NSString NSAccessibilityRoleAttribute = new NSString(NSAccessibilityRoleAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRoleDescriptionAttribute NSAccessibilityRoleDescriptionAttribute_;
public static const NSString NSAccessibilityRoleDescriptionAttribute = new NSString(NSAccessibilityRoleDescriptionAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityRowRole NSAccessibilityRowRole_;
public static const NSString NSAccessibilityRowRole = new NSString(NSAccessibilityRowRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityScrollAreaRole NSAccessibilityScrollAreaRole_;
public static const NSString NSAccessibilityScrollAreaRole = new NSString(NSAccessibilityScrollAreaRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityScrollBarRole NSAccessibilityScrollBarRole_;
public static const NSString NSAccessibilityScrollBarRole = new NSString(NSAccessibilityScrollBarRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedAttribute NSAccessibilitySelectedAttribute_;
public static const NSString NSAccessibilitySelectedAttribute = new NSString(NSAccessibilitySelectedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedChildrenAttribute NSAccessibilitySelectedChildrenAttribute_;
public static const NSString NSAccessibilitySelectedChildrenAttribute = new NSString(NSAccessibilitySelectedChildrenAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedChildrenChangedNotification NSAccessibilitySelectedChildrenChangedNotification_;
public static const NSString NSAccessibilitySelectedChildrenChangedNotification = new NSString(NSAccessibilitySelectedChildrenChangedNotification_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextAttribute NSAccessibilitySelectedTextAttribute_;
public static const NSString NSAccessibilitySelectedTextAttribute = new NSString(NSAccessibilitySelectedTextAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextChangedNotification NSAccessibilitySelectedTextChangedNotification_;
public static const NSString NSAccessibilitySelectedTextChangedNotification = new NSString(NSAccessibilitySelectedTextChangedNotification_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextRangeAttribute NSAccessibilitySelectedTextRangeAttribute_;
public static const NSString NSAccessibilitySelectedTextRangeAttribute = new NSString(NSAccessibilitySelectedTextRangeAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextRangesAttribute NSAccessibilitySelectedTextRangesAttribute_;
public static const NSString NSAccessibilitySelectedTextRangesAttribute = new NSString(NSAccessibilitySelectedTextRangesAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySizeAttribute NSAccessibilitySizeAttribute_;
public static const NSString NSAccessibilitySizeAttribute = new NSString(NSAccessibilitySizeAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySliderRole NSAccessibilitySliderRole_;
public static const NSString NSAccessibilitySliderRole = new NSString(NSAccessibilitySliderRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySortButtonRole NSAccessibilitySortButtonRole_;
public static const NSString NSAccessibilitySortButtonRole = new NSString(NSAccessibilitySortButtonRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySplitterRole NSAccessibilitySplitterRole_;
public static const NSString NSAccessibilitySplitterRole = new NSString(NSAccessibilitySplitterRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityStandardWindowSubrole NSAccessibilityStandardWindowSubrole_;
public static const NSString NSAccessibilityStandardWindowSubrole = new NSString(NSAccessibilityStandardWindowSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityStaticTextRole NSAccessibilityStaticTextRole_;
public static const NSString NSAccessibilityStaticTextRole = new NSString(NSAccessibilityStaticTextRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityStringForRangeParameterizedAttribute NSAccessibilityStringForRangeParameterizedAttribute_;
public static const NSString NSAccessibilityStringForRangeParameterizedAttribute = new NSString(NSAccessibilityStringForRangeParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityStyleRangeForIndexParameterizedAttribute NSAccessibilityStyleRangeForIndexParameterizedAttribute_;
public static const NSString NSAccessibilityStyleRangeForIndexParameterizedAttribute = new NSString(NSAccessibilityStyleRangeForIndexParameterizedAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySubroleAttribute NSAccessibilitySubroleAttribute_;
public static const NSString NSAccessibilitySubroleAttribute = new NSString(NSAccessibilitySubroleAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilitySystemDialogSubrole NSAccessibilitySystemDialogSubrole_;
public static const NSString NSAccessibilitySystemDialogSubrole = new NSString(NSAccessibilitySystemDialogSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTabGroupRole NSAccessibilityTabGroupRole_;
public static const NSString NSAccessibilityTabGroupRole = new NSString(NSAccessibilityTabGroupRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTableRole NSAccessibilityTableRole_;
public static const NSString NSAccessibilityTableRole = new NSString(NSAccessibilityTableRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTableRowSubrole NSAccessibilityTableRowSubrole_;
public static const NSString NSAccessibilityTableRowSubrole = new NSString(NSAccessibilityTableRowSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTabsAttribute NSAccessibilityTabsAttribute_;
public static const NSString NSAccessibilityTabsAttribute = new NSString(NSAccessibilityTabsAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTextAreaRole NSAccessibilityTextAreaRole_;
public static const NSString NSAccessibilityTextAreaRole = new NSString(NSAccessibilityTextAreaRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTextFieldRole NSAccessibilityTextFieldRole_;
public static const NSString NSAccessibilityTextFieldRole = new NSString(NSAccessibilityTextFieldRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTextLinkSubrole NSAccessibilityTextLinkSubrole_;
public static const NSString NSAccessibilityTextLinkSubrole = new NSString(NSAccessibilityTextLinkSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTitleAttribute NSAccessibilityTitleAttribute_;
public static const NSString NSAccessibilityTitleAttribute = new NSString(NSAccessibilityTitleAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTitleUIElementAttribute NSAccessibilityTitleUIElementAttribute_;
public static const NSString NSAccessibilityTitleUIElementAttribute = new NSString(NSAccessibilityTitleUIElementAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityToolbarRole NSAccessibilityToolbarRole_;
public static const NSString NSAccessibilityToolbarRole = new NSString(NSAccessibilityToolbarRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityTopLevelUIElementAttribute NSAccessibilityTopLevelUIElementAttribute_;
public static const NSString NSAccessibilityTopLevelUIElementAttribute = new NSString(NSAccessibilityTopLevelUIElementAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityUnknownRole NSAccessibilityUnknownRole_;
public static const NSString NSAccessibilityUnknownRole = new NSString(NSAccessibilityUnknownRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityUnknownSubrole NSAccessibilityUnknownSubrole_;
public static const NSString NSAccessibilityUnknownSubrole = new NSString(NSAccessibilityUnknownSubrole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityValueAttribute NSAccessibilityValueAttribute_;
public static const NSString NSAccessibilityValueAttribute = new NSString(NSAccessibilityValueAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityValueChangedNotification NSAccessibilityValueChangedNotification_;
public static const NSString NSAccessibilityValueChangedNotification = new NSString(NSAccessibilityValueChangedNotification_);
/** @method flags=const */
alias Cocoa.NSAccessibilityValueDescriptionAttribute NSAccessibilityValueDescriptionAttribute_;
public static const NSString NSAccessibilityValueDescriptionAttribute = new NSString(NSAccessibilityValueDescriptionAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityValueIndicatorRole NSAccessibilityValueIndicatorRole_;
public static const NSString NSAccessibilityValueIndicatorRole = new NSString(NSAccessibilityValueIndicatorRole_);
/** @method flags=const */
alias Cocoa.NSAccessibilityVerticalOrientationValue NSAccessibilityVerticalOrientationValue_;
public static const NSString NSAccessibilityVerticalOrientationValue = new NSString(NSAccessibilityVerticalOrientationValue_);
/** @method flags=const */
alias Cocoa.NSAccessibilityVerticalScrollBarAttribute NSAccessibilityVerticalScrollBarAttribute_;
public static const NSString NSAccessibilityVerticalScrollBarAttribute = new NSString(NSAccessibilityVerticalScrollBarAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityVisibleCharacterRangeAttribute NSAccessibilityVisibleCharacterRangeAttribute_;
public static const NSString NSAccessibilityVisibleCharacterRangeAttribute = new NSString(NSAccessibilityVisibleCharacterRangeAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityVisibleChildrenAttribute NSAccessibilityVisibleChildrenAttribute_;
public static const NSString NSAccessibilityVisibleChildrenAttribute = new NSString(NSAccessibilityVisibleChildrenAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityWindowAttribute NSAccessibilityWindowAttribute_;
public static const NSString NSAccessibilityWindowAttribute = new NSString(NSAccessibilityWindowAttribute_);
/** @method flags=const */
alias Cocoa.NSAccessibilityWindowRole NSAccessibilityWindowRole_;
public static const NSString NSAccessibilityWindowRole = new NSString(NSAccessibilityWindowRole_);
/** @method flags=const */
alias Cocoa.NSBackgroundColorAttributeName NSBackgroundColorAttributeName_;
public static const NSString NSBackgroundColorAttributeName = new NSString(NSBackgroundColorAttributeName_);
/** @method flags=const */
alias Cocoa.NSBaselineOffsetAttributeName NSBaselineOffsetAttributeName_;
public static const NSString NSBaselineOffsetAttributeName = new NSString(NSBaselineOffsetAttributeName_);
/** @method flags=const */
alias Cocoa.NSCalibratedRGBColorSpace NSCalibratedRGBColorSpace_;
public static const NSString NSCalibratedRGBColorSpace = new NSString(NSCalibratedRGBColorSpace_);
/** @method flags=const */
alias Cocoa.NSDeviceRGBColorSpace NSDeviceRGBColorSpace_;
public static const NSString NSDeviceRGBColorSpace = new NSString(NSDeviceRGBColorSpace_);
/** @method flags=const */
alias Cocoa.NSDeviceResolution NSDeviceResolution_;
public static const NSString NSDeviceResolution = new NSString(NSDeviceResolution_);
/** @method flags=const */
alias Cocoa.NSDragPboard NSDragPboard_;
public static const NSString NSDragPboard = new NSString(NSDragPboard_);
/** @method flags=const */
alias Cocoa.NSFilenamesPboardType NSFilenamesPboardType_;
public static const NSString NSFilenamesPboardType = new NSString(NSFilenamesPboardType_);
/** @method flags=const */
alias Cocoa.NSFontAttributeName NSFontAttributeName_;
public static const NSString NSFontAttributeName = new NSString(NSFontAttributeName_);
/** @method flags=const */
alias Cocoa.NSForegroundColorAttributeName NSForegroundColorAttributeName_;
public static const NSString NSForegroundColorAttributeName = new NSString(NSForegroundColorAttributeName_);
/** @method flags=const */
alias Cocoa.NSHTMLPboardType NSHTMLPboardType_;
public static const NSString NSHTMLPboardType = new NSString(NSHTMLPboardType_);
/** @method flags=const */
alias Cocoa.NSLinkAttributeName NSLinkAttributeName_;
public static const NSString NSLinkAttributeName = new NSString(NSLinkAttributeName_);
/** @method flags=const */
alias Cocoa.NSParagraphStyleAttributeName NSParagraphStyleAttributeName_;
public static const NSString NSParagraphStyleAttributeName = new NSString(NSParagraphStyleAttributeName_);
/** @method flags=const */
alias Cocoa.NSPrintAllPages NSPrintAllPages_;
public static const NSString NSPrintAllPages = new NSString(NSPrintAllPages_);
/** @method flags=const */
alias Cocoa.NSPrintCopies NSPrintCopies_;
public static const NSString NSPrintCopies = new NSString(NSPrintCopies_);
/** @method flags=const */
alias Cocoa.NSPrintFirstPage NSPrintFirstPage_;
public static const NSString NSPrintFirstPage = new NSString(NSPrintFirstPage_);
/** @method flags=const */
alias Cocoa.NSPrintJobDisposition NSPrintJobDisposition_;
public static const NSString NSPrintJobDisposition = new NSString(NSPrintJobDisposition_);
/** @method flags=const */
alias Cocoa.NSPrintLastPage NSPrintLastPage_;
public static const NSString NSPrintLastPage = new NSString(NSPrintLastPage_);
/** @method flags=const */
alias Cocoa.NSPrintMustCollate NSPrintMustCollate_;
public static const NSString NSPrintMustCollate = new NSString(NSPrintMustCollate_);
/** @method flags=const */
alias Cocoa.NSPrintPreviewJob NSPrintPreviewJob_;
public static const NSString NSPrintPreviewJob = new NSString(NSPrintPreviewJob_);
/** @method flags=const */
alias Cocoa.NSPrintSaveJob NSPrintSaveJob_;
public static const NSString NSPrintSaveJob = new NSString(NSPrintSaveJob_);
/** @method flags=const */
alias Cocoa.NSPrintSavePath NSPrintSavePath_;
public static const NSString NSPrintSavePath = new NSString(NSPrintSavePath_);
/** @method flags=const */
alias Cocoa.NSPrintSpoolJob NSPrintSpoolJob_;
public static const NSString NSPrintSpoolJob = new NSString(NSPrintSpoolJob_);
/** @method flags=const */
alias Cocoa.NSRTFPboardType NSRTFPboardType_;
public static const NSString NSRTFPboardType = new NSString(NSRTFPboardType_);
/** @method flags=const */
alias Cocoa.NSStrikethroughColorAttributeName NSStrikethroughColorAttributeName_;
public static const NSString NSStrikethroughColorAttributeName = new NSString(NSStrikethroughColorAttributeName_);
/** @method flags=const */
alias Cocoa.NSStrikethroughStyleAttributeName NSStrikethroughStyleAttributeName_;
public static const NSString NSStrikethroughStyleAttributeName = new NSString(NSStrikethroughStyleAttributeName_);
/** @method flags=const */
alias Cocoa.NSStringPboardType NSStringPboardType_;
public static const NSString NSStringPboardType = new NSString(NSStringPboardType_);
/** @method flags=const */
alias Cocoa.NSTIFFPboardType NSTIFFPboardType_;
public static const NSString NSTIFFPboardType = new NSString(NSTIFFPboardType_);
/** @method flags=const */
alias Cocoa.NSURLPboardType NSURLPboardType_;
public static const NSString NSURLPboardType = new NSString(NSURLPboardType_);
/** @method flags=const */
alias Cocoa.NSUnderlineColorAttributeName NSUnderlineColorAttributeName_;
public static const NSString NSUnderlineColorAttributeName = new NSString(NSUnderlineColorAttributeName_);
/** @method flags=const */
alias Cocoa.NSUnderlineStyleAttributeName NSUnderlineStyleAttributeName_;
public static const NSString NSUnderlineStyleAttributeName = new NSString(NSUnderlineStyleAttributeName_);
/** @method flags=const */
alias Cocoa.NSDefaultRunLoopMode NSDefaultRunLoopMode_;
public static const NSString NSDefaultRunLoopMode = new NSString(NSDefaultRunLoopMode_);
/** @method flags=const */
alias Cocoa.NSErrorFailingURLStringKey NSErrorFailingURLStringKey_;
public static const NSString NSErrorFailingURLStringKey = new NSString(NSErrorFailingURLStringKey_);

/** Functions */

/**
 * @param action cast=(NSString*)
 */
alias Cocoa.NSAccessibilityActionDescription NSAccessibilityActionDescription;
/**
 * @param element cast=(id)
 * @param notification cast=(NSString*)
 */
alias Cocoa.NSAccessibilityPostNotification NSAccessibilityPostNotification;
/**
* @param element cast=(id)
* @param attribute cast=(NSString*)
* @param value cast=(id)
*/
alias Cocoa.NSAccessibilityRaiseBadArgumentException NSAccessibilityRaiseBadArgumentException;
/**
* @param role cast=(NSString*)
* @param subrole cast=(NSString*)
*/
alias Cocoa.NSAccessibilityRoleDescription NSAccessibilityRoleDescription;
/**
* @param element cast=(id)
*/
alias Cocoa.NSAccessibilityRoleDescriptionForUIElement NSAccessibilityRoleDescriptionForUIElement;
/**
* @param element cast=(id)
*/
alias Cocoa.NSAccessibilityUnignoredAncestor NSAccessibilityUnignoredAncestor;
/**
* @param originalChildren cast=(NSArray*)
*/
alias Cocoa.NSAccessibilityUnignoredChildren NSAccessibilityUnignoredChildren;
/**
* @param originalChild cast=(id)
*/
alias Cocoa.NSAccessibilityUnignoredChildrenForOnlyChild NSAccessibilityUnignoredChildrenForOnlyChild;
/**
* @param element cast=(id)
*/
alias Cocoa.NSAccessibilityUnignoredDescendant NSAccessibilityUnignoredDescendant;
alias Cocoa.NSBeep NSBeep;
/**
* @param depth cast=(NSWindowDepth)
*/
alias Cocoa.NSBitsPerPixelFromDepth NSBitsPerPixelFromDepth;
/**
* @param cf cast=(CFTypeRef)
*/
alias Carbon.CFRelease CFRelease;
/**
* @param allocator cast=(CFAllocatorRef)
* @param originalString cast=(CFStringRef)
* @param charactersToLeaveUnescaped cast=(CFStringRef)
* @param legalURLCharactersToBeEscaped cast=(CFStringRef)
* @param encoding cast=(CFStringEncoding)
*/
alias Carbon.CFURLCreateStringByAddingPercentEscapes CFURLCreateStringByAddingPercentEscapes;
/**
* @param newCursorPosition flags=struct */
alias Carbon.CGWarpMouseCursorPosition CGWarpMouseCursorPosition;
/**
* @param hfsFileTypeCode cast=(OSType)
*/
alias Cocoa.NSFileTypeForHFSTypeCode NSFileTypeForHFSTypeCode;
/**
* @param typePtr cast=(char*)
* @param sizep cast=(NSUInteger*)
* @param alignp cast=(NSUInteger*)
*/
alias Cocoa.NSGetSizeAndAlignment NSGetSizeAndAlignment;
/**
* @param directory cast=(NSSearchPathDirectory)
* @param domainMask cast=(NSSearchPathDomainMask)
* @param expandTilde cast=(BOOL)
*/
alias Cocoa.NSSearchPathForDirectoriesInDomains NSSearchPathForDirectoriesInDomains;
alias Cocoa.NSTemporaryDirectory NSTemporaryDirectory;

/** Sends */

/** @method flags=cast */
alias objc.objc_msgSend_bool objc_msgSend_bool;
/** @method flags=cast */
alias objc.objc_msgSend_fpret objc_msgSend_fpret;
/** @method flags=cast */
alias objc.objc_msgSend objc_msgSend;
/** @method flags=cast */
alias objc.objc_msgSend_stret objc_msgSend_stret;

/** Sizeof natives */


/** Memmove natives */

/**
 * @param dest cast=(void *),flags=no_in critical
 * @param src cast=(void *),flags=critical
 */
alias stdc.memmove memmove;

/** This section is auto generated */
}
